@@ -11,6 +11,8 @@
 #ifndef __FREECHEMICALFEATURE_H_13012005_1023__
 #define __FREECHEMICALFEATURE_H_13012005_1023__
 
+#include <utility>
+
 #include <Geometry/point.h>
 #include <ChemicalFeatures/ChemicalFeature.h>
 
@@ -18,25 +20,25 @@ namespace ChemicalFeatures {
 
 //------------------------------------------------------
 //! Class for chemical features that do not originate from molecules
-//  e.g. pharmacophores, site-maps etc.
+/// e.g. pharmacophores, site-maps etc.
 class RDKIT_CHEMICALFEATURES_EXPORT FreeChemicalFeature
     : public ChemicalFeature {
  public:
   //! start with everything specified
-  FreeChemicalFeature(const std::string &family, std::string type,
+  FreeChemicalFeature(std::string family, std::string type,
                       const RDGeom::Point3D &loc, int id = -1)
-      : d_id(id), d_family(family), d_type(type), d_position(loc) {}
+      : d_id(id),
+        d_family(std::move(family)),
+        d_type(std::move(type)),
+        d_position(loc) {}
 
   //! start with family and location specified, leave the type blank
-  FreeChemicalFeature(const std::string &family, const RDGeom::Point3D &loc)
-      : d_id(-1), d_family(family), d_type(""), d_position(loc) {}
+  FreeChemicalFeature(std::string family, const RDGeom::Point3D &loc)
+      : d_id(-1), d_family(std::move(family)), d_type(""), d_position(loc) {}
 
   //! start with everything blank
   FreeChemicalFeature()
-      : 
-        d_family(""),
-        d_type(""),
-        d_position(RDGeom::Point3D(0.0, 0.0, 0.0)) {}
+      : d_family(""), d_type(""), d_position(RDGeom::Point3D(0.0, 0.0, 0.0)) {}
 
   explicit FreeChemicalFeature(const std::string &pickle) {
     this->initFromString(pickle);
@@ -48,19 +50,19 @@ class RDKIT_CHEMICALFEATURES_EXPORT FreeChemicalFeature
         d_type(other.getType()),
         d_position(other.getPos()) {}
 
-  ~FreeChemicalFeature() {}
+  ~FreeChemicalFeature() override = default;
 
   //! return our id
-  int getId() const { return d_id; }
+  int getId() const override { return d_id; }
 
   //! return our family
-  const std::string &getFamily() const { return d_family; }
+  const std::string &getFamily() const override { return d_family; }
 
   //! return our type
-  const std::string &getType() const { return d_type; }
+  const std::string &getType() const override { return d_type; }
 
   //! return our position
-  RDGeom::Point3D getPos() const { return d_position; }
+  RDGeom::Point3D getPos() const override { return d_position; }
 
   //! set our id
   void setId(const int id) { d_id = id; }
