@@ -74,8 +74,8 @@ python::list BulkDice(const T &siv1, python::list sivs, bool returnDistance) {
   unsigned int nsivs = python::extract<unsigned int>(sivs.attr("__len__")());
   for (unsigned int i = 0; i < nsivs; ++i) {
     double simVal;
-    const T &siv2 = python::extract<T>(sivs[i])();
-    simVal = DiceSimilarity(siv1, siv2, returnDistance);
+    const T *siv2 = python::extract<T *>(sivs[i])();
+    simVal = DiceSimilarity(siv1, *siv2, returnDistance);
     res.append(simVal);
   }
   return res;
@@ -87,8 +87,8 @@ python::list BulkTanimoto(const T &siv1, python::list sivs,
   unsigned int nsivs = python::extract<unsigned int>(sivs.attr("__len__")());
   for (unsigned int i = 0; i < nsivs; ++i) {
     double simVal;
-    const T &siv2 = python::extract<T>(sivs[i])();
-    simVal = TanimotoSimilarity(siv1, siv2, returnDistance);
+    const T *siv2 = python::extract<T *>(sivs[i])();
+    simVal = TanimotoSimilarity(siv1, *siv2, returnDistance);
     res.append(simVal);
   }
   return res;
@@ -101,8 +101,8 @@ python::list BulkTversky(const T &siv1, python::list sivs, double a, double b,
   unsigned int nsivs = python::extract<unsigned int>(sivs.attr("__len__")());
   for (unsigned int i = 0; i < nsivs; ++i) {
     double simVal;
-    const T &siv2 = python::extract<T>(sivs[i])();
-    simVal = TverskySimilarity(siv1, siv2, a, b, returnDistance);
+    const T *siv2 = python::extract<T *>(sivs[i])();
+    simVal = TverskySimilarity(siv1, *siv2, a, b, returnDistance);
     res.append(simVal);
   }
   return res;
@@ -140,8 +140,9 @@ struct sparseIntVec_wrapper {
         // Note: we cannot support __len__ because, at least at the moment
         // (BPL v1.34.1), it must return an int.
         .def("__setitem__", &SparseIntVect<IndexType>::setVal,
-             "Set the value at a specified location")
+             python::args("self"), "Set the value at a specified location")
         .def("__getitem__", &SparseIntVect<IndexType>::getVal,
+             python::args("self"),
              "Get the value at a specified location")
         .def(python::self & python::self)
         .def(python::self | python::self)
@@ -168,17 +169,19 @@ struct sparseIntVec_wrapper {
         //.def(python::self * int())
         .def(python::self *= int())
         .def("GetTotalVal", &SparseIntVect<IndexType>::getTotalVal,
-             (python::args("useAbs") = false),
+             ((python::args("self"), python::args("useAbs") = false)),
              "Get the sum of the values in the vector, basically L1 norm")
         .def("GetLength", &SparseIntVect<IndexType>::getLength,
-             "Returns the length of the vector")
-        .def("ToBinary", &SIVToBinaryText<IndexType>,
+             python::args("self"), "Returns the length of the vector")
+        .def("ToBinary", &SIVToBinaryText<IndexType>, python::args("self"),
              "returns a binary (pickle) representation of the vector")
         .def("UpdateFromSequence", &pyUpdateFromSequence<IndexType>,
+             python::args("self", "seq"),
              "update the vector based on the values in the list or tuple")
         .def("GetNonzeroElements", &pyGetNonzeroElements<IndexType>,
+             python::args("self"),
              "returns a dictionary of the nonzero elements")
-        .def("ToList", pyToList<IndexType>,
+        .def("ToList", pyToList<IndexType>, python::args("self"),
              "Return the SparseIntVect as a python list")
         .def_pickle(siv_pickle_suite<IndexType>());
 
