@@ -17,13 +17,48 @@ namespace ForceFields {
 namespace MMFF {
 class MMFFVdWCollection;
 class MMFFVdW;
+
+//! combined vdW and charge terms for MMFF
+class RDKIT_FORCEFIELD_EXPORT NonbondedContrib : public ForceFieldContrib {
+ public:
+  NonbondedContrib() {}
+  NonbondedContrib(ForceField *owner);
+  //! Track a new VdW pair
+  void addTerm(unsigned int idx1, unsigned int idx2,
+               const MMFFVdWRijstarEps *mmffVdWConstants, bool includeCharge,
+               double chargeTerm, std::uint8_t dielModel, bool is1_4);
+  double getEnergy(double *pos) const override;
+  void getGrad(double *pos, double *grad) const override;
+  NonbondedContrib *copy() const override {
+    return new NonbondedContrib(*this);
+  }
+
+ private:
+  enum ContribType {
+    VDW = 1 << 0,           //!< van der Waals contribution
+    ELECTROSTATIC = 1 << 1  //!< electrostatic contribution
+  };
+  std::vector<int16_t> d_at1Idxs;
+  std::vector<int16_t> d_at2Idxs;
+  std::vector<std::uint8_t>
+      d_contribTypes;                //!< bit field 0x1: vdW, 0x2: electrostatic
+  std::vector<double> d_R_ij_stars;  //!< the preferred length of the contact
+  std::vector<double>
+      d_wellDepths;  //!< the vdW well depth (strength of the interaction)
+  std::vector<double> d_chargeTerms;
+  std::vector<std::uint8_t> d_is_1_4s;
+  std::vector<std::uint8_t>
+      d_dielModels;  //!< dielectric model (1: constant; 2: distance-dependent)
+};
+
 //! the van der Waals term for MMFF
 class RDKIT_FORCEFIELD_EXPORT VdWContrib : public ForceFieldContrib {
  public:
   VdWContrib() {}
   VdWContrib(ForceField *owner);
   //! Track a new VdW pair
-  void addTerm(unsigned int idx1, unsigned int idx2, const MMFFVdWRijstarEps *mmffVdWConstants);
+  void addTerm(unsigned int idx1, unsigned int idx2,
+               const MMFFVdWRijstarEps *mmffVdWConstants);
   double getEnergy(double *pos) const override;
   void getGrad(double *pos, double *grad) const override;
   VdWContrib *copy() const override { return new VdWContrib(*this); }
@@ -31,8 +66,9 @@ class RDKIT_FORCEFIELD_EXPORT VdWContrib : public ForceFieldContrib {
  private:
   std::vector<int16_t> d_at1Idxs;
   std::vector<int16_t> d_at2Idxs;
-  std::vector<double> d_R_ij_stars; //!< the preferred length of the contact
-  std::vector<double> d_wellDepths; //!< the vdW well depth (strength of the interaction)
+  std::vector<double> d_R_ij_stars;  //!< the preferred length of the contact
+  std::vector<double>
+      d_wellDepths;  //!< the vdW well depth (strength of the interaction)
 };
 
 //! the electrostatic term for MMFF
@@ -48,8 +84,8 @@ class RDKIT_FORCEFIELD_EXPORT EleContrib : public ForceFieldContrib {
 
   */
   EleContrib(ForceField *owner);
-  void addTerm(unsigned int idx1, unsigned int idx2,
-               double chargeTerm, std::uint8_t dielModel, bool is1_4);
+  void addTerm(unsigned int idx1, unsigned int idx2, double chargeTerm,
+               std::uint8_t dielModel, bool is1_4);
   double getEnergy(double *pos) const override;
   void getGrad(double *pos, double *grad) const override;
 
