@@ -93,38 +93,46 @@ struct uGrid3D_wrapper {
   static void wrap() {
     python::class_<UniformGrid3D>(
         "UniformGrid3D_", uGridClassDoc.c_str(),
-        python::init<std::string>("pickle constructor"))
+        python::init<std::string>(python::args("self", "pkl"),
+                                  "pickle constructor"))
         .def("GetGridPointIndex", &UniformGrid3D::getGridPointIndex,
+             python::args("self", "point"),
              "Get the index to the grid point closest to the specified point")
         .def("GetGridIndex", &UniformGrid3D::getGridIndex,
+             python::args("self", "xi", "yi", "zi"),
              "Get the index to the grid point with the three integer indices "
              "provided")
-        .def("GetGridIndices", &getGridIndicesWrap,
+        .def("GetGridIndices", &getGridIndicesWrap, python::args("self", "idx"),
              "Returns the integer indices of the grid index provided.")
-        .def("GetValPoint", getValPoint,
+        .def("GetValPoint", getValPoint, python::args("self", "pt"),
              "Get the value at the closest grid point")
-        .def("GetVal", getValIndex, "Get the value at the specified grid point")
-        .def("SetVal", setValIndex, "Set the value at the specified grid point")
-        .def("SetValPoint", setValPoint,
+        .def("GetVal", getValIndex, python::args("self", "id"),
+             "Get the value at the specified grid point")
+        .def("SetVal", setValIndex, python::args("self", "id", "val"),
+             "Set the value at the specified grid point")
+        .def("SetValPoint", setValPoint, python::args("self", "pt", "val"),
              "Set the value at grid point closest to the specified point")
         .def("GetGridPointLoc", &UniformGrid3D::getGridPointLoc,
+             python::args("self", "pointId"),
              "Get the location of the specified grid point")
-        .def("GetSize", &UniformGrid3D::getSize,
+        .def("GetSize", &UniformGrid3D::getSize, python::args("self"),
              "Get the size of the grid (number of grid points)")
-        .def("GetNumX", &UniformGrid3D::getNumX,
+        .def("GetNumX", &UniformGrid3D::getNumX, python::args("self"),
              "Get the number of grid points along x-axis")
-        .def("GetNumY", &UniformGrid3D::getNumY,
+        .def("GetNumY", &UniformGrid3D::getNumY, python::args("self"),
              "Get the number of grid points along y-axis")
-        .def("GetNumZ", &UniformGrid3D::getNumZ,
+        .def("GetNumZ", &UniformGrid3D::getNumZ, python::args("self"),
              "Get the number of grid points along z-axis")
         .def("GetOffset", &UniformGrid3D::getOffset,
              python::return_value_policy<python::copy_const_reference>(),
-             "Get the location of the center of the grid")
-        .def("GetSpacing", &UniformGrid3D::getSpacing, "Get the grid spacing")
+             python::args("self"), "Get the location of the center of the grid")
+        .def("GetSpacing", &UniformGrid3D::getSpacing, python::args("self"),
+             "Get the grid spacing")
         .def("GetOccupancyVect", &UniformGrid3D::getOccupancyVect,
              python::return_value_policy<python::reference_existing_object>(),
-             "Get the occupancy vector for the grid")
+             python::args("self"), "Get the occupancy vector for the grid")
         .def("CompareParams", &UniformGrid3D::compareParams,
+             python::args("self", "other"),
              "Compare the parameters between two grid object")
         .def("SetSphereOccupancy", &UniformGrid3D::setSphereOccupancy,
              (python::arg("self"), python::arg("center"), python::arg("radius"),
@@ -161,19 +169,25 @@ struct uGrid3D_wrapper {
                 python::return_value_policy<python::manage_new_object>());
 
     python::def("WriteGridToFile", writeGridToFile,
+                python::args("grid", "filename"),
                 "Write the grid to a grid file");
 
     python::def("TverskyIndex", tverskyIndex<UniformGrid3D>,
+                python::args("grid1", "grid2", "alpha", "beta"),
                 "Compute the tversky index between two grid objects");
     python::def("TanimotoDistance", tanimotoDistance<UniformGrid3D>,
+                python::args("grid1", "grid2"),
                 "Compute the tanimoto distance between two grid objects");
     python::def("ProtrudeDistance", protrudeDistance<UniformGrid3D>,
+                python::args("grid1", "grid2"),
                 "Compute the protrude distance between two grid objects");
     python::def(
         "ComputeGridCentroid", computeGridCentroidWrap,
+        python::args("grid", "pt", "windowRadius"),
         "Compute the grid point at the center of sphere around a Point3D");
     python::def(
         "FindGridTerminalPoints", findGridTerminalPointsWrap,
+        python::args("grid", "windowRadius", "inclusionFraction"),
         "Find a grid's terminal points (defined in the subshape algorithm).");
   }
 };
