@@ -48,7 +48,8 @@ void Digraph::addEdge(Node *beg, Bond *bond, Node *end) {
   end->add(&e);
 }
 
-Digraph::Digraph(const CIPMol &mol, Atom *atom) : d_mol{mol} {
+Digraph::Digraph(const CIPMol &mol, Atom *atom, bool atropisomerMode)
+    : d_mol{mol} {
   PRECONDITION(atom, "cannot init digraph on a nullptr")
 
   auto visit = std::vector<char>(d_mol.getNumAtoms());
@@ -60,6 +61,7 @@ Digraph::Digraph(const CIPMol &mol, Atom *atom) : d_mol{mol} {
 
   dp_root = &addNode(std::move(visit), atom, atomic_num, dist, flags);
   dp_origin = dp_root;
+  d_atropisomerMode = atropisomerMode;
 }
 
 const CIPMol &Digraph::getMol() const { return d_mol; };
@@ -72,9 +74,10 @@ int Digraph::getNumNodes() const { return d_nodes.size(); }
 
 std::vector<Node *> Digraph::getNodes(Atom *atom) const {
   std::vector<Node *> result;
-  auto queue = std::list<Node *>({getCurrentRoot()});
+  std::vector<Node*> queue = {getCurrentRoot()};
 
-  for (const auto &node : queue) {
+  for (size_t i=0; i<queue.size(); ++i) {
+    auto node = queue[i];
     if (atom == node->getAtom()) {
       result.push_back(node);
     }
@@ -151,7 +154,7 @@ void Digraph::expand(Node *beg) {
 
       // duplicate nodes for bond orders (except for root atoms...)
       // for example >S=O
-      if (dp_origin != beg) {
+      if (dp_origin != beg || d_atropisomerMode) {
         if (atom->getFormalCharge() < 0 &&
             d_mol.getFractionalAtomicNum(atom).denominator() > 1) {
           end = beg->newBondDuplicateChild(nbrIdx, nbr);
@@ -164,7 +167,7 @@ void Digraph::expand(Node *beg) {
         }
       }
     } else if (bond == prev) {  // bond order expansion (backwards)
-      if (dp_origin->getAtom() != nbr) {
+      if (dp_origin->getAtom() != nbr || d_atropisomerMode) {
         for (int i = 0; i < virtual_nodes; ++i) {
           auto end = beg->newBondDuplicateChild(nbrIdx, nbr);
           addEdge(beg, bond, end);
