@@ -13,7 +13,7 @@
 #ifdef RDK_BUILD_YAEHMOP_SUPPORT
 #include <YAeHMOP/EHTTools.h>
 #endif
-#include <iostream>
+#include <limits>
 #include <vector>
 #include <numeric>
 #include <cmath>
@@ -25,6 +25,7 @@
 #include <boost/multiprecision/cpp_int.hpp>
 #include <RDGeneral/BoostEndInclude.h>
 #include <GraphMol/FileParsers/ProximityBonds.h>
+#include <RDGeneral/ControlCHandler.h>
 
 typedef boost::adjacency_list<boost::vecS, boost::vecS, boost::undirectedS>
     Graph;
@@ -179,20 +180,22 @@ void determineConnectivity(RWMol &mol, bool useHueckel, int charge,
         "The RDKit was not compiled with YAeHMOP support");
   }
 #endif
-  auto numAtoms = mol.getNumAtoms();
-  for (unsigned int i = 0; i < numAtoms; i++) {
-    for (unsigned int j = i + 1; j < numAtoms; j++) {
-      mol.removeBond(i, j);
-      mol.getAtomWithIdx(i)->setNoImplicit(true);
-      mol.getAtomWithIdx(j)->setNoImplicit(true);
-    }
+  // remove all bonds
+  mol.beginBatchEdit();
+  for (auto bond : mol.bonds()) {
+    mol.removeBond(bond->getBeginAtomIdx(), bond->getEndAtomIdx());
+  }
+  mol.commitBatchEdit();
+  // set all atoms to noImplicit
+  for (auto atom : mol.atoms()) {
+    atom->setNoImplicit(true);
   }
   if (useHueckel) {
     connectivityHueckel(mol, charge);
   } else if (useVdw) {
     connectivityVdW(mol, covFactor);
   } else {
-    ConnectTheDots(&mol, ctdIGNORE_H_H_CONTACTS);
+    ConnectTheDots(&mol, ctdQUICKREMOVE_H_H_CONTACTS);
   }
 }  // determineConnectivity()
 
@@ -299,9 +302,12 @@ void setAtomicRadicals(RWMol &mol, const std::vector<unsigned int> &valency,
 
 bool checkSaturation(const std::vector<unsigned int> &order,
                      const std::vector<unsigned int> &valency) {
-  std::vector<unsigned int> unsat;
-  getUnsaturated(order, valency, unsat);
-  return unsat.empty();
+  for (unsigned int i = 0; i < order.size(); i++) {
+    if (order[i] > valency[i]) {
+      return false;
+    }
+  }
+  return true;
 }
 
 void setAtomMap(RWMol &mol) {
@@ -364,20 +370,29 @@ void addBondOrdering(RWMol &mol,
 }
 
 void determineBondOrders(RWMol &mol, int charge, bool allowChargedFragments,
-                         bool embedChiral, bool useAtomMap) {
+                         bool embedChiral, bool useAtomMap, size_t iterations) {
+  if (iterations == 0) {
+    // LazyCartesianProduct allows up to uint1024_t::max iterations,
+    // but it's unlikely we'll even get to size_t::max
+    iterations = std::numeric_limits<size_t>::max();
+  }
+
   auto numAtoms = mol.getNumAtoms();
 
   std::vector<std::vector<unsigned int>> conMat(
       numAtoms, std::vector<unsigned int>(numAtoms, 0));
   std::vector<unsigned int> origValency(numAtoms, 0);
-  for (unsigned int i = 0; i < numAtoms; i++) {
-    for (unsigned int j = i + 1; j < numAtoms; j++) {
-      if (mol.getBondBetweenAtoms(i, j)) {
-        conMat[i][j]++;
-        origValency[i]++;
-        origValency[j]++;
-      }
+
+  for (const auto bond : mol.bonds()) {
+    auto i = bond->getBeginAtomIdx();
+    auto j = bond->getEndAtomIdx();
+    // conMat is symmetric
+    if (i > j) {
+      std::swap(i, j);
     }
+    conMat[i][j]++;
+    origValency[i]++;
+    origValency[j]++;
   }
 
   std::vector<std::vector<unsigned int>> best(conMat);
@@ -390,8 +405,20 @@ void determineBondOrders(RWMol &mol, int charge, bool allowChargedFragments,
   bool chargeValid = false;
   bool saturationValid = false;
 
+  ControlCHandler::reset();
+
   while (!valenceCombos.atEnd()) {
+    if (--iterations == 0) {
+      throw MaxFindBondOrdersItersExceeded();
+    }
+    if (ControlCHandler::getGotSignal()) {
+      BOOST_LOG(rdWarningLog)
+          << "Interrupted, cancelling determine Bond Orders" << std::endl;
+      return;
+    }
+
     auto order = valenceCombos.next();
+
     std::vector<unsigned int> unsat;
     getUnsaturated(order, origValency, unsat);
     // checks whether the atomic connectivity is valid for the current set of
@@ -438,7 +465,7 @@ void determineBondOrders(RWMol &mol, int charge, bool allowChargedFragments,
         }
       }
 
-    } while (newBonds == true);
+    } while (newBonds);
 
     valencyValid = checkValency(order, valency);
     chargeValid = checkCharge(mol, valency, charge);
@@ -451,7 +478,6 @@ void determineBondOrders(RWMol &mol, int charge, bool allowChargedFragments,
         return;
       } else {
         int sum = std::accumulate(valency.begin(), valency.end(), 0);
-        ;
         if (sum > bestSum) {
           best = ordMat;
           bestSum = sum;
@@ -468,13 +494,13 @@ void determineBondOrders(RWMol &mol, int charge, bool allowChargedFragments,
 
 void determineBonds(RWMol &mol, bool useHueckel, int charge, double covFactor,
                     bool allowChargedFragments, bool embedChiral,
-                    bool useAtomMap, bool useVdw) {
+                    bool useAtomMap, bool useVdw, size_t maxIterations) {
   if (mol.getNumAtoms() <= 1) {
     return;
   }
   determineConnectivity(mol, useHueckel, charge, covFactor, useVdw);
   determineBondOrders(mol, charge, allowChargedFragments, embedChiral,
-                      useAtomMap);
+                      useAtomMap, maxIterations);
 }  // determineBonds()
 
 }  // namespace RDKit
