@@ -14,6 +14,15 @@
 #include <GraphMol/RDKitBase.h>
 
 namespace RDKit {
+
+class RDKIT_DETERMINEBONDS_EXPORT MaxFindBondOrdersItersExceeded
+    : public std::runtime_error {
+ public:
+  explicit MaxFindBondOrdersItersExceeded()
+      : std::runtime_error(
+            "Max Iterations Exceeded in Determine Bond Orders"){};
+};
+
 // ! assigns atomic connectivity to a molecule using atomic coordinates,
 // disregarding pre-existing bonds
 /*!
@@ -56,10 +65,15 @@ RDKIT_DETERMINEBONDS_EXPORT void determineConnectivity(RWMol &mol,
    sanitizeMol() when this is true
    \param useAtomMap (optional) if this is \c
    true, an atom map will be created for the molecule
+   \param maxIterations (optional) maximum number of iterations to run in the
+   bond order detection algorithm, after which a MaxFindBondOrdersItersExceeded
+   exception will be thrown. Defaults to 0 (no limit)
+
+   \throws MaxFindBondOrdersItersExceeded
  */
 RDKIT_DETERMINEBONDS_EXPORT void determineBondOrders(
     RWMol &mol, int charge = 0, bool allowChargedFragments = true,
-    bool embedChiral = true, bool useAtomMap = false);
+    bool embedChiral = true, bool useAtomMap = false, size_t maxIterations = 0);
 
 // ! assigns atomic connectivity to a molecule using atomic coordinates,
 // disregarding pre-existing bonds; it is recommended to sanitize the molecule
@@ -86,11 +100,16 @@ RDKIT_DETERMINEBONDS_EXPORT void determineBondOrders(
    for the molecule
    \param useVdw (optional) if this is  \c false, the connect-the-dots method
     will be used instead of the van der Waals method
+   \param maxIterations (optional) maximum number of iterations to run in the
+   bond order detection algorithm, after which a MaxFindBondOrdersItersExceeded
+   exception will be thrown. Defaults to 0 (no limit)
+
+   \throws MaxFindBondOrdersItersExceeded
  */
 RDKIT_DETERMINEBONDS_EXPORT void determineBonds(
     RWMol &mol, bool useHueckel = false, int charge = 0, double covFactor = 1.3,
     bool allowChargedFragments = true, bool embedChiral = true,
-    bool useAtomMap = false, bool useVdw = false);
+    bool useAtomMap = false, bool useVdw = false, size_t maxIterations = 0);
 
 }  // namespace RDKit
 
