@@ -7,10 +7,12 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
+#include <string>
 
 #include <RDBoost/python.h>
 #include <GraphMol/GraphMol.h>
 #include <RDBoost/Wrap.h>
+#include <RDGeneral/ControlCHandler.h>
 
 #include <GraphMol/DetermineBonds/DetermineBonds.h>
 
@@ -18,6 +20,7 @@ namespace python = boost::python;
 using namespace RDKit;
 
 namespace {
+
 void determineConnectivityHelper(ROMol &mol, bool useHueckel, int charge,
                                  double covFactor, bool useVdw) {
   auto &wmol = static_cast<RWMol &>(mol);
@@ -25,17 +28,26 @@ void determineConnectivityHelper(ROMol &mol, bool useHueckel, int charge,
 }
 void determineBondOrdersHelper(ROMol &mol, int charge,
                                bool allowChargedFragments, bool embedChiral,
-                               bool useAtomMap) {
+                               bool useAtomMap, size_t maxIterations) {
   auto &wmol = static_cast<RWMol &>(mol);
   determineBondOrders(wmol, charge, allowChargedFragments, embedChiral,
-                      useAtomMap);
+                      useAtomMap, maxIterations);
+  if (ControlCHandler::getGotSignal()) {
+    PyErr_SetString(PyExc_KeyboardInterrupt, "Determine Bond Orders cancelled");
+    boost::python::throw_error_already_set();
+  }
 }
 void determineBondsHelper(ROMol &mol, bool useHueckel, int charge,
                           double covFactor, bool allowChargedFragments,
-                          bool embedChiral, bool useAtomMap, bool useVdw) {
+                          bool embedChiral, bool useAtomMap, bool useVdw,
+                          size_t maxIterations) {
   auto &wmol = static_cast<RWMol &>(mol);
   determineBonds(wmol, useHueckel, charge, covFactor, allowChargedFragments,
-                 embedChiral, useAtomMap, useVdw);
+                 embedChiral, useAtomMap, useVdw, maxIterations);
+  if (ControlCHandler::getGotSignal()) {
+    PyErr_SetString(PyExc_KeyboardInterrupt, "Determine Bond Orders cancelled");
+    boost::python::throw_error_already_set();
+  }
 }
 bool hueckelSupportEnabled() {
 #ifdef RDK_BUILD_YAEHMOP_SUPPORT
@@ -46,19 +58,27 @@ bool hueckelSupportEnabled() {
 }
 }  // namespace
 
+void rdMaxFindBondOrdersItersExceededTranslator(
+    const RDKit::MaxFindBondOrdersItersExceeded &x) {
+  PyErr_SetString(PyExc_RuntimeError, x.what());
+}
+
 BOOST_PYTHON_MODULE(rdDetermineBonds) {
   python::scope().attr("__doc__") =
       "Module containing a C++ implementation of the xyz2mol algorithm. This is based on xyz2mol: https://github.com/jensengroup/xyz2mol";
 
+  python::register_exception_translator<RDKit::MaxFindBondOrdersItersExceeded>(
+      &rdMaxFindBondOrdersItersExceededTranslator);
+
   std::string docs;
   docs =
-      R"DOC(Assigns atomic connectivity to a molecule using atomic coordinates, 
+      R"DOC(Assigns atomic connectivity to a molecule using atomic coordinates,
 disregarding pre-existing bonds
 
 Args:
    mol : the molecule of interest; it must have a 3D conformer
    useHueckel : (optional) if this is  \c true, extended Hueckel theory
-       will be used to determine connectivity rather than the van der Waals 
+       will be used to determine connectivity rather than the van der Waals
        or connect-the-dots methods
    charge : (optional) the charge of the molecule; it must be provided if
        the Hueckel method is used and charge is non-zero
@@ -74,7 +94,7 @@ Args:
               docs.c_str());
 
   docs =
-      R"DOC(Assigns atomic connectivity to a molecule using atomic coordinates, 
+      R"DOC(Assigns atomic connectivity to a molecule using atomic coordinates,
 disregarding pre-existing bonds
 
 Args:
@@ -87,24 +107,28 @@ Args:
    embedChiral : (optional) if this is true,
       chirality information will be embedded into the molecule; the function calls
       sanitizeMol() when this is true
-   useAtomMap : (optional) if this is true, an atom map will be created for the 
+   useAtomMap : (optional) if this is true, an atom map will be created for the
       molecule
+   maxIterations: (optional) maximum number of iterations to run in the bond order
+   determination algorithm, after which a MaxFindBondOrdersItersExceeded
+   exception will be thrown. Defaults to 0 (no limit)
 )DOC";
   python::def(
       "DetermineBondOrders", &determineBondOrdersHelper,
       (python::arg("mol"), python::arg("charge") = 0,
        python::arg("allowChargedFragments") = true,
-       python::arg("embedChiral") = true, python::arg("useAtomMap") = false),
+       python::arg("embedChiral") = true, python::arg("useAtomMap") = false,
+       python::arg("maxIterations") = 0),
       docs.c_str());
 
   docs =
-      R"DOC(Assigns atomic connectivity to a molecule using atomic coordinates, 
+      R"DOC(Assigns atomic connectivity to a molecule using atomic coordinates,
 disregarding pre-existing bonds
 
 Args:
    mol : the molecule of interest; it must have a 3D conformer
    useHueckel : (optional) if this is true, extended Hueckel theory
-       will be used to determine connectivity rather than the van der Waals 
+       will be used to determine connectivity rather than the van der Waals
        or connect-the-dots methods
    charge : (optional) the charge of the molecule; it must be provided if
        the Hueckel method is used and charge is non-zero
@@ -116,10 +140,13 @@ Args:
    embedChiral : (optional) if this is true,
       chirality information will be embedded into the molecule; the function calls
       sanitizeMol() when this is true
-   useAtomMap : (optional) if this is true, an atom map will be created for the 
+   useAtomMap : (optional) if this is true, an atom map will be created for the
       molecule
    useVdw: (optional) if this is false, the connect-the-dots method
        will be used instead of the van der Waals method
+   maxIterations: (optional) maximum number of iterations to run in the bond order
+   determination algorithm, after which a MaxFindBondOrdersItersExceeded
+   exception will be thrown. Defaults to 0 (no limit)
 )DOC";
   python::def(
       "DetermineBonds", &determineBondsHelper,
@@ -127,7 +154,7 @@ Args:
        python::arg("charge") = 0, python::arg("covFactor") = 1.3,
        python ::arg("allowChargedFragments") = true,
        python::arg("embedChiral") = true, python::arg("useAtomMap") = false,
-       python::arg("useVdw") = false),
+       python::arg("useVdw") = false, python::arg("maxIterations") = 0),
       docs.c_str());
   python::def("hueckelEnabled", &hueckelSupportEnabled,
               "whether or not the RDKit was compiled with YAeHMOP support");
