@@ -8,6 +8,10 @@
 //  of the RDKit source tree.
 //
 #include "CDXMLParser.h"
+#include <GraphMol/RDKitBase.h>
+#include <GraphMol/RWMol.h>
+
+#ifndef RDK_BUILD_CHEMDRAW_SUPPORT
 #include <boost/property_tree/xml_parser.hpp>
 #include <boost/property_tree/ptree.hpp>
 #include <GraphMol/MolOps.h>
@@ -29,7 +33,6 @@ namespace RDKit {
 namespace {
 const std::string NEEDS_FUSE("CDXML_NEEDS_FUSE");
 const std::string CDXML_FRAG_ID("CDXML_FRAG_ID");
-const std::string CDXML_GROUP_ID("CDXML_GROUP_ID");
 const std::string FUSE_LABEL("CDXML_NODE_ID");
 const std::string CDX_SCHEME_ID("CDX_SCHEME_ID");
 const std::string CDX_STEP_ID("CDX_STEP_ID");
@@ -39,7 +42,6 @@ const std::string CDX_AGENT_ID("CDX_AGENT_ID");
 const std::string CDX_ATOM_POS("CDX_ATOM_POS");
 const std::string CDX_ATOM_ID("_CDX_ATOM_ID");
 const std::string CDX_BOND_ID("_CDX_BOND_ID");
-const std::string CDX_BOND_ORDERING("CDXML_BOND_ORDERING");
 
 constexpr double RDKIT_DEPICT_BONDLENGTH = 1.5;
 
@@ -454,7 +456,7 @@ bool parse_fragment(RWMol &mol, ptree &frag,
         ids[bond.end]->setIsAromatic(true);
         ids[bond.start]->setIsAromatic(true);
       }
-      bnd->setProp("CDX_BOND_ID", bond.bond_id);
+      bnd->setProp(CDX_BOND_ID, bond.bond_id);
       if (bond.display == "WedgeBegin") {
         bnd->setBondDir(Bond::BondDir::BEGINWEDGE);
         bnd->setProp(common_properties::_MolFileBondCfg, 1);
@@ -705,10 +707,15 @@ void visit_children(
 
 namespace v2 {
 namespace CDXMLParser {
+bool hasChemDrawCDXSupport() { return false; }
 
 std::vector<std::unique_ptr<RWMol>> MolsFromCDXMLDataStream(
     std::istream &inStream, const CDXMLParserParams &params) {
   // populate tree structure pt
+  if (params.format == CDXMLFormat::CDX) {
+    throw FileParseException("Full ChemDraw support is not enabled, cannot parse CDX files");
+  }
+  
   using boost::property_tree::ptree;
   ptree pt;
   try {
@@ -827,10 +834,77 @@ std::vector<std::unique_ptr<RWMol>> MolsFromCDXMLFile(
 }
 
 std::vector<std::unique_ptr<RWMol>> MolsFromCDXML(
-    const std::string &cdxml, const CDXMLParserParams &params) {
+
+						  const std::string &cdxml, const CDXMLParserParams &params) {
+ 
   std::stringstream iss(cdxml);
   return MolsFromCDXMLDataStream(iss, params);
 }
 }  // namespace CDXMLParser
 }  // namespace v2
 }  // namespace RDKit
+#else
+#include <ChemDraw/chemdraw.h>
+#include <RDGeneral/BadFileException.h>
+#include <filesystem> // For std::filesystem::path
+#include <algorithm>  // For std::transform
+#include <cctype>     // For std::tolower
+
+namespace RDKit{
+
+
+namespace v2 {
+namespace CDXMLParser {
+bool hasChemDrawCDXSupport() { return true; }
+  
+std::vector<std::unique_ptr<RWMol>> MolsFromCDXMLDataStream(
+    std::istream &inStream, const CDXMLParserParams &params) {
+  // populate tree structure pt
+  ChemDrawParserParams chemdraw_params;
+  chemdraw_params.sanitize = params.sanitize;
+  chemdraw_params.removeHs = params.removeHs;
+  switch(params.format) {
+  case CDXMLFormat::CDX: {
+    chemdraw_params.format = CDXFormat::CDX;
+    break;
+  }
+  case CDXMLFormat::CDXML: {
+    chemdraw_params.format = CDXFormat::CDXML; break;
+  }
+  case CDXMLFormat::Auto:
+    {
+      chemdraw_params.format = CDXFormat::AUTO; break;
+    }
+  }
+
+  return MolsFromChemDrawDataStream(inStream, chemdraw_params);
+}
+
+std::vector<std::unique_ptr<RWMol>> MolsFromCDXMLFile(
+    const std::string &fileName, const CDXMLParserParams &params) {
+  std::ifstream ifs(fileName,  std::ios::binary);
+  if (!ifs || ifs.bad()) {
+    std::ostringstream errout;
+    errout << "Bad inxput file " << fileName;
+    throw BadFileException(errout.str());
+  }
+
+  try {
+    return MolsFromCDXMLDataStream(ifs, params);
+  } catch (const std::exception &ex) {
+    std::ostringstream errout;
+    errout << "Bad input file " << fileName << " " << ex.what();
+
+    throw FileParseException(errout.str());
+  }
+}
+
+std::vector<std::unique_ptr<RWMol>> MolsFromCDXML(
+    const std::string &cdxml, const CDXMLParserParams &params) {
+  std::stringstream iss(cdxml);
+  return MolsFromCDXMLDataStream(iss, params);
+}
+}
+}
+}
+#endif
