@@ -38,6 +38,9 @@ namespace v2 {
 namespace FileParsers {
 namespace {
 
+// Flag for parsing chirality labels
+enum class [[nodiscard]] ChiralityLabelStatus{VALID, INVALID};
+
 class PDBInfo {
  public:
   PDBInfo(const mae::IndexedBlock &atom_block) {
@@ -128,16 +131,19 @@ bool streamIsGoodOrExhausted(std::istream *stream) {
   return stream->good() || (stream->eof() && stream->fail() && !stream->bad());
 }
 
-void parseChiralityLabel(RWMol &mol, const std::string &stereo_prop) {
+ChiralityLabelStatus parseChiralityLabel(RWMol &mol,
+                                         const std::string &stereo_prop) {
   boost::char_separator<char> sep{"_"};
   boost::tokenizer<boost::char_separator<char>> tokenizer{stereo_prop, sep};
 
   auto tItr = tokenizer.begin();
 
   const int chiral_idx = FileParserUtils::toInt(*tItr) - 1;
-  Atom *chiral_atom = mol.getAtomWithIdx(chiral_idx);
-  CHECK_INVARIANT(chiral_atom != nullptr, "bad prop value");
+  if (chiral_idx < 0 || chiral_idx >= static_cast<int>(mol.getNumAtoms())) {
+    return ChiralityLabelStatus::INVALID;
+  }
 
+  auto chiral_atom = mol.getAtomWithIdx(chiral_idx);
   unsigned nSwaps = 2;
   const char rotation_direction = (++tItr)->back();
   switch (rotation_direction) {
@@ -148,21 +154,24 @@ void parseChiralityLabel(RWMol &mol, const std::string &stereo_prop) {
       nSwaps = 1;
       break;
     case '?':  // Undefined
-      return;
+      return ChiralityLabelStatus::VALID;
     default:
-      break;
+      return ChiralityLabelStatus::INVALID;
   }
-  CHECK_INVARIANT(nSwaps < 2, "bad prop value");
 
   INT_LIST bond_indexes;
   for (++tItr; tItr != tokenizer.end(); ++tItr) {
     const int nbr_idx = FileParserUtils::toInt(*tItr) - 1;
-    const Bond *bnd = mol.getBondBetweenAtoms(chiral_idx, nbr_idx);
-    CHECK_INVARIANT(bnd, "bad chiral bond");
-    bond_indexes.push_back(bnd->getIdx());
+    if (auto bond = mol.getBondBetweenAtoms(chiral_idx, nbr_idx); bond) {
+      bond_indexes.push_back(bond->getIdx());
+    } else {
+      return ChiralityLabelStatus::INVALID;
+    }
+  }
+
+  if (bond_indexes.size() != chiral_atom->getDegree()) {
+    return ChiralityLabelStatus::INVALID;
   }
-  CHECK_INVARIANT(bond_indexes.size() == chiral_atom->getDegree(),
-                  "bad prop value");
 
   nSwaps += chiral_atom->getPerturbationOrder(bond_indexes);
   switch (nSwaps % 2) {
@@ -173,6 +182,7 @@ void parseChiralityLabel(RWMol &mol, const std::string &stereo_prop) {
       chiral_atom->setChiralTag(Atom::CHI_TETRAHEDRAL_CCW);
       break;
   }
+  return ChiralityLabelStatus::VALID;
 }
 
 void parseStereoBondLabel(RWMol &mol, const std::string &stereo_prop) {
@@ -231,23 +241,29 @@ bool is_ignored_property(const std::string &prop) {
 
 //! Copy over the structure properties, including stereochemistry.
 void set_mol_properties(RWMol &mol, const mae::Block &ct_block) {
-  for (const auto &prop : ct_block.getProperties<std::string>()) {
-    if (is_ignored_property(prop.first)) {
+  for (const auto &[prop_name, value] : ct_block.getProperties<std::string>()) {
+    if (is_ignored_property(prop_name)) {
       continue;
     }
 
-    if (prop.first == mae::CT_TITLE) {
-      mol.setProp(common_properties::_Name, prop.second);
-    } else if (prop.first.find(mae::CT_CHIRALITY_PROP_PREFIX) == 0 ||
-               prop.first.find(mae::CT_PSEUDOCHIRALITY_PROP_PREFIX) == 0) {
-      parseChiralityLabel(mol, prop.second);
-    } else if (prop.first.find(mae::CT_EZ_PROP_PREFIX) == 0) {
-      parseStereoBondLabel(mol, prop.second);
+    if (prop_name == mae::CT_TITLE) {
+      mol.setProp(common_properties::_Name, value);
+    } else if (prop_name.find(mae::CT_CHIRALITY_PROP_PREFIX) == 0 ||
+               prop_name.find(mae::CT_PSEUDOCHIRALITY_PROP_PREFIX) == 0) {
+      // Not stopping if we see a "bad" label since the log can be helpful
+      if (parseChiralityLabel(mol, value) == ChiralityLabelStatus::INVALID) {
+        BOOST_LOG(rdWarningLog)
+            << "Ignoring invalid chirality label: '" << value << "'\n";
+      }
+
+    } else if (prop_name.find(mae::CT_EZ_PROP_PREFIX) == 0) {
+      parseStereoBondLabel(mol, value);
     } else {
-      auto propName = strip_prefix_from_mae_property(prop.first);
-      mol.setProp(propName, prop.second);
+      auto propName = strip_prefix_from_mae_property(prop_name);
+      mol.setProp(propName, value);
     }
   }
+
   for (const auto &prop : ct_block.getProperties<double>()) {
     if (is_ignored_property(prop.first)) {
       continue;
@@ -467,7 +483,7 @@ void build_mol(RWMol &mol, mae::Block &structure_block, bool sanitize,
       unsigned int failedOp = 0;
       MolOps::sanitizeMol(mol, failedOp, MolOps::SANITIZE_CLEANUP);
       MolOps::detectBondStereochemistry(mol);
-      MolOps::removeHs(mol, false, false);
+      MolOps::removeHs(mol);
     } else {
       MolOps::sanitizeMol(mol);
       MolOps::detectBondStereochemistry(mol, replaceExistingTags);
