@@ -15,19 +15,26 @@
 
 namespace RDKit {
 
-std::string MolToXYZBlock(const ROMol& mol, int confId) {
+std::string MolToXYZBlock(const ROMol &mol, int confId,
+                          unsigned int precision) {
   if (!mol.getNumConformers()) {
     BOOST_LOG(rdErrorLog)
         << "Cannot write molecules with no conformers to XYZ block\n";
     return "";
   }
 
-  const auto& conf = mol.getConformer(confId);
+  const auto &conf = mol.getConformer(confId);
   const unsigned int nAtoms = mol.getNumAtoms();
 
   std::stringstream ss;
   ss << nAtoms << '\n';
 
+  unsigned fieldWidth = 5 + precision;
+  std::stringstream formatString;
+  formatString << "%-3s %" << fieldWidth << "." << precision << "f %"
+               << fieldWidth << "." << precision << "f %" << fieldWidth << "."
+               << precision << "f\n";
+
   std::string name;
   if (mol.getPropIfPresent(common_properties::_Name, name)) {
     ss << name.substr(0, name.find_first_of('\n'));
@@ -35,22 +42,22 @@ std::string MolToXYZBlock(const ROMol& mol, int confId) {
   ss << '\n';
 
   for (unsigned int i = 0; i < nAtoms; i++) {
-    const auto& symbol = mol.getAtomWithIdx(i)->getSymbol();
-    const auto& pos = conf.getAtomPos(i);
-    ss << boost::format{"%-3s %11.6f %11.6f %11.6f\n"} % symbol % pos.x %
-              pos.y % pos.z;
+    const auto &symbol = mol.getAtomWithIdx(i)->getSymbol();
+    const auto &pos = conf.getAtomPos(i);
+    ss << boost::format{formatString.str()} % symbol % pos.x % pos.y % pos.z;
   }
   return ss.str();
 }
 
-void MolToXYZFile(const ROMol& mol, const std::string& fName, int confId) {
+void MolToXYZFile(const ROMol &mol, const std::string &fName, int confId,
+                  unsigned int precision) {
   std::ofstream outStream(fName);
   if (!outStream) {
     std::ostringstream errout;
     errout << "Bad output file " << fName;
     throw BadFileException(errout.str());
   }
-  outStream << MolToXYZBlock(mol, confId);
+  outStream << MolToXYZBlock(mol, confId, precision);
 }
 
 }  // namespace RDKit
