@@ -1,6 +1,6 @@
 #include <RDGeneral/test.h>
-#include <stdlib.h>
-#include <stdio.h>
+#include <cstdlib>
+#include <cstdio>
 
 #include <GraphMol/GraphMol.h>
 #include <GraphMol/RDKitBase.h>
