@@ -115,8 +115,8 @@ TEST_CASE("MaeMolSupplier") {
     std::string fName = getenv("RDBASE");
     fName += "/Code/GraphMol/FileParsers/test_data/props_test.mae";
 
-    MaeMolSupplier maesup(fName);
-    std::unique_ptr<ROMol> nmol(maesup.next());
+    FileParsers::MaeMolSupplier maesup(fName);
+    auto nmol(maesup.next());
     TEST_ASSERT(nmol);
   }
 }
@@ -171,10 +171,10 @@ TEST_CASE("TestParsingInvalidChiralityLabelsWithMaeMolSupplier") {
       (boost::format(maeblock_template) % invalid_chirality_label).str();
 
   auto iss = std::make_unique<std::istringstream>(maeblock);
-  constexpr bool sanitize = false;
   constexpr bool takeOwnership = true;
+  constexpr FileParsers::MaeMolSupplierParams params{.sanitize = false};
 
-  MaeMolSupplier suppl(iss.release(), takeOwnership, sanitize);
+  FileParsers::MaeMolSupplier suppl(iss.release(), takeOwnership, params);
   auto mol = suppl.next();
 
   REQUIRE(mol);
