@@ -45,8 +45,8 @@ RDKIT_FILTERCATALOG_EXPORT const FilterCatalog &GetFunctionalGroupHierarchy();
     /param normalized If set to true, return the flattened hierarchy
                       with lower case labels.  [default false]
 */
-RDKIT_FILTERCATALOG_EXPORT const std::map<std::string, ROMOL_SPTR>
-    &GetFlattenedFunctionalGroupHierarchy(bool normalized = false);
+RDKIT_FILTERCATALOG_EXPORT const std::map<std::string, ROMOL_SPTR> &
+GetFlattenedFunctionalGroupHierarchy(bool normalized = false);
 }  // namespace RDKit
 
 #endif
