@@ -7,6 +7,7 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
 #include <RDGeneral/RDLog.h>
 #include <GraphMol/RDKitBase.h>
@@ -2453,10 +2454,11 @@ void testAtomPairFPDifference() {
       const auto &fpFromFreeFuncPair = fpFromFreeFuncAsVectOfPairs.at(i);
       const auto &fpFromGeneratorPair = fpFromGeneratorAsVectOfPairs.at(i);
       if (fpFromFreeFuncPair != fpFromGeneratorPair) {
-        BOOST_LOG(rdErrorLog) << "fpFromFreeFuncPair (" << fpFromFreeFuncPair.first << ", "
-                  << fpFromFreeFuncPair.second << ")"
-                  << "\nfpFromGeneratorPair (" << fpFromGeneratorPair.first
-                  << ", " << fpFromGeneratorPair.second << ")" << std::endl;
+        BOOST_LOG(rdErrorLog)
+            << "fpFromFreeFuncPair (" << fpFromFreeFuncPair.first << ", "
+            << fpFromFreeFuncPair.second << ")"
+            << "\nfpFromGeneratorPair (" << fpFromGeneratorPair.first << ", "
+            << fpFromGeneratorPair.second << ")" << std::endl;
       }
     }
   }
