@@ -1,7 +1,5 @@
 //
-//  Copyright (C) 2013-2018 Paolo Tosco
-//
-//  Copyright (C) 2004-2006 Rational Discovery LLC
+//  Copyright (C) 2013-2022 Paolo Tosco and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -21,7 +19,7 @@
 #include <mutex>
 #endif
 #include <boost/noncopyable.hpp>
-#include <boost/tuple/tuple.hpp>
+#include <tuple>
 #include <cstdint>
 
 namespace ForceFields {
