@@ -469,27 +469,6 @@ void addNonbonded(const ROMol &mol, int confId, const AtomicParamVect &params,
   }
 }
 
-#if 0
-      // ------------------------------------------------------------------------
-      //
-      //
-      //
-      // ------------------------------------------------------------------------
-      bool okToIncludeTorsion(const ROMol &mol,const Bond *bond,
-                              int idx1,int idx2,int idx3,int idx4){
-        bool res=true;
-        RingInfo *rings=mol.getRingInfo();
-        // having torsions in small rings makes the solver unstable
-        // and tends to yield poor-quality geometries, so filter those out:
-        if(rings->isBondInRingOfSize(bond->getIdx(),3)){
-          res = false;
-        }// else if(rings->isBondInRingOfSize(bond->getIdx(),4)){
-         // res = false;
-        //}
-        return res;
-      }
-#endif
-
 const std::string DefaultTorsionBondSmarts::ds_string =
     "[!$(*#*)&!D1]~[!$(*#*)&!D1]";
 boost::scoped_ptr<const ROMol> DefaultTorsionBondSmarts::ds_instance;
