@@ -40,11 +40,10 @@ namespace UFF {
 inline std::pair<int, double> UFFOptimizeMolecule(
     ROMol &mol, int maxIters = 1000, double vdwThresh = 10.0, int confId = -1,
     bool ignoreInterfragInteractions = true) {
-  ForceFields::ForceField *ff = UFF::constructForceField(
-      mol, vdwThresh, confId, ignoreInterfragInteractions);
+  std::unique_ptr<ForceFields::ForceField> ff(UFF::constructForceField(
+      mol, vdwThresh, confId, ignoreInterfragInteractions));
   std::pair<int, double> res =
       ForceFieldsHelper::OptimizeMolecule(*ff, maxIters);
-  delete ff;
   return res;
 }
 
@@ -68,14 +67,13 @@ inline std::pair<int, double> UFFOptimizeMolecule(
 
 */
 inline void UFFOptimizeMoleculeConfs(ROMol &mol,
-                              std::vector<std::pair<int, double>> &res,
-                              int numThreads = 1, int maxIters = 1000,
-                              double vdwThresh = 10.0,
-                              bool ignoreInterfragInteractions = true) {
-  ForceFields::ForceField *ff =
-      UFF::constructForceField(mol, vdwThresh, -1, ignoreInterfragInteractions);
+                                     std::vector<std::pair<int, double>> &res,
+                                     int numThreads = 1, int maxIters = 1000,
+                                     double vdwThresh = 10.0,
+                                     bool ignoreInterfragInteractions = true) {
+  std::unique_ptr<ForceFields::ForceField> ff(UFF::constructForceField(
+      mol, vdwThresh, -1, ignoreInterfragInteractions));
   ForceFieldsHelper::OptimizeMoleculeConfs(mol, *ff, res, numThreads, maxIters);
-  delete ff;
 }
 }  // end of namespace UFF
 }  // end of namespace RDKit
