@@ -172,12 +172,12 @@ M  END
 }
 
 namespace {
-bool no_match(const ROMol &mol, const std::vector<unsigned int> &ids) {
+bool no_match(const ROMol &mol, const std::span<const unsigned int> ids) {
   RDUNUSED_PARAM(mol);
   RDUNUSED_PARAM(ids);
   return false;
 }
-bool always_match(const ROMol &mol, const std::vector<unsigned int> &ids) {
+bool always_match(const ROMol &mol, const std::span<const unsigned int> ids) {
   RDUNUSED_PARAM(mol);
   RDUNUSED_PARAM(ids);
   return true;
