@@ -172,6 +172,9 @@ class MarvinCMLReader {
           query->setProp(common_properties::molFileAlias, marvinAtom->mrvAlias);
         }
         query->setQuery(makeAtomNullQuery());
+        query->setIsotope(marvinAtom->rgroupRef);
+        query->setProp(common_properties::_MolFileRLabel,
+                       static_cast<unsigned int>(marvinAtom->rgroupRef));
       }
 
       else if (symb.size() <= 2) {
