@@ -866,6 +866,70 @@ class MrvTests {
     BOOST_LOG(rdInfoLog) << "done" << std::endl;
   }
 
+  void testMarvinRgroupError() {
+    BOOST_LOG(rdInfoLog) << "testing marvin Rgroup error" << std::endl;
+    const auto molb = R"CTAB( 
+  -INDIGO-06252516172D
+
+  2  1  0  0  0  0  0  0  0  0999 V2000
+    9.9900   -7.1250    0.0000 R#  0  0  0  0  0  0  0  0  0  0  0  0
+    8.9900   -7.1250    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0
+  1  2  1  0  0  0  0
+M  RGP  1   1   1
+M  END
+    )CTAB";
+    std::unique_ptr<ROMol> mol = v2::FileParsers::MolFromMolBlock(molb);
+
+    SmilesWriteParams ps;
+    ps.canonical = false;
+
+    std::string smilesOut = MolToSmiles(*mol, ps);
+    std::string cxSmilesOut = MolToCXSmiles(*mol, ps);
+
+    auto outMolStr = MolToMrvBlock(*mol, true, -1, true, false);
+
+    std::unique_ptr<ROMol> mol2 =
+        RDKit::v2::MarvinParser::MolFromMrvBlock(outMolStr);
+
+    std::string smilesOut2 = MolToSmiles(*mol2, ps);
+    std::string cxSmilesOut2 = MolToCXSmiles(*mol2, ps);
+
+    TEST_ASSERT(smilesOut == smilesOut2);
+    TEST_ASSERT(cxSmilesOut == cxSmilesOut2);
+  }
+
+  void testMarvinRgroupError2() {
+    BOOST_LOG(rdInfoLog)
+        << "testing marvin Rgroup error starting with MRV block" << std::endl;
+    const auto mrvb =
+        R"CTAB(<cml xmlns="http://www.chemaxon.com" version="ChemAxon file format v20.20.0, generated by vunknown" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.chemaxon.com http://www.chemaxon.com/marvin/schema/mrvSchema_20_20_0.xsd">
+    <MDocument>
+        <MChemicalStruct>
+            <molecule molID="m1">
+                <atomArray>
+                    <atom id="a1" elementType="R" x2="-0.666834670524129" y2="-0.38500847027952034" rgroupRef="1"/>
+                    <atom id="a2" elementType="O" x2="0.666834670524129" y2="0.38500847027952023" lonePair="2"/>
+                </atomArray>
+                <bondArray>
+                    <bond id="b1" atomRefs2="a1 a2" order="1"/>
+                </bondArray>
+            </molecule>
+        </MChemicalStruct>
+    </MDocument>
+</cml>)CTAB";
+
+    std::unique_ptr<ROMol> mol = v2::MarvinParser::MolFromMrvBlock(mrvb);
+    std::string tempStr;
+    auto firstAtom = mol->getAtomWithIdx(0);
+
+    TEST_ASSERT(
+        firstAtom->getProp<std::string>(common_properties::dummyLabel) == "R1");
+    TEST_ASSERT(firstAtom->getIsotope() == 1);
+    int iLabel(0);
+    firstAtom->getProp(common_properties::_MolFileRLabel, iLabel);
+    TEST_ASSERT(iLabel == 1);
+  }
+
  public:
   void RunTests() {
     UseLegacyStereoPerceptionFixture useLegacy(false);
@@ -891,6 +955,13 @@ class MrvTests {
       }
     }
 
+    if (testToRun == "" || testToRun == "testMarvinRgroupError") {
+      testMarvinRgroupError();
+    }
+    if (testToRun == "" || testToRun == "testMarvinRgroupError2") {
+      testMarvinRgroupError2();
+    }
+
     // the molecule tests - starting with molfiles/sdf
     if (testToRun == "" || testToRun == "sdfTests") {
       std::list<MolTest> sdfTests{
