@@ -1,22 +1,27 @@
 //
+//  Copyright (C) 2020-2022 David Cosgrove and other RDKit contributors
+//
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
 //  The contents are covered by the terms of the BSD license
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
-// Original author: David Cosgrove (CozChemIx) on 08/05/2020.
+// Original author: David Cosgrove (CozChemIx).
 //
 
 #include <GraphMol/MolDraw2D/DrawTextFTCairo.h>
 
 namespace RDKit {
+namespace MolDraw2D_detail {
 
 // ****************************************************************************
 DrawTextFTCairo::DrawTextFTCairo(double max_fnt_sz, double min_fnt_sz,
                                  const std::string &font_file, cairo_t *dp_cr)
     : DrawTextFT(max_fnt_sz, min_fnt_sz, font_file), dp_cr_(dp_cr) {}
 
+void DrawTextFTCairo::setCairoContext(cairo_t *cr) { dp_cr_ = cr; }
+
 // ****************************************************************************
 double DrawTextFTCairo::extractOutline() {
   cairo_set_source_rgba(dp_cr_, colour().r, colour().g, colour().b, colour().a);
@@ -87,4 +92,5 @@ int DrawTextFTCairo::CubicToFunctionImpl(const FT_Vector *controlOne,
   return 0;
 }
 
+}  // namespace MolDraw2D_detail
 }  // namespace RDKit
