@@ -1,11 +1,13 @@
 //
+//  Copyright (C) 2020-2022 David Cosgrove and other RDKit contributors
+//
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
 //  The contents are covered by the terms of the BSD license
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
-// Original author: David Cosgrove (CozChemIx) on 08/05/2020.
+// Original author: David Cosgrove (CozChemIx).
 //
 
 #ifndef RDKIT_DRAWTEXTFTCAIRO_H
@@ -16,13 +18,19 @@
 #include <GraphMol/MolDraw2D/DrawTextFT.h>
 
 namespace RDKit {
+namespace MolDraw2D_detail {
 
 // ****************************************************************************
 
 class DrawTextFTCairo : public DrawTextFT {
  public:
+  ~DrawTextFTCairo() override = default;
   DrawTextFTCairo(double max_fnt_sz, double min_fnt_sz,
                   const std::string &font_file, cairo_t *dp_cr);
+  DrawTextFTCairo(const DrawTextFTCairo &) = delete;
+  DrawTextFTCairo(DrawTextFTCairo &&) = delete;
+  DrawTextFTCairo &operator=(const DrawTextFTCairo &) = delete;
+  DrawTextFTCairo &operator=(DrawTextFTCairo &&) = delete;
 
   int MoveToFunctionImpl(const FT_Vector *to) override;
   int LineToFunctionImpl(const FT_Vector *to) override;
@@ -31,15 +39,15 @@ class DrawTextFTCairo : public DrawTextFT {
   int CubicToFunctionImpl(const FT_Vector *controlOne,
                           const FT_Vector *controlTwo,
                           const FT_Vector *to) override;
+  void setCairoContext(cairo_t *cr);
 
- protected:
   // adds x_trans_ and y_trans_ to coords returns x advance distance
-  virtual double extractOutline() override;
+  double extractOutline() override;
 
- private:
   cairo_t *dp_cr_;
 };
 
+}  // namespace MolDraw2D_detail
 }  // namespace RDKit
 
 #endif  // RDKIT_DRAWTEXTFTCAIRO_H
