@@ -23,6 +23,8 @@ class QString;
 
 namespace RDKit {
 
+RDKIT_MOLDRAW2DQT_EXPORT extern const char *rdkitQtVersion;
+
 class RDKIT_MOLDRAW2DQT_EXPORT MolDraw2DQt : public MolDraw2D {
  public:
   MolDraw2DQt(int width, int height, QPainter *qp, int panelWidth = -1,
@@ -36,6 +38,10 @@ class RDKIT_MOLDRAW2DQT_EXPORT MolDraw2DQt : public MolDraw2D {
   void drawPolygon(const std::vector<Point2D> &cds,
                    bool rawCoords = false) override;
   void clearDrawing() override;
+  void drawWavyLine(const Point2D &cds1, const Point2D &cds2,
+                    const DrawColour &col1, const DrawColour &col2,
+                    unsigned int nSegments = 16, double vertOffset = 0.05,
+                    bool rawCoords = false) override;
 
  private:
   QPainter *d_qp;
