@@ -1,11 +1,8 @@
 import sys
 import unittest
 
-from rdkit import Chem
-from rdkit import RDConfig
-from rdkit.Chem import AllChem
-from rdkit.Chem import Draw
-from rdkit.Chem import rdDepictor
+from rdkit import Chem, RDConfig
+from rdkit.Chem import AllChem, Draw, rdDepictor
 from rdkit.Chem.Draw import rdMolDraw2DQt
 
 try:
