@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2021 Greg Landrum
+//  Copyright (C) 2021-2025 Greg Landrum and other RDKit contributors
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
 //  The contents are covered by the terms of the BSD license
@@ -458,3 +458,55 @@ M  END
   CHECK(json.find("-0.5347") == std::string::npos);
   CHECK(json.find("-0.5348") != std::string::npos);
 }
+
+TEST_CASE("github #8460: MolToJSON does not handle atropisomers") {
+  SECTION("as reported") {
+    auto m = "C1CC(C)C=1c1c(CC)cccc1C |wU:4.3|"_smiles;
+    REQUIRE(m);
+    CHECK(m->getBondWithIdx(4)->getStereo() == Bond::BondStereo::STEREOATROPCW);
+    auto refSmiles = MolToCXSmiles(*m);
+    auto json = MolInterchange::MolToJSONData(*m);
+    CHECK(json.find("\"stereo\":\"atrop_cw\"") != std::string::npos);
+
+    auto nmols = MolInterchange::JSONDataToMols(json);
+    CHECK(nmols.size() == 1);
+    CHECK(nmols[0]->getBondWithIdx(4)->getStereo() ==
+          Bond::BondStereo::STEREOATROPCW);
+    CHECK(MolToCXSmiles(*nmols[0]) == refSmiles);
+  }
+  SECTION("enhanced stereo") {
+    auto m = "C1CC(C)C=1c1c(CC)cccc1C |wU:4.3,&1:4|"_smiles;
+    REQUIRE(m);
+    CHECK(m->getBondWithIdx(4)->getStereo() == Bond::BondStereo::STEREOATROPCW);
+    CHECK(m->getStereoGroups().size() == 1);
+
+    auto refSmiles = MolToCXSmiles(*m);
+    auto json = MolInterchange::MolToJSONData(*m);
+    CHECK(json.find("\"stereo\":\"atrop_cw\"") != std::string::npos);
+
+    auto nmols = MolInterchange::JSONDataToMols(json);
+    CHECK(nmols.size() == 1);
+    CHECK(nmols[0]->getBondWithIdx(4)->getStereo() ==
+          Bond::BondStereo::STEREOATROPCW);
+    CHECK(nmols[0]->getStereoGroups().size() == 1);
+
+    CHECK(MolToCXSmiles(*nmols[0]) == refSmiles);
+  }
+  SECTION("round trips") {
+    std::vector<std::string> smileses = {
+        "C1CC(C)C=1c1c(CC)cccc1C |wD:4.3|",
+        "C1CC(C)C=1c1c(CC)cccc1C |wD:4.3,&1:4|"
+        "C1CC(C)C=1c1c(CC)cccc1C |wU:4.3,o1:4|",
+        "C1CC(C)C=1c1c(CC)cccc1[C@H](F)Cl |wU:4.3,&1:4,13|"};
+    for (const auto &smi : smileses) {
+      auto m = v2::SmilesParse::MolFromSmiles(smi);
+      REQUIRE(m);
+
+      auto refSmiles = MolToCXSmiles(*m);
+      auto json = MolInterchange::MolToJSONData(*m);
+      auto nmols = MolInterchange::JSONDataToMols(json);
+      CHECK(nmols.size() == 1);
+      CHECK(MolToCXSmiles(*nmols[0]) == refSmiles);
+    }
+  }
+}
\ No newline at end of file
