@@ -151,6 +151,8 @@ RDKIT_MOLSTANDARDIZE_EXPORT void removeFragmentsInPlace(
 RDKIT_MOLSTANDARDIZE_EXPORT RWMol *canonicalTautomer(
     const RWMol *mol,
     const CleanupParameters &params = defaultCleanupParameters);
+RDKIT_MOLSTANDARDIZE_EXPORT void canonicalTautomerInPlace(
+    RWMol &mol, const CleanupParameters &params = defaultCleanupParameters);
 
 //! Returns the tautomer parent of a given molecule. The fragment parent is the
 /// standardized canonical tautomer of the molecule
@@ -158,6 +160,13 @@ RDKIT_MOLSTANDARDIZE_EXPORT RWMol *tautomerParent(
     const RWMol &mol,
     const CleanupParameters &params = defaultCleanupParameters,
     bool skipStandardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void tautomerParentInPlace(
+    RWMol &mol, const CleanupParameters &params = defaultCleanupParameters,
+    bool skipStandardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void tautomerParentInPlace(
+    std::vector<RWMol *> &mols, int numThreads = 1,
+    const CleanupParameters &params = defaultCleanupParameters,
+    bool skipStandardize = false);
 
 //! Returns the fragment parent of a given molecule. The fragment parent is the
 /// largest organic covalent unit in the molecule.
@@ -165,18 +174,39 @@ RDKIT_MOLSTANDARDIZE_EXPORT RWMol *fragmentParent(
     const RWMol &mol,
     const CleanupParameters &params = defaultCleanupParameters,
     bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void fragmentParentInPlace(
+    RWMol &mol, const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void fragmentParentInPlace(
+    std::vector<RWMol *> &mols, int numThreads = 1,
+    const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
 
 //! calls removeStereochemistry() on the given molecule
 RDKIT_MOLSTANDARDIZE_EXPORT RWMol *stereoParent(
     const RWMol &mol,
     const CleanupParameters &params = defaultCleanupParameters,
     bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void stereoParentInPlace(
+    RWMol &mol, const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void stereoParentInPlace(
+    std::vector<RWMol *> &mols, int numThreads = 1,
+    const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
 
 //! removes all isotopes specifications from the given molecule
 RDKIT_MOLSTANDARDIZE_EXPORT RWMol *isotopeParent(
     const RWMol &mol,
     const CleanupParameters &params = defaultCleanupParameters,
     bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void isotopeParentInPlace(
+    RWMol &mol, const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void isotopeParentInPlace(
+    std::vector<RWMol *> &mols, int numThreads = 1,
+    const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
 
 //! Returns the charge parent of a given molecule. The charge parent is the
 //! uncharged version of the fragment parent.
@@ -184,13 +214,28 @@ RDKIT_MOLSTANDARDIZE_EXPORT RWMol *chargeParent(
     const RWMol &mol,
     const CleanupParameters &params = defaultCleanupParameters,
     bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void chargeParentInPlace(
+    RWMol &mol, const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
+//! operates on multiple molecules
+RDKIT_MOLSTANDARDIZE_EXPORT void chargeParentInPlace(
+    std::vector<RWMol *> &mols, int numThreads = 1,
+    const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
 
-//! Returns the super parent. The super parent is the fragment, charge, isotope,
-//! stereo, and tautomer parent of the molecule.
+//! Returns the super parent. The super parent is the fragment, charge,
+//! isotope, stereo, and tautomer parent of the molecule.
 RDKIT_MOLSTANDARDIZE_EXPORT RWMol *superParent(
     const RWMol &mol,
     const CleanupParameters &params = defaultCleanupParameters,
     bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void superParentInPlace(
+    RWMol &mol, const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
+RDKIT_MOLSTANDARDIZE_EXPORT void superParentInPlace(
+    std::vector<RWMol *> &mols, int numThreads = 1,
+    const CleanupParameters &params = defaultCleanupParameters,
+    bool skip_standardize = false);
 
 //! Convenience function for quickly standardizing a single SMILES string.
 /// Returns a standardized canonical SMILES string given a SMILES string.
