@@ -268,8 +268,24 @@ PyTautomerEnumeratorResult *enumerateHelper(
   return new PyTautomerEnumeratorResult(self.enumerate(mol));
 }
 
+std::vector<MolStandardize::TautomerScoringFunctions::SubstructTerm>
+GetDefaultTautomerSubstructsHelper() {
+  std::vector<MolStandardize::TautomerScoringFunctions::SubstructTerm> terms;
+  for (auto term : MolStandardize::TautomerScoringFunctions::
+           getDefaultTautomerScoreSubstructs()) {
+    terms.emplace_back(term);
+  }
+  return terms;
+}
+  
+
 }  // namespace
 
+// This indicates that the scoreSubstructs takes a minimum of 1 argument and a maximum of 2
+// so we can call it ScoreSubstructs(mol) or ScoreSubstructs(mol, terms)
+BOOST_PYTHON_FUNCTION_OVERLOADS(scoreSubstructs_overloads,
+				RDKit::MolStandardize::TautomerScoringFunctions::scoreSubstructs, 1, 2)
+
 struct tautomer_wrapper {
   static void wrap() {
     python::enum_<MolStandardize::TautomerEnumeratorStatus>(
@@ -283,9 +299,11 @@ struct tautomer_wrapper {
 
     python::class_<PyTautomerEnumeratorCallback, boost::noncopyable>(
         "TautomerEnumeratorCallback",
-        tautomerEnumeratorCallbackClassDoc.c_str(), python::init<>())
+        tautomerEnumeratorCallbackClassDoc.c_str(),
+        python::init<>(python::args("self")))
         .def("__call__",
              python::pure_virtual(&PyTautomerEnumeratorCallback::operator()),
+             python::args("self", "mol", "res"),
              "This must be implemented in the derived class. "
              "Return True if the tautomer enumeration should continue; "
              "False if the tautomer enumeration should stop.\n");
@@ -314,9 +332,9 @@ struct tautomer_wrapper {
         python::no_init)
         .def(python::map_indexing_suite<MolStandardize::SmilesTautomerMap,
                                         true>())
-        .def("keys", &smilesTautomerMapKeysHelper)
-        .def("values", &smilesTautomerMapValuesHelper)
-        .def("items", &smilesTautomerMapItemsHelper);
+        .def("keys", &smilesTautomerMapKeysHelper, python::args("self"))
+        .def("values", &smilesTautomerMapValuesHelper, python::args("self"))
+        .def("items", &smilesTautomerMapItemsHelper, python::args("self"));
 
     python::class_<PyTautomerEnumeratorResult, boost::noncopyable>(
         "TautomerEnumeratorResult",
@@ -353,12 +371,14 @@ struct tautomer_wrapper {
             "tuple of bond indices modified by the transforms")
         .def("__call__", &PyTautomerEnumeratorResult::tautomers,
              python::return_value_policy<python::manage_new_object>(),
-             "tautomers generated by the enumerator")
+             python::args("self"), "tautomers generated by the enumerator")
         .def("__iter__", python::range(&PyTautomerEnumeratorResult::begin,
                                        &PyTautomerEnumeratorResult::end))
         .def("__getitem__", &PyTautomerEnumeratorResult::at,
-             python::return_value_policy<python::manage_new_object>())
-        .def("__len__", &PyTautomerEnumeratorResult::size);
+             python::return_value_policy<python::manage_new_object>(),
+             python::args("self", "pos"))
+        .def("__len__", &PyTautomerEnumeratorResult::size,
+             python::args("self"));
 
     python::class_<MolStandardize::TautomerEnumerator, boost::noncopyable>(
         "TautomerEnumerator", python::no_init)
@@ -475,10 +495,11 @@ struct tautomer_wrapper {
              "returns whether AssignStereochemistry will be called "
              "on each tautomer generated by the Enumerate() method.")
         .def("SetCallback", &setCallbackHelper,
+             python::args("self", "callback"),
              "Pass an instance of a class derived from\n"
              "TautomerEnumeratorCallback, which must implement the\n"
              "__call__() method.")
-        .def("GetCallback", &getCallbackHelper,
+        .def("GetCallback", &getCallbackHelper, python::args("self"),
              "Get the TautomerEnumeratorCallback subclass instance,\n"
              "or None if none was set.")
         .def_readonly(
@@ -488,6 +509,53 @@ struct tautomer_wrapper {
                 MolStandardize::getV1TautomerEnumerator,
                 "return a TautomerEnumerator using v1 of the enumeration rules",
                 python::return_value_policy<python::manage_new_object>());
+
+    std::string docString =
+        "scores the ring system of the tautomer for canonicalization\n"
+        "Aromatic rings score 100, all carbon aromatic rings score 250";
+    python::def("ScoreRings",
+                MolStandardize::TautomerScoringFunctions::scoreRings,
+                python::arg("mol"), docString.c_str());
+
+    docString =
+        "scores the number of heteroHs of the tautomer for canonicalization\n"
+        "This gives a negative penalty to hydrogens attached to S,P, Se and Te";
+    python::def("ScoreHeteroHs",
+                MolStandardize::TautomerScoringFunctions::scoreHeteroHs,
+                python::arg("mol"), docString.c_str());
+
+    python::class_<MolStandardize::TautomerScoringFunctions::SubstructTerm>(
+        "SubstructTerm",
+        "Sets the score of this particular tautomer substructure, higher scores are more preferable\n"
+        "Aromatic rings score 100, all carbon aromatic rings score 250",
+        python::init<std::string, std::string, int>(
+            python::args("self", "name", "smarts", "score")))
+        .def_readonly(
+            "name",
+            &MolStandardize::TautomerScoringFunctions::SubstructTerm::name)
+        .def_readonly(
+            "smarts",
+            &MolStandardize::TautomerScoringFunctions::SubstructTerm::smarts)
+        .def_readonly(
+            "score",
+            &MolStandardize::TautomerScoringFunctions::SubstructTerm::score);
+
+    python::class_<
+        std::vector<MolStandardize::TautomerScoringFunctions::SubstructTerm>>(
+        "SubstructTermVector")
+        .def(python::vector_indexing_suite<std::vector<
+                 MolStandardize::TautomerScoringFunctions::SubstructTerm>>());
+    
+    docString = "scores the tautomer substructures";
+    python::def("ScoreSubstructs", &MolStandardize::TautomerScoringFunctions::scoreSubstructs,
+		scoreSubstructs_overloads((python::arg("mol"), python::arg("terms")),
+					  docString.c_str())
+		);
+
+
+    python::def("GetDefaultTautomerScoreSubstructs",
+                GetDefaultTautomerSubstructsHelper,
+                "Return the default tautomer substructure scoring terms");
   }
 };
 
