@@ -150,8 +150,8 @@ void RWMol::insertMol(const ROMol &other) {
     const bool takeOwnership = true;
     addAtom(newAt, updateLabel, takeOwnership);
     // take care of atom-numbering-dependent properties:
-    INT_VECT nAtoms;
-    if (newAt->getPropIfPresent(common_properties::_ringStereoAtoms, nAtoms)) {
+    if (INT_VECT nAtoms;
+        newAt->getPropIfPresent(common_properties::_ringStereoAtoms, nAtoms)) {
       for (auto &val : nAtoms) {
         if (val < 0) {
           val = -1 * (-val + origNumAtoms);
@@ -161,6 +161,11 @@ void RWMol::insertMol(const ROMol &other) {
       }
       newAt->setProp(common_properties::_ringStereoAtoms, nAtoms, true);
     }
+    if (unsigned int val;
+        oatom->getPropIfPresent(common_properties::_ringStereoOtherAtom, val)) {
+      newAt->setProp(common_properties::_ringStereoOtherAtom,
+                     val + origNumAtoms, true);
+    }
   }
 
   for (const auto obond : other.bonds()) {
@@ -601,6 +606,7 @@ void RWMol::removeBond(unsigned int aid1, unsigned int aid2) {
   dp_ringInfo->reset();
 
   removeSubstanceGroupsReferencingBond(*this, idx);
+  removeBondFromGroups(bnd, d_stereo_groups);
 
   // loop over all bonds with higher indices and update their indices
   for (auto bond : bonds()) {
@@ -608,7 +614,6 @@ void RWMol::removeBond(unsigned int aid1, unsigned int aid2) {
       bond->setIdx(bond->getIdx() - 1);
     }
   }
-  bnd->setOwningMol(nullptr);
 
   auto vd1 = boost::vertex(bnd->getBeginAtomIdx(), d_graph);
   auto vd2 = boost::vertex(bnd->getEndAtomIdx(), d_graph);
@@ -728,6 +733,8 @@ void RWMol::batchRemoveBonds() {
     }
 
     removeSubstanceGroupsReferencingBond(*this, idx);
+    // Remove this bond from any stereo group
+    removeBondFromGroups(bnd, d_stereo_groups);
 
     bnd->setOwningMol(nullptr);
 
