@@ -16,6 +16,7 @@
 // https://eprints.whiterose.ac.uk/3568/1/willets3.pdf
 
 #include <chrono>
+#include <functional>
 #include <iostream>
 #include <map>
 #include <regex>
@@ -43,7 +44,6 @@
 
 namespace RDKit {
 namespace RascalMCES {
-
 class TimedOutException : public std::exception {
  public:
   TimedOutException(long long int run_time,
@@ -90,6 +90,7 @@ struct RascalStartPoint {
   std::unique_ptr<ROMol> d_mol1;
   std::unique_ptr<ROMol> d_mol2;
 
+  // The line graphs of the 2 molecules as adjacency matrices
   std::vector<std::vector<int>> d_adjMatrix1, d_adjMatrix2;
   std::vector<std::pair<int, int>> d_vtxPairs;
   std::vector<boost::dynamic_bitset<>> d_modProd;
@@ -334,15 +335,14 @@ void makeLineGraph(const ROMol &mol, std::vector<std::vector<int>> &adjMatrix) {
 // make sure that mol1_bond in mol1 and mol2_bond in mol2 are, in at least one
 // ring that is the same. If aromaticRingsMatchOnly is true, then only aromatic
 // bonds are considered.
-bool checkRings(const ROMol &mol1,
-                        std::vector<std::string> &mol1RingSmiles,
-                        int mol1BondIdx, const ROMol &mol2,
-                        std::vector<std::string> &mol2RingSmiles,
-                        int mol2BondIdx,
-                        bool aromaticRingsMatchOnly) {
+bool checkRings(const ROMol &mol1, std::vector<std::string> &mol1RingSmiles,
+                int mol1BondIdx, const ROMol &mol2,
+                std::vector<std::string> &mol2RingSmiles, int mol2BondIdx,
+                bool aromaticRingsMatchOnly) {
   auto mol1Bond = mol1.getBondWithIdx(mol1BondIdx);
   auto mol2Bond = mol2.getBondWithIdx(mol2BondIdx);
-  if (aromaticRingsMatchOnly && (!mol1Bond->getIsAromatic() || !mol2Bond->getIsAromatic())) {
+  if (aromaticRingsMatchOnly &&
+      (!mol1Bond->getIsAromatic() || !mol2Bond->getIsAromatic())) {
     return true;
   }
 
@@ -453,13 +453,15 @@ void buildPairs(const ROMol &mol1, const std::vector<unsigned int> &vtxLabels1,
   for (auto i = 0u; i < vtxLabels1.size(); ++i) {
     for (auto j = 0u; j < vtxLabels2.size(); ++j) {
       if (vtxLabels1[i] == vtxLabels2[j]) {
-        // completeSmallestRings automatically implies completeAromaticRings and 
+        // completeSmallestRings automatically implies completeAromaticRings and
         // ringMatchesRingsOnly
         if (opts.completeSmallestRings &&
-            !checkRings(mol1, mol1RingSmiles, i, mol2, mol2RingSmiles, j, false)) {
+            !checkRings(mol1, mol1RingSmiles, i, mol2, mol2RingSmiles, j,
+                        false)) {
           continue;
         } else if (opts.completeAromaticRings &&
-            !checkRings(mol1, mol1RingSmiles, i, mol2, mol2RingSmiles, j, true)) {
+                   !checkRings(mol1, mol1RingSmiles, i, mol2, mol2RingSmiles, j,
+                               true)) {
           continue;
         }
         if (!opts.completeSmallestRings && opts.ringMatchesRingOnly &&
@@ -472,6 +474,32 @@ void buildPairs(const ROMol &mol1, const std::vector<unsigned int> &vtxLabels1,
   }
 }
 
+// Use the Floyd-Warshall algorithm to compute the distance matrix from the
+// adjacency matrix.
+// Adapted from https://en.wikipedia.org/wiki/Floyd–Warshall_algorithm
+void calcDistMatrix(const std::vector<std::vector<int>> &adjMatrix,
+                    std::vector<std::vector<int>> &distMatrix) {
+  distMatrix = std::vector<std::vector<int>>(
+      adjMatrix.size(),
+      std::vector<int>(adjMatrix.size(), adjMatrix.size() + 1));
+  for (size_t i = 0u; i < adjMatrix.size(); ++i) {
+    distMatrix[i][i] = 0;
+    for (size_t j = 0u; j < adjMatrix.size(); ++j) {
+      if (i != j && adjMatrix[i][j]) {
+        distMatrix[i][j] = 1;
+      }
+    }
+  }
+  for (size_t k = 0u; k < adjMatrix.size(); ++k) {
+    for (size_t i = 0u; i < adjMatrix.size(); ++i) {
+      for (size_t j = 0u; j < adjMatrix.size(); ++j) {
+        distMatrix[i][j] =
+            std::min(distMatrix[i][j], distMatrix[i][k] + distMatrix[k][j]);
+      }
+    }
+  }
+}
+
 // Make the modular product between the 2 graphs passed in.  Each node in the
 // graph is a pair of vertices, one from the first graph, the other from the
 // second, whose labels match.  Two vertices are connected in the modular
@@ -480,11 +508,9 @@ void buildPairs(const ROMol &mol1, const std::vector<unsigned int> &vtxLabels1,
 void makeModularProduct(const ROMol &mol1,
                         const std::vector<std::vector<int>> &adjMatrix1,
                         const std::vector<unsigned int> &vtxLabels1,
-                        const std::vector<std::vector<int>> &distMatrix1,
                         const ROMol &mol2,
                         const std::vector<std::vector<int>> &adjMatrix2,
                         const std::vector<unsigned int> &vtxLabels2,
-                        const std::vector<std::vector<int>> &distMatrix2,
                         const RascalOptions &opts,
                         std::vector<std::pair<int, int>> &vtxPairs,
                         std::vector<boost::dynamic_bitset<>> &modProd) {
@@ -500,6 +526,12 @@ void makeModularProduct(const ROMol &mol1,
     modProd.clear();
     return;
   }
+  std::vector<std::vector<int>> distMatrix1, distMatrix2;
+  if (opts.maxFragSeparation > -1) {
+    calcDistMatrix(adjMatrix1, distMatrix1);
+    calcDistMatrix(adjMatrix2, distMatrix2);
+  }
+
   modProd = std::vector<boost::dynamic_bitset<>>(
       vtxPairs.size(), boost::dynamic_bitset<>(vtxPairs.size()));
   for (auto i = 0u; i < vtxPairs.size() - 1; ++i) {
@@ -516,14 +548,9 @@ void makeModularProduct(const ROMol &mol1,
           distsOk = false;
         }
       }
-      if (opts.singleLargestFrag &&
-          distMatrix1[vtxPairs[i].first][vtxPairs[j].first] !=
-              distMatrix2[vtxPairs[i].second][vtxPairs[j].second]) {
-        distsOk = false;
-      }
       if (distsOk && adjMatrix1[vtxPairs[i].first][vtxPairs[j].first] ==
                          adjMatrix2[vtxPairs[i].second][vtxPairs[j].second]) {
-        modProd[i][j] = modProd[j][i] = 1;
+        modProd[i][j] = modProd[j][i] = true;
       }
     }
   }
@@ -580,8 +607,8 @@ void printClique(const std::vector<unsigned int> &clique,
       os << "{" << vtxPairs[mem].first << ", " << vtxPairs[mem].second << "},";
     }
   }
-  std::cout << std::endl;
-  std::cout << "mol 1 bonds : [";
+  os << std::endl;
+  os << "mol 1 bonds : [";
   for (auto mem : clique) {
     if (swapped) {
       os << vtxPairs[mem].second << ", ";
@@ -589,8 +616,8 @@ void printClique(const std::vector<unsigned int> &clique,
       os << vtxPairs[mem].first << ", ";
     }
   }
-  std::cout << "]" << std::endl;
-  std::cout << "mol 2 bonds : [";
+  os << "]" << std::endl;
+  os << "mol 2 bonds : [";
   for (auto mem : clique) {
     if (swapped) {
       os << vtxPairs[mem].first << ", ";
@@ -598,7 +625,7 @@ void printClique(const std::vector<unsigned int> &clique,
       os << vtxPairs[mem].second << ", ";
     }
   }
-  std::cout << "]" << std::endl;
+  os << "]" << std::endl;
 }
 
 // if the clique involves a delta-y exchange, returns true.  Should only be
@@ -762,7 +789,7 @@ void updateMaxClique(const std::vector<unsigned int> &clique, bool deltaYPoss,
       if (!didCliqueOk) {
         goodClique = cliqueOk(clique, opts, mol1, mol2, vtxPairs);
       }
-      if (goodClique &&
+      if (goodClique && maxCliques.size() < opts.maxBestMCESs &&
           (maxCliques.empty() || clique.size() == maxCliques.front().size())) {
         maxCliques.push_back(clique);
       }
@@ -977,33 +1004,6 @@ void findEquivalentBonds(const ROMol &mol, std::vector<int> &equivBonds) {
   }
 }
 
-// Use the Floyd-Warshall algorithm to compute the distance matrix from the
-// adjacency matrix.
-// Adapted from https://en.wikipedia.org/wiki/Floyd–Warshall_algorithm
-void calcDistMatrix(const std::vector<std::vector<int>> &adjMatrix,
-                    std::vector<std::vector<int>> &distMatrix) {
-  distMatrix = std::vector<std::vector<int>>(
-      adjMatrix.size(),
-      std::vector<int>(adjMatrix.size(), adjMatrix.size() + 1));
-  for (size_t i = 0u; i < adjMatrix.size(); ++i) {
-    distMatrix[i][i] = 0;
-    for (size_t j = 0u; j < adjMatrix.size(); ++j) {
-      if (i != j && adjMatrix[i][j]) {
-        distMatrix[i][j] = 1;
-      }
-    }
-  }
-  for (size_t k = 0u; k < adjMatrix.size(); ++k) {
-    for (size_t i = 0u; i < adjMatrix.size(); ++i) {
-      for (size_t j = 0u; j < adjMatrix.size(); ++j) {
-        if (distMatrix[i][j] > distMatrix[i][k] + distMatrix[k][j]) {
-          distMatrix[i][j] = distMatrix[i][k] + distMatrix[k][j];
-        }
-      }
-    }
-  }
-}
-
 // Set the atomic number of the atoms that match the SMARTS in
 // RascalOptions.EquivalentAtoms to 110, 111 etc.  These will
 // be mapped back at the end.
@@ -1072,19 +1072,12 @@ RascalStartPoint makeInitialPartitionSet(const ROMol *mol1, const ROMol *mol2,
   makeLineGraph(*starter.d_mol1, starter.d_adjMatrix1);
   makeLineGraph(*starter.d_mol2, starter.d_adjMatrix2);
 
-  std::vector<std::vector<int>> distMat1, distMat2;
-  if (opts.maxFragSeparation > -1 || opts.singleLargestFrag) {
-    calcDistMatrix(starter.d_adjMatrix1, distMat1);
-    calcDistMatrix(starter.d_adjMatrix2, distMat2);
-  }
-
   // pairs are vertices in the 2 line graphs that are the same type.
   // d_modProd is the modular product/correspondence graph of the two
   // line graphs.
   makeModularProduct(*starter.d_mol1, starter.d_adjMatrix1, bondLabels1,
-                     distMat1, *starter.d_mol2, starter.d_adjMatrix2,
-                     bondLabels2, distMat2, opts, starter.d_vtxPairs,
-                     starter.d_modProd);
+                     *starter.d_mol2, starter.d_adjMatrix2, bondLabels2, opts,
+                     starter.d_vtxPairs, starter.d_modProd);
   if (starter.d_modProd.empty()) {
     return starter;
   }
