@@ -136,6 +136,9 @@ void RascalResult::largestFragsOnly(unsigned int numFrags) {
   std::sort(frags.begin(), frags.end(),
             [](const boost::shared_ptr<ROMol> &f1,
                const boost::shared_ptr<ROMol> &f2) -> bool {
+              if (f1->getNumAtoms() == f2->getNumAtoms()) {
+                return f1->getNumBonds() > f2->getNumBonds();
+              }
               return f1->getNumAtoms() > f2->getNumAtoms();
             });
   frags.erase(frags.begin() + numFrags, frags.end());
