@@ -481,51 +481,14 @@ TEST_CASE("bad aromatics 1") {
   }
 }
 
-TEST_CASE("timeout") {
-  auto m1 =
-      "O[C@@H]1CC[C@H](C[C@H]1OC)C[C@@H](C)[C@@H]4CC(=O)[C@H](C)/C=C(\\C)[C@@H](O)[C@@H](OC)C(=O)[C@H](C)C[C@H](C)\\C=C\\C=C\\C=C(/C)[C@@H](OC)C[C@@H]2CC[C@@H](C)[C@@](O)(O2)C(=O)C(=O)N3CCCC[C@H]3C(=O)O4"_smiles;
-  REQUIRE(m1);
-  auto m2 =
-      "CCC1C=C(CC(CC(C2C(CC(C(O2)(C(=O)C(=O)N3CCCCC3C(=O)OC(C(C(CC1=O)O)C)C(=CC4CCC(C(C4)OC)O)C)O)C)OC)OC)C)C"_smiles;
-  REQUIRE(m2);
-
-  {
-    RascalOptions opts;
-    opts.timeout = 10;
-    opts.maxBondMatchPairs = 2000;
-    auto res = rascalMCES(*m1, *m2, opts);
-    REQUIRE(res.size() == 1);
-    REQUIRE(res.front().getBondMatches().size() >= 39);
-    check_smarts_ok(*m1, *m2, res.front());
-  }
-  {
-    RascalOptions opts;
-    opts.timeout = 70;
-    opts.maxBondMatchPairs = 2000;
-    auto res = rascalMCES(*m1, *m2, opts);
-    REQUIRE(res.size() == 1);
-    REQUIRE(res.front().getBondMatches().size() >= 44);
-    check_smarts_ok(*m1, *m2, res.front());
-  }
-  {
-    RascalOptions opts;
-    opts.timeout = 120;
-    opts.maxBondMatchPairs = 2000;
-    auto res = rascalMCES(*m1, *m2, opts);
-    REQUIRE(res.size() == 1);
-    REQUIRE(res.front().getBondMatches().size() >= 44);
-    check_smarts_ok(*m1, *m2, res.front());
-  }
-}
-
 TEST_CASE("single fragment") {
   RascalOptions opts;
   std::vector<std::tuple<std::string, std::string, unsigned int, unsigned int>>
       tests = {
-          {"C1CC1CCC1NC1", "C1CC1CCCCC1NC1", 8, 6},
-          {"c1cnccc1CCc1ncccc1", "c1cnccc1CCCCCCc1ncccc1", 14, 9},
+          {"C1CC1CCC1NC1", "C1CC1CCCCC1NC1", 8, 5},
+          {"c1cnccc1CCc1ncccc1", "c1cnccc1CCCCCCc1ncccc1", 14, 8},
           {"c1ccccc1c1cccc(c1)CCc1ccccc1", "c1ccccc1c1cccc(c1)CCCCCc1ccccc1",
-           21, 16},
+           21, 15},
           {"Cc1cc2nc(-c3cccc(NC(=O)CSc4ccc(Cl)cc4)c3)oc2cc1C  CHEMBL1398008",
            "COc1ccc2oc(-c3ccc(C)c(NC(=O)COc4cc(C)cc(C)c4)c3)nc2c1  CHEMBL1436972",
            27, 21}};
@@ -712,7 +675,6 @@ TEST_CASE("complete smallest rings") {
   }
 }
 
-
 TEST_CASE("multiple cliques returned") {
   std::vector<std::tuple<std::string, std::string, unsigned int, unsigned int,
                          std::vector<std::pair<int, int>>>>
@@ -769,70 +731,6 @@ TEST_CASE("multiple cliques returned") {
   }
 }
 
-TEST_CASE("benchmarks") {
-  // As well as timings, this also tests that the same result is produced from
-  // random ordering of the input molecules i.e. the results aren't input order
-  // dependent.
-  std::vector<std::tuple<std::string, std::string, std::string, double, int,
-                         unsigned int, int>>
-      tests = {{"juglone", "Oc1cccc2C(=O)C=CC(=O)c12",
-                "O1C(=O)C=Cc2cc(OC)c(O)cc12", 0.5, 100, 8, 10},
-               {"methadone", "c1ccccc1C(C(=O)CC)(c1ccccc1)CC(C)N(C)C",
-                "c1ccccc1C1(CCN(C)CC1)C(=O)OCC", 0.6, 100, 16, 20},
-               {"symmetrical",
-                "c1c(OC)c(OC)c(OC)cc1C(=O)OCCCOC(=O)c1cc(OC)c(OC)c(OC)c1",
-                "c1c(OC)c(OC)c(OC)cc1C(=O)OCCOC(=O)c1cc(OC)c(OC)c(OC)c1", 0.7,
-                100, 32, 50},
-               {"testosterone", "CC12CCC3C(C1CCC2O)CCC4=CC(=O)CCC34C",
-                "CC12CCC3C(C1CCC2O)CCC4=C3C=CC(=C4)O", 0.6, 100, 16, 50}};
-  std::vector<double> timings;
-  std::random_device rd;
-  std::mt19937 g(rd());
-  // It's convenient if the same test is run each time.
-  g.seed(1);
-  RascalOptions opts;
-  for (const auto &test : tests) {
-    auto m1 = std::unique_ptr<ROMol>(RDKit::SmilesToMol(std::get<1>(test)));
-    auto m2 = std::unique_ptr<ROMol>(RDKit::SmilesToMol(std::get<2>(test)));
-    opts.similarityThreshold = std::get<3>(test);
-    std::vector<unsigned int> atom1Inds(m1->getNumAtoms(), 0);
-    std::iota(atom1Inds.begin(), atom1Inds.end(), 0);
-    std::vector<unsigned int> atom2Inds(m2->getNumAtoms(), 0);
-    std::iota(atom2Inds.begin(), atom2Inds.end(), 0);
-    auto t1 = std::chrono::high_resolution_clock::now();
-    for (int i = 0; i < std::get<4>(test); ++i) {
-      std::shuffle(atom1Inds.begin(), atom1Inds.end(), g);
-      std::unique_ptr<ROMol> randmol1(MolOps::renumberAtoms(*m1, atom1Inds));
-      std::shuffle(atom2Inds.begin(), atom2Inds.end(), g);
-      std::unique_ptr<ROMol> randmol2(MolOps::renumberAtoms(*m2, atom2Inds));
-
-      auto res = rascalMCES(*randmol1, *randmol2, opts);
-      REQUIRE(res.size() == 1);
-      REQUIRE(std::get<5>(test) == res.front().getBondMatches().size());
-      check_smarts_ok(*randmol1, *randmol2, res.front());
-    }
-    auto t2 = std::chrono::high_resolution_clock::now();
-    timings.push_back(
-        std::chrono::duration_cast<std::chrono::milliseconds>(t2 - t1).count() /
-        std::get<4>(test));
-  }
-
-  // Make sure we haven't slowed it down a lot.
-  //  for (size_t i = 0; i < tests.size(); ++i) {
-  //    std::cout << "TIMING : " << std::get<0>(tests[i]) << " took " <<
-  //    timings[i]
-  //              << " milliseconds on average of " << std::get<4>(tests[i])
-  //              << " runs\n";
-  //  }
-  for (size_t i = 0; i < tests.size(); ++i) {
-    auto ref_time = std::get<6>(tests[i]);
-#ifndef NDEBUG  // allow more time for debug builds
-    ref_time *= 5;
-#endif
-    REQUIRE(timings[i] < ref_time);
-  }
-}
-
 // Anything starting FMCS is taken from the test data for RDKit's FMCS tests.
 TEST_CASE("FMCS test1Basics") {
   auto m1 = "CC1CCC(N)CC1"_smiles;
@@ -1512,41 +1410,6 @@ TEST_CASE("Order of atoms in bond labels must be consistent - Github 8198.") {
   }
 }
 
-TEST_CASE("Duplicate Single Largest Frag") {
-  {
-    auto m1 = "c1ccc2c(c1)c(ncn2)CNCc3ccc(cc3)Cl"_smiles;
-    REQUIRE(m1);
-    auto m2 = "c1ccc2c(c1)c(ncn2)CCCc3ccc(cc3)Cl"_smiles;
-    REQUIRE(m2);
-    RascalOptions opts;
-    opts.singleLargestFrag = true;
-    opts.allBestMCESs = true;
-    auto res = rascalMCES(*m1, *m2, opts);
-    REQUIRE(res.size() == 1);
-    CHECK(res.front().getAtomMatches().size() == 11);
-    CHECK(res.front().getBondMatches().size() == 12);
-  }
-  {
-    // Without the fix, there were 156 results sets, with different breaks
-    // in the long chain giving different numbers of atoms in the largest
-    // fragment.
-    auto m1 = "CN(C)c1ccc(CC(=O)NCCCCCCCCCCNC23CC4CC(C2)CC(C3)C4)cc1"_smiles;
-    REQUIRE(m1);
-    auto m2 = "CN(C)c1ccc(CC(=O)NCCCCCCCCCCCCNC23CC4CC(C2)CC(C3)C4)cc1"_smiles;
-    REQUIRE(m2);
-    RascalOptions opts;
-    opts.singleLargestFrag = true;
-    opts.allBestMCESs = true;
-    auto res = rascalMCES(*m1, *m2, opts);
-    REQUIRE(!res.empty());
-    CHECK(res.size() == 4);
-    CHECK(res.front().getAtomMatches().size() == 23);
-    CHECK(res.front().getBondMatches().size() == 23);
-    CHECK(res.back().getAtomMatches().size() == 23);
-    CHECK(res.back().getBondMatches().size() == 23);
-  }
-}
-
 TEST_CASE(
     "Github 8246 - equivalentAtoms SMARTS not translated back in the SMARTS string") {
   auto m1 = "COC1=CC2(Oc3ccc(-c4ccc(OC)c(OC)c4)cc3C2=O)C(OC)=CC1O"_smiles;
@@ -1581,6 +1444,43 @@ TEST_CASE("Specify minimum clique size directly.") {
   REQUIRE(res2.empty());
 }
 
+TEST_CASE("Duplicate Single Largest Frag") {
+  {
+    auto m1 = "c1ccc2c(c1)c(ncn2)CNCc3ccc(cc3)Cl"_smiles;
+    REQUIRE(m1);
+    auto m2 = "c1ccc2c(c1)c(ncn2)CCCc3ccc(cc3)Cl"_smiles;
+    REQUIRE(m2);
+    RascalOptions opts;
+    opts.singleLargestFrag = true;
+    opts.allBestMCESs = true;
+    opts.timeout = -1;
+    auto res = rascalMCES(*m1, *m2, opts);
+    REQUIRE(res.size() == 1);
+    CHECK(res.front().getAtomMatches().size() == 11);
+    CHECK(res.front().getBondMatches().size() == 12);
+  }
+  {
+    // Without the fix, there were 156 results sets, with different breaks
+    // in the long chain giving different numbers of atoms in the largest
+    // fragment.
+    auto m1 = "CN(C)c1ccc(CC(=O)NCCCCCCCCCCNC23CC4CC(C2)CC(C3)C4)cc1"_smiles;
+    REQUIRE(m1);
+    auto m2 = "CN(C)c1ccc(CC(=O)NCCCCCCCCCCCCNC23CC4CC(C2)CC(C3)C4)cc1"_smiles;
+    REQUIRE(m2);
+    RascalOptions opts;
+    opts.singleLargestFrag = true;
+    opts.allBestMCESs = true;
+    opts.timeout = -1;
+    auto res = rascalMCES(*m1, *m2, opts);
+    REQUIRE(!res.empty());
+    CHECK(res.size() == 4);
+    CHECK(res.front().getAtomMatches().size() == 23);
+    CHECK(res.front().getBondMatches().size() == 23);
+    CHECK(res.back().getAtomMatches().size() == 23);
+    CHECK(res.back().getBondMatches().size() == 23);
+  }
+}
+
 TEST_CASE("Github8255 - incorrect MCES with singleLargestFrag=true") {
   RascalOptions opts;
   opts.singleLargestFrag = true;
@@ -1596,8 +1496,8 @@ TEST_CASE("Github8255 - incorrect MCES with singleLargestFrag=true") {
     auto res = rascalMCES(*m1, *m2, opts);
     CHECK(res.size() == 3);
     for (auto &r : res) {
-      CHECK(r.getAtomMatches().size() == 20);
-      CHECK(r.getBondMatches().size() == 21);
+      CHECK(r.getAtomMatches().size() == 22);
+      CHECK(r.getBondMatches().size() == 24);
     }
   }
   {
@@ -1612,4 +1512,50 @@ TEST_CASE("Github8255 - incorrect MCES with singleLargestFrag=true") {
       CHECK(r.getBondMatches().size() == 22);
     }
   }
+}
+
+TEST_CASE("Github8360 - another incorrect MCES with singleLargestFrag=true") {
+  RascalOptions opts;
+  opts.singleLargestFrag = true;
+  opts.allBestMCESs = true;
+  opts.completeAromaticRings = false;
+  {
+    auto m2 = "c1ccc(cn1)-c1ccc2ccccc2n1"_smiles;
+    REQUIRE(m2);
+    auto m1 = "c1ccc(cn1)-c1cc2ccccc2[nH]1"_smiles;
+    REQUIRE(m1);
+    auto res = rascalMCES(*m1, *m2, opts);
+    CHECK(res.size() == 3);
+    for (auto &r : res) {
+      CHECK(r.getAtomMatches().size() == 15);
+      CHECK(r.getBondMatches().size() == 16);
+    }
+  }
+  {
+    auto m1 = "C=CCCC=CCCC1CNCCC1"_smiles;
+    REQUIRE(m1);
+    auto m2 = "C=CCC=CCCCC1CNCCC1"_smiles;
+    REQUIRE(m2);
+    auto res = rascalMCES(*m1, *m2, opts);
+    REQUIRE(!res.empty());
+    CHECK(res.size() == 1);
+    for (auto &r : res) {
+      CHECK(r.getAtomMatches().size() == 9);
+      CHECK(r.getBondMatches().size() == 9);
+    }
+  }
+}
+
+TEST_CASE("Github8645 - memory blows up") {
+  RascalOptions opts;
+  opts.similarityThreshold = 0.3;
+  opts.timeout = 10;
+  opts.singleLargestFrag = true;
+  auto m1 = "Fc1c(F)c(F)c(F)c(F)c1c1c(F)c(F)c(F)c(F)c1"_smiles;
+  REQUIRE(m1);
+  auto m2 = "FC1(F)C(F)(F)C(F)(F)C(F)(F)C(F)(F)C1(F)(F)"_smiles;
+  REQUIRE(m2);
+  auto res = rascalMCES(*m1, *m2, opts);
+  REQUIRE(res.size() == 1);
+  CHECK(res.front().getBondMatches().size() == 1);
 }
\ No newline at end of file
