@@ -696,7 +696,8 @@ namespace detail {
 
 void printSyntaxErrorMessage(std::string_view input,
                              std::string_view err_message,
-                             unsigned int bad_token_position) {
+                             unsigned int bad_token_position,
+                             std::string_view input_type) {
   // NOTE: If the input is very long, the pointer to the failed location
   // becomes less useful. We should truncate the length of the error message
   // to 41 chars.
@@ -717,10 +718,10 @@ void printSyntaxErrorMessage(std::string_view input,
       (bad_token_position >= prefix_size ? prefix_size
                                          : bad_token_position - 1);
 
-  BOOST_LOG(rdErrorLog) << "SMILES Parse Error: " << err_message
+  BOOST_LOG(rdErrorLog) << input_type << " Parse Error: " << err_message
                         << " while parsing: " << input << std::endl;
   BOOST_LOG(rdErrorLog)
-      << "SMILES Parse Error: check for mistakes around position "
+      << input_type << " Parse Error: check for mistakes around position "
       << bad_token_position << ":" << std::endl;
   BOOST_LOG(rdErrorLog) << truncate_input(input, bad_token_position - 1)
                         << std::endl;
