@@ -491,7 +491,7 @@ static bool SortBasedOnFirstElement(
 namespace SmilesWrite {
 namespace detail {
 std::string MolToSmiles(const ROMol &mol, const SmilesWriteParams &params,
-                        bool doingCXSmiles) {
+                        bool doingCXSmiles, bool includeStereoGroups) {
   if (!mol.getNumAtoms()) {
     return "";
   }
@@ -500,7 +500,8 @@ std::string MolToSmiles(const ROMol &mol, const SmilesWriteParams &params,
           static_cast<unsigned int>(params.rootedAtAtom) < mol.getNumAtoms(),
       "rootedAtAtom must be less than the number of atoms");
 
-  int rootedAtAtom = params.rootedAtAtom;
+  int rootedAtAtom;
+  std::vector<int> fragsRootedAtAtom;
   std::vector<std::vector<int>> fragsMolAtomMapping;
   auto mols =
       MolOps::getMolFrags(mol, false, nullptr, &fragsMolAtomMapping, false);
@@ -515,6 +516,13 @@ std::string MolToSmiles(const ROMol &mol, const SmilesWriteParams &params,
     for (auto aidx : atsInFrag) {
       atsPresent.set(aidx);
     }
+
+    rootedAtAtom = -1;
+    if (params.rootedAtAtom >= 0 && atsPresent[params.rootedAtAtom]) {
+      rootedAtAtom = params.rootedAtAtom - atsPresent.find_first();
+    }
+    fragsRootedAtAtom.push_back(rootedAtAtom);
+
     for (const auto bnd : mol.bonds()) {
       if (atsPresent[bnd->getBeginAtomIdx()] &&
           atsPresent[bnd->getEndAtomIdx()]) {
@@ -558,11 +566,13 @@ std::string MolToSmiles(const ROMol &mol, const SmilesWriteParams &params,
         MolOps::assignStereochemistry(*tmol, params.cleanStereo);
       }
     }
-    if (!doingCXSmiles) {
+    if (!doingCXSmiles || !includeStereoGroups) {
       // remove any stereo groups that may be present. Otherwise they will be
       // used in the canonicalization
       std::vector<StereoGroup> noStereoGroups;
       tmol->setStereoGroups(noStereoGroups);
+    }
+    if (!doingCXSmiles) {
       // remove any wiggle bonds, unspecified double bond stereochemistry, or
       // dative bonds (if we aren't doing dative bonds in the standard SMILES)
       for (auto bond : tmol->bonds()) {
@@ -593,6 +603,20 @@ std::string MolToSmiles(const ROMol &mol, const SmilesWriteParams &params,
       }
     }
 
+    // if we are doing CXSMILES, Hydrogen bonds are shown as single bonds
+    // in the smiles part, and are indicated with the H: block of the CX
+    // extensions
+
+    if (doingCXSmiles) {
+      for (auto bond : tmol->bonds()) {
+        if (bond->getBondType() == Bond::HYDROGEN) {
+          bond->setBondType(Bond::SINGLE);
+        }
+      }
+    }
+
+    rootedAtAtom = fragsRootedAtAtom[fragIdx];
+
     if (params.doRandom && rootedAtAtom == -1) {
       // need to find a random atom id between 0 and mol.getNumAtoms()
       // exclusively
@@ -741,6 +765,8 @@ std::string MolToCXSmiles(const ROMol &romol,
   RWMol trwmol(romol);
 
   bool doingCXSmiles = true;
+  bool includeStereoGroups =
+      flags & SmilesWrite::CXSmilesFields::CX_ENHANCEDSTEREO;
   SmilesWriteParams params = paramsInput;
 
   // if kekule is to be done, and the bond attrs (wedging) is to be done, we
@@ -753,7 +779,8 @@ std::string MolToCXSmiles(const ROMol &romol,
     params.doKekule = false;
   }
 
-  auto res = SmilesWrite::detail::MolToSmiles(trwmol, params, doingCXSmiles);
+  auto res = SmilesWrite::detail::MolToSmiles(trwmol, params, doingCXSmiles,
+                                              includeStereoGroups);
   if (res.empty()) {
     return res;
   }
