@@ -14,6 +14,7 @@
 namespace RDKit {
 namespace StructureCheck {
 // used in unit test
-RDKIT_STRUCTCHECKER_EXPORT bool StringToAugmentedAtom(const char *str, AugmentedAtom &aa);
-}
-}
+RDKIT_STRUCTCHECKER_EXPORT bool StringToAugmentedAtom(const char *str,
+                                                      AugmentedAtom &aa);
+}  // namespace StructureCheck
+}  // namespace RDKit
