@@ -46,6 +46,7 @@
 #include <DataStructs/BitOps.h>
 #include <GraphMol/MolOps.h>
 #include <GraphMol/TautomerQuery/TautomerQuery.h>
+#include <GraphMol/GeneralizedSubstruct/XQMol.h>
 
 #include <algorithm>
 #include <string>
@@ -53,6 +54,8 @@
 
 namespace RDKit {
 
+using GeneralizedSubstruct::ExtendedQueryMol;
+
 RDKIT_SUBSTRUCTLIBRARY_EXPORT bool SubstructLibraryCanSerialize();
 
 //! Base class API for holding molecules to substructure search.
@@ -743,6 +746,13 @@ class RDKIT_SUBSTRUCTLIBRARY_EXPORT SubstructLibrary {
                                        const SubstructMatchParameters &params,
                                        int numThreads = -1,
                                        int maxResults = -1) const;
+  //! overload
+  std::vector<unsigned int> getMatches(const ExtendedQueryMol &query,
+                                       unsigned int startIdx,
+                                       unsigned int endIdx,
+                                       const SubstructMatchParameters &params,
+                                       int numThreads = -1,
+                                       int maxResults = -1) const;
 
   //! Return the number of matches for the query
   /*!
@@ -819,6 +829,11 @@ class RDKIT_SUBSTRUCTLIBRARY_EXPORT SubstructLibrary {
                             unsigned int endIdx,
                             const SubstructMatchParameters &params,
                             int numThreads = -1) const;
+  //! overload
+  unsigned int countMatches(const ExtendedQueryMol &query,
+                            unsigned int startIdx, unsigned int endIdx,
+                            const SubstructMatchParameters &params,
+                            int numThreads = -1) const;
 
   //! Returns true if any match exists for the query
   /*!
@@ -883,6 +898,10 @@ class RDKIT_SUBSTRUCTLIBRARY_EXPORT SubstructLibrary {
   bool hasMatch(const MolBundle &query, unsigned int startIdx,
                 unsigned int endIdx, const SubstructMatchParameters &params,
                 int numThreads = -1) const;
+  //! overload
+  bool hasMatch(const ExtendedQueryMol &query, unsigned int startIdx,
+                unsigned int endIdx, const SubstructMatchParameters &params,
+                int numThreads = -1) const;
   //! Returns the molecule at the given index
   /*!
     \param idx       Index of the molecule in the library (n.b. could contain
