@@ -7,13 +7,6 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
-// This file contains an implementation of synthonspace substructure search
-// similar to that described in
-// 'Fast Substructure Search in Combinatorial Library Spaces',
-// Thomas Liphardt and Thomas Sander,
-// J. Chem. Inf. Model. 2023, 63, 16, 5133–5141
-// https://doi.org/10.1021/acs.jcim.3c00290
-//
 // The algorithm allows the substructure searching of a very large library
 // of structures that is described in synthon format (such as Enamine REAL)
 // without enumerating the individual structures during the search process.
@@ -34,7 +27,10 @@
 #include <GraphMol/SynthonSpaceSearch/SynthonSpaceSearch_details.h>
 #include <GraphMol/SynthonSpaceSearch/SynthonSet.h>
 #include <GraphMol/SynthonSpaceSearch/SynthonSpace.h>
+#include <GraphMol/SmilesParse/SmilesParse.h>
+
 #include <GraphMol/SmilesParse/SmilesWrite.h>
+#include <RDGeneral/ControlCHandler.h>
 
 namespace RDKit::SynthonSpaceSearch {
 
@@ -42,9 +38,12 @@ const std::vector<std::shared_ptr<ROMol>> &SynthonSet::getConnectorRegions()
     const {
   return d_connectorRegions;
 }
-
-const std::unique_ptr<ExplicitBitVect> &SynthonSet::getConnRegFP() const {
-  return d_connRegFP;
+const std::vector<std::string> &SynthonSet::getConnectorRegionSmiles() const {
+  return d_connRegSmis;
+}
+const std::vector<std::unique_ptr<ExplicitBitVect>> &SynthonSet::getConnRegFPs()
+    const {
+  return d_connRegFPs;
 }
 const std::unique_ptr<ExplicitBitVect> &SynthonSet::getAddFP() const {
   return d_addFP;
@@ -53,11 +52,6 @@ const std::unique_ptr<ExplicitBitVect> &SynthonSet::getSubtractFP() const {
   return d_subtractFP;
 }
 
-const std::vector<std::vector<std::unique_ptr<ExplicitBitVect>>> &
-SynthonSet::getSynthonFPs() const {
-  return d_synthonFPs;
-}
-
 namespace {
 void writeBitSet(std::ostream &os, const boost::dynamic_bitset<> &bitset) {
   streamWrite(os, bitset.size());
@@ -73,24 +67,28 @@ void writeBitSet(std::ostream &os, const boost::dynamic_bitset<> &bitset) {
 
 void SynthonSet::writeToDBStream(std::ostream &os) const {
   streamWrite(os, d_id);
-  streamWrite(os, getConnectorRegions().size());
+  streamWrite(os, static_cast<std::uint64_t>(getConnectorRegions().size()));
   for (const auto &cr : getConnectorRegions()) {
     MolPickler::pickleMol(*cr, os, PicklerOps::AllProps);
   }
-  auto connRegFPstr = getConnRegFP()->toString();
-  streamWrite(os, connRegFPstr);
+  streamWrite(os, static_cast<std::uint64_t>(getConnRegFPs().size()));
+  for (const auto &fp : getConnRegFPs()) {
+    auto connRegFPstr = fp->toString();
+    streamWrite(os, connRegFPstr);
+  }
 
   writeBitSet(os, d_connectors);
-  streamWrite(os, d_synthConnPatts.size());
+  streamWrite(os, static_cast<std::uint64_t>(d_synthConnPatts.size()));
   for (const auto &scp : d_synthConnPatts) {
     writeBitSet(os, scp);
   }
 
-  streamWrite(os, d_synthons.size());
+  streamWrite(os, static_cast<std::uint64_t>(d_synthons.size()));
   for (const auto &rs : d_synthons) {
-    streamWrite(os, rs.size());
-    for (const auto &r : rs) {
-      r->writeToDBStream(os);
+    streamWrite(os, static_cast<std::uint64_t>(rs.size()));
+    for (const auto &[id, synthon] : rs) {
+      streamWrite(os, id);
+      streamWrite(os, synthon->getSmiles());
     }
   }
 
@@ -101,13 +99,9 @@ void SynthonSet::writeToDBStream(std::ostream &os) const {
   } else {
     streamWrite(os, false);
   }
-
-  streamWrite(os, d_synthonFPs.size());
-  for (const auto &fpv : d_synthonFPs) {
-    streamWrite(os, fpv.size());
-    for (const auto &fp : fpv) {
-      streamWrite(os, fp->toString());
-    }
+  streamWrite(os, static_cast<std::uint64_t>(d_numConnectors.size()));
+  for (const auto &c : d_numConnectors) {
+    streamWrite(os, c);
   }
 }
 
@@ -124,73 +118,74 @@ void readBitSet(std::istream &is, boost::dynamic_bitset<> &bitset) {
 }
 }  // namespace
 
-void SynthonSet::readFromDBStream(std::istream &is, std::uint32_t version) {
+void SynthonSet::readFromDBStream(std::istream &is, const SynthonSpace &space,
+                                  std::uint32_t version) {
+  PRECONDITION(version >= 3000, "Binary database version no longer supported.");
   streamRead(is, d_id, 0);
-  size_t numConnRegs;
+  std::uint64_t numConnRegs;
   streamRead(is, numConnRegs);
   d_connectorRegions.resize(numConnRegs);
-  for (size_t i = 0; i < numConnRegs; ++i) {
+  d_connRegSmis.resize(numConnRegs);
+  for (std::uint64_t i = 0; i < numConnRegs; ++i) {
     d_connectorRegions[i] = std::make_unique<ROMol>();
     MolPickler::molFromPickle(is, *d_connectorRegions[i]);
+    d_connRegSmis[i] = MolToSmiles(*d_connectorRegions[i]);
+  }
+  std::uint64_t numConnRegFPs;
+  streamRead(is, numConnRegFPs);
+  for (std::uint64_t i = 0; i < numConnRegFPs; ++i) {
+    std::string pickle;
+    streamRead(is, pickle, 0);
+    d_connRegFPs.push_back(std::make_unique<ExplicitBitVect>(pickle));
   }
-  std::string pickle;
-  streamRead(is, pickle, 0);
-  d_connRegFP = std::make_unique<ExplicitBitVect>(pickle);
   readBitSet(is, d_connectors);
-  if (version >= 2010) {
-    size_t numSynthConnPatts;
-    streamRead(is, numSynthConnPatts);
-    d_synthConnPatts.resize(numSynthConnPatts);
-    for (size_t i = 0; i < numSynthConnPatts; ++i) {
-      boost::dynamic_bitset<> synthConnPatt;
-      readBitSet(is, synthConnPatt);
-      d_synthConnPatts[i] = synthConnPatt;
-    }
+  std::uint64_t numSynthConnPatts;
+  streamRead(is, numSynthConnPatts);
+  d_synthConnPatts.resize(numSynthConnPatts);
+  for (std::uint64_t i = 0; i < numSynthConnPatts; ++i) {
+    boost::dynamic_bitset<> synthConnPatt;
+    readBitSet(is, synthConnPatt);
+    d_synthConnPatts[i] = synthConnPatt;
   }
 
-  size_t numRS;
+  std::uint64_t numRS;
   streamRead(is, numRS);
   d_synthons.clear();
-  for (size_t i = 0; i < numRS; ++i) {
-    size_t numR;
+  for (std::uint64_t i = 0; i < numRS; ++i) {
+    std::uint64_t numR;
     streamRead(is, numR);
     d_synthons.emplace_back();
     d_synthons[i].resize(numR);
-    for (size_t j = 0; j < numR; ++j) {
-      d_synthons[i][j] = std::make_unique<Synthon>();
-      d_synthons[i][j]->readFromDBStream(is);
+    for (std::uint64_t j = 0; j < numR; ++j) {
+      std::string synthonName;
+      streamRead(is, synthonName, 0);
+      std::string smiles;
+      streamRead(is, smiles, 0);
+      // The synthons should be in the pool by now.
+      if (auto synth = space.getSynthonFromPool(smiles); synth == nullptr) {
+        std::cout << "smiles " << smiles << " not in pool" << std::endl;
+        throw std::runtime_error("Database file " + space.getInputFileName() +
+                                 " appears corrupted.");
+      } else {
+        d_synthons[i][j] = std::pair(synthonName, synth);
+      }
     }
   }
 
-  if (version >= 2010) {
-    bool haveAddFP;
-    streamRead(is, haveAddFP);
-    if (haveAddFP) {
-      std::string fString;
-      streamRead(is, fString, 0);
-      d_addFP = std::make_unique<ExplicitBitVect>(fString);
-      streamRead(is, fString, 0);
-      d_subtractFP = std::make_unique<ExplicitBitVect>(fString);
-    }
+  bool haveAddFP;
+  streamRead(is, haveAddFP);
+  if (haveAddFP) {
+    std::string fString;
+    streamRead(is, fString, 0);
+    d_addFP = std::make_unique<ExplicitBitVect>(fString);
+    streamRead(is, fString, 0);
+    d_subtractFP = std::make_unique<ExplicitBitVect>(fString);
   }
-
-  size_t numFS;
-  streamRead(is, numFS);
-  d_synthonFPs.clear();
-  for (size_t i = 0; i < numFS; ++i) {
-    size_t numF;
-    streamRead(is, numF);
-    d_synthonFPs.emplace_back();
-    d_synthonFPs[i].resize(numF);
-    for (size_t j = 0; j < numF; ++j) {
-      std::string fString;
-      streamRead(is, fString, 0);
-      d_synthonFPs[i][j] = std::make_unique<ExplicitBitVect>(fString);
-    }
-  }
-  // So that d_synthConnPatts is filled in.
-  if (version < 2010) {
-    assignConnectorsUsed();
+  std::uint64_t numConns;
+  streamRead(is, numConns);
+  d_numConnectors.resize(numConns);
+  for (unsigned int i = 0; i < numConns; ++i) {
+    streamRead(is, d_numConnectors[i]);
   }
 }
 
@@ -208,12 +203,12 @@ void SynthonSet::enumerateToStream(std::ostream &os) const {
   }
 }
 
-void SynthonSet::addSynthon(const int synthonSetNum,
-                            std::unique_ptr<Synthon> newSynthon) {
+void SynthonSet::addSynthon(const int synthonSetNum, Synthon *newSynthon,
+                            const std::string &synthonId) {
   if (static_cast<size_t>(synthonSetNum) >= d_synthons.size()) {
     d_synthons.resize(synthonSetNum + 1);
   }
-  d_synthons[synthonSetNum].emplace_back(std::move(newSynthon));
+  d_synthons[synthonSetNum].push_back(std::make_pair(synthonId, newSynthon));
 }
 
 namespace {
@@ -223,10 +218,9 @@ namespace {
 // of synthon are assumed to be a single molecule, and each product is
 // a molecule made from the corresponding member of longVecNum and the first
 // element of the other vectors.
-
 std::vector<std::unique_ptr<ROMol>> buildSampleMolecules(
-    const std::vector<std::vector<ROMol *>> &synthons, const size_t longVecNum,
-    const SynthonSet &reaction) {
+    const std::vector<std::vector<std::unique_ptr<RWMol>>> &synthons,
+    const size_t longVecNum, const SynthonSet &reaction) {
   std::vector<std::unique_ptr<ROMol>> sampleMolecules;
   sampleMolecules.reserve(synthons[longVecNum].size());
 
@@ -253,11 +247,11 @@ std::vector<std::unique_ptr<ROMol>> buildSampleMolecules(
       for (size_t j = 0; j < synthons.size(); ++j) {
         std::string sep = j ? " and " : " ";
         if (j == longVecNum) {
-          msg += sep + synths[j][i]->getId() + " (" +
-                 synths[j][i]->getSmiles() + ")";
+          msg += sep + synths[j][i].first + " (" +
+                 synths[j][i].second->getSmiles() + ")";
         } else {
-          msg += sep + synths[j].front()->getId() + " (" +
-                 synths[j].front()->getSmiles() + ")";
+          msg += sep + synths[j].front().first + " (" +
+                 synths[j].front().second->getSmiles() + ")";
         }
       }
       msg += "\n" + std::string(e.what()) + "\n";
@@ -267,91 +261,74 @@ std::vector<std::unique_ptr<ROMol>> buildSampleMolecules(
   }
   return sampleMolecules;
 }
-
-// transfer information for bonds created by molzip
-void fixSynthonAtomAndBond(const Atom *sampleMolAtom, const Bond *bond,
-                           RWMol &synthCp) {
-  PRECONDITION(sampleMolAtom, "No atom passed in.");
-  PRECONDITION(bond, "No bond passed in.");
-  const auto synthAt =
-      synthCp.getAtomWithIdx(sampleMolAtom->getProp<int>("idx"));
-  for (const auto nbor : synthCp.atomNeighbors(synthAt)) {
-    if (!nbor->getAtomicNum() && nbor->getIsotope() <= MAX_CONNECTOR_NUM) {
-      nbor->setIsAromatic(sampleMolAtom->getIsAromatic());
-      const auto synthBond =
-          synthCp.getBondBetweenAtoms(synthAt->getIdx(), nbor->getIdx());
-      synthBond->setIsAromatic(bond->getIsAromatic());
-      synthBond->setBondType(bond->getBondType());
-    }
-  }
-}
 }  // namespace
 
-void SynthonSet::transferProductBondsToSynthons() {
-  // Each synthon is built into a product and the atoms and bonds tracked.
-  // Properties of the atoms and bonds are mapped back from the products
-  // onto the synthons.  This way, when a query molecule is split up, the
-  // fragments should be consistent with those of the corresponding synthons.
-  tagSynthonAtomsAndBonds();
+void SynthonSet::makeSynthonSearchMols() {
+  // Each synthon is built into a product and then split on the
+  // newly formed bonds.  The fragment from the original synthon of
+  // interest is then stored as the synthon searchMol.  This way,
+  // when a query molecule is split up, the fragments should be
+  // consistent with those of the corresponding synthons.
 
-  std::vector<std::vector<ROMol *>> synthonMolCopies(d_synthons.size());
+  // Synthons are shared, so we need to copy the molecules into a new
+  // set that we can fiddle with without upsetting anything else.
+  std::vector<std::vector<std::unique_ptr<RWMol>>> synthonMolCopies(
+      d_synthons.size());
   for (size_t i = 0; i < d_synthons.size(); ++i) {
     synthonMolCopies[i].reserve(d_synthons[i].size());
     for (size_t j = 0; j < d_synthons[i].size(); ++j) {
-      synthonMolCopies[i].emplace_back(d_synthons[i][j]->getOrigMol().get());
+      synthonMolCopies[i].emplace_back(
+          new RWMol(*d_synthons[i][j].second->getOrigMol().get()));
+      for (auto &atom : synthonMolCopies[i][j]->atoms()) {
+        atom->setProp<int>("molNum", i);
+        atom->setProp<int>("idx", atom->getIdx());
+      }
+      for (auto &bond : synthonMolCopies[i][j]->bonds()) {
+        bond->setProp<int>("molNum", i);
+        bond->setProp<int>("idx", bond->getIdx());
+      }
     }
   }
 
+  std::vector<std::pair<unsigned int, unsigned int>> dummyLabels;
+  for (unsigned int i = 1; i <= MAX_CONNECTOR_NUM; ++i) {
+    dummyLabels.emplace_back(i, i);
+  }
+
   // Now build sets of sample molecules using each synthon set in turn.
   for (size_t synthSetNum = 0; synthSetNum < d_synthons.size(); ++synthSetNum) {
-    std::vector<boost::dynamic_bitset<>> synthsToUse(d_synthons.size());
-    for (size_t j = 0; j < d_synthons.size(); ++j) {
-      if (j == synthSetNum) {
-        synthsToUse[j] = boost::dynamic_bitset<>(d_synthons[j].size());
-        synthsToUse[j].set();
-      } else {
-        synthsToUse[j] = boost::dynamic_bitset<>(d_synthons[j].size());
-        synthsToUse[j][0] = true;
-      }
-    }
     auto sampleMols =
         buildSampleMolecules(synthonMolCopies, synthSetNum, *this);
     for (size_t j = 0; j < sampleMols.size(); ++j) {
-      auto synthCp =
-          std::make_unique<RWMol>(*d_synthons[synthSetNum][j]->getOrigMol());
-      // transfer the aromaticity of the atom in the sample molecule to the
-      // corresponding atom in the synthon copy
-      for (const auto &atom : sampleMols[j]->atoms()) {
-        if (const int molNum = atom->getProp<int>("molNum");
-            static_cast<size_t>(molNum) == synthSetNum) {
-          const int atIdx = atom->getProp<int>("idx");
-          synthCp->getAtomWithIdx(atIdx)->setIsAromatic(atom->getIsAromatic());
-        }
-      }
-      // likewise for the bonds, but not all bonds will have the tags,
-      // because some are formed by molzip.
+      std::vector<unsigned int> splitBonds;
       for (const auto &bond : sampleMols[j]->bonds()) {
-        if (bond->hasProp("molNum")) {
-          if (const int molNum = bond->getProp<int>("molNum");
-              static_cast<size_t>(molNum) == synthSetNum) {
-            const int bondIdx = bond->getProp<int>("idx");
-            const auto sbond = synthCp->getBondWithIdx(bondIdx);
-            sbond->setIsAromatic(bond->getIsAromatic());
-            sbond->setBondType(bond->getBondType());
-          }
-        } else {
-          // it came from molzip, so in the synth, one end atom corresponds to
-          // an atom in sampleMol and the other end was a dummy.
-          if (static_cast<size_t>(bond->getBeginAtom()->getProp<int>(
-                  "molNum")) == synthSetNum) {
-            fixSynthonAtomAndBond(bond->getBeginAtom(), bond, *synthCp);
-          } else if (static_cast<size_t>(bond->getEndAtom()->getProp<int>(
-                         "molNum")) == synthSetNum) {
-            fixSynthonAtomAndBond(bond->getEndAtom(), bond, *synthCp);
-          }
+        if (!bond->hasProp("molNum")) {
+          splitBonds.push_back(bond->getIdx());
         }
       }
-      d_synthons[synthSetNum][j]->setSearchMol(std::move(synthCp));
+
+      const std::unique_ptr<ROMol> fragMol(MolFragmenter::fragmentOnBonds(
+          *sampleMols[j], splitBonds, true, &dummyLabels));
+      std::vector<std::unique_ptr<ROMol>> molFrags;
+      MolOps::getMolFrags(*fragMol, molFrags, false);
+      int fragWeWant = -1;
+      for (size_t i = 0; i < molFrags.size(); ++i) {
+        for (const auto &atom : molFrags[i]->atoms()) {
+          if (atom->hasProp("molNum") &&
+              atom->getProp<unsigned int>("molNum") == synthSetNum) {
+            fragWeWant = i;
+            break;
+          }
+        }
+        if (fragWeWant != -1) {
+          break;
+        }
+      }
+      unsigned int otf;
+      sanitizeMol(*static_cast<RWMol *>(molFrags[fragWeWant].get()), otf,
+                  MolOps::SANITIZE_SYMMRINGS);
+      d_synthons[synthSetNum][j].second->setSearchMol(
+          std::move(molFrags[fragWeWant]));
     }
   }
 }
@@ -359,7 +336,7 @@ void SynthonSet::transferProductBondsToSynthons() {
 void SynthonSet::removeEmptySynthonSets() {
   d_synthons.erase(
       std::remove_if(d_synthons.begin(), d_synthons.end(),
-                     [](const std::vector<std::unique_ptr<Synthon>> &r)
+                     [](const std::vector<std::pair<std::string, Synthon *>> &r)
                          -> bool { return r.empty(); }),
       d_synthons.end());
 }
@@ -368,29 +345,28 @@ void SynthonSet::buildConnectorRegions() {
   std::set<std::string> smis;
   for (const auto &rset : d_synthons) {
     for (const auto &r : rset) {
-      for (const auto &cr : r->getConnRegions()) {
+      for (const auto &cr : r.second->getConnRegions()) {
         if (auto smi = MolToSmiles(*cr); smis.insert(smi).second) {
           d_connectorRegions.push_back(cr);
+          d_connRegSmis.push_back(smi);
         }
       }
     }
   }
   if (!getConnectorRegions().empty()) {
-    d_connRegFP.reset(PatternFingerprintMol(*getConnectorRegions().front()));
-    for (size_t i = 1; i < getConnectorRegions().size(); ++i) {
+    d_connRegFPs.reserve(d_connectorRegions.size());
+    for (const auto &connReg : getConnectorRegions()) {
       std::unique_ptr<ExplicitBitVect> fp(
-          PatternFingerprintMol(*getConnectorRegions()[i]));
-      *d_connRegFP |= *fp;
+          PatternFingerprintMol(*connReg, PATT_FP_NUM_BITS));
+      d_connRegFPs.push_back(std::move(fp));
     }
-  } else {
-    d_connRegFP = std::make_unique<ExplicitBitVect>(2048);
   }
   // It should be the case that all synthons in a synthon set
   // have the same number of connections, so just do the 1st
   // one of each.
   for (const auto &synthonSet : d_synthons) {
     d_numConnectors.push_back(
-        details::countConnections(*synthonSet.front()->getOrigMol()));
+        details::countConnections(*synthonSet.front().second->getOrigMol()));
   }
 }
 
@@ -414,8 +390,8 @@ void SynthonSet::assignConnectorsUsed() {
     d_synthConnPatts.back().resize(MAX_CONNECTOR_NUM + 1, false);
     const auto &reag = synthSet.front();
     for (size_t i = 0; i < MAX_CONNECTOR_NUM; ++i) {
-      if (std::regex_search(reag->getSmiles(), connRegexs[2 * i]) ||
-          std::regex_search(reag->getSmiles(), connRegexs[2 * i + 1])) {
+      if (std::regex_search(reag.second->getSmiles(), connRegexs[2 * i]) ||
+          std::regex_search(reag.second->getSmiles(), connRegexs[2 * i + 1])) {
         d_connectors.set(i + 1);
         d_synthConnPatts.back().set(i + 1);
       }
@@ -427,7 +403,21 @@ const std::vector<int> &SynthonSet::getNumConnectors() const {
   return d_numConnectors;
 }
 
-bool SynthonSet::hasFingerprints() const { return !d_synthonFPs.empty(); }
+std::uint64_t SynthonSet::getNumProducts() const {
+  uint64_t thisSize = 1;
+  for (const auto &r : d_synthons) {
+    thisSize *= r.size();
+  }
+  return thisSize;
+}
+
+bool SynthonSet::hasFingerprints() const {
+  if (d_synthons.empty()) {
+    return false;
+  }
+  return static_cast<bool>(d_synthons.front().front().second->getFP());
+}
+
 bool SynthonSet::hasAddAndSubtractFPs() const {
   return static_cast<bool>(d_addFP);
 }
@@ -438,44 +428,45 @@ void SynthonSet::buildSynthonFingerprints(
   d_subtractFP.reset();
 
   // The synthons should have had transferProductBondsToSynthons
-  // applied to them by now.
-  d_synthonFPs.clear();
+  // applied to them by now, so that they have a searchMol.
 
-  d_synthonFPs.reserve(d_synthons.size());
   for (size_t synthSetNum = 0; synthSetNum < d_synthons.size(); ++synthSetNum) {
-    d_synthonFPs.emplace_back();
-    d_synthonFPs.back().reserve(d_synthons[synthSetNum].size());
     for (const auto &synth : d_synthons[synthSetNum]) {
-      d_synthonFPs[synthSetNum].emplace_back(
-          fpGen.getFingerprint(*synth->getSearchMol()));
+      if (ControlCHandler::getGotSignal()) {
+        return;
+      }
+      synth.second->setFP(std::unique_ptr<ExplicitBitVect>(
+          fpGen.getFingerprint(*synth.second->getSearchMol())));
     }
   }
 }
 
 void SynthonSet::buildAddAndSubtractFPs(
-    const FingerprintGenerator<std::uint64_t> &fpGen) {
+    const FingerprintGenerator<std::uint64_t> &fpGen, unsigned int numBits) {
+  PRECONDITION(hasFingerprints(), "No fingerprints for synthons.");
   d_addFP.reset();
   d_subtractFP.reset();
   std::vector<std::vector<size_t>> synthonNums(d_synthons.size());
   std::vector<size_t> numSynthons(d_synthons.size());
-  std::vector<int> naddbitcounts(fpGen.getOptions()->d_fpSize, 0);
-  std::vector<int> nsubbitcounts(fpGen.getOptions()->d_fpSize, 0);
+  std::vector<int> naddbitcounts(numBits, 0);
+  std::vector<int> nsubbitcounts(numBits, 0);
   size_t totSamples = 1;
   // Sample the synthons evenly across their size ranges.
   for (size_t i = 0; i < d_synthons.size(); ++i) {
-    std::vector<std::tuple<size_t, Synthon *>> sortedSynthons(
-        d_synthons[i].size());
+    std::vector<std::pair<size_t, std::pair<std::string, Synthon *>>>
+        sortedSynthons(d_synthons[i].size());
     for (size_t j = 0; j < d_synthons[i].size(); ++j) {
-      sortedSynthons[j] = std::make_tuple(j, d_synthons[i][j].get());
+      sortedSynthons[j] = std::make_pair(j, d_synthons[i][j]);
     }
     std::sort(sortedSynthons.begin(), sortedSynthons.end(),
-              [](const std::tuple<size_t, Synthon *> &a,
-                 const std::tuple<size_t, Synthon *> &b) -> bool {
-                auto as = std::get<1>(a);
-                auto bs = std::get<1>(b);
+              [](const std::pair<size_t, std::pair<std::string, Synthon *>> &a,
+                 const std::pair<size_t, std::pair<std::string, Synthon *>> &b)
+                  -> bool {
+                auto as = a.second.second;
+                auto bs = b.second.second;
                 if (as->getOrigMol()->getNumAtoms() ==
                     bs->getOrigMol()->getNumAtoms()) {
-                  return as->getId() < bs->getId();
+                  return a.second.first < b.second.first;
                 }
                 return as->getOrigMol()->getNumAtoms() <
                        bs->getOrigMol()->getNumAtoms();
@@ -493,14 +484,17 @@ void SynthonSet::buildAddAndSubtractFPs(
   details::Stepper stepper(numSynthons);
   std::vector<size_t> theseSynthNums(synthonNums.size(), 0);
   while (stepper.d_currState[0] != numSynthons[0]) {
+    if (ControlCHandler::getGotSignal()) {
+      return;
+    }
     for (size_t i = 0; i < stepper.d_currState.size(); ++i) {
       theseSynthNums[i] = synthonNums[i][stepper.d_currState[i]];
     }
     auto prod = buildProduct(theseSynthNums);
     std::unique_ptr<ExplicitBitVect> prodFP(fpGen.getFingerprint(*prod));
-    ExplicitBitVect approxFP(*d_synthonFPs[0][theseSynthNums[0]]);
-    for (size_t j = 1; j < d_synthonFPs.size(); ++j) {
-      approxFP |= *d_synthonFPs[j][theseSynthNums[j]];
+    ExplicitBitVect approxFP(*d_synthons[0][theseSynthNums[0]].second->getFP());
+    for (size_t j = 1; j < d_synthons.size(); ++j) {
+      approxFP |= *d_synthons[j][theseSynthNums[j]].second->getFP();
     }
     // addFP is what's in the productFP and not in approxFP
     // and subtractFP is vice versa.  The former captures the bits of
@@ -525,14 +519,13 @@ void SynthonSet::buildAddAndSubtractFPs(
   // This is the fraction of products that must set a bit for
   // it to be included.  Arrived at by empirical means.
   double frac = 0.75;
-  d_addFP = std::make_unique<ExplicitBitVect>(fpGen.getOptions()->d_fpSize);
+  d_addFP = std::make_unique<ExplicitBitVect>(numBits);
   for (size_t i = 0; i < naddbitcounts.size(); ++i) {
     if (naddbitcounts[i] > int(totSamples * frac)) {
       d_addFP->setBit(i);
     }
   }
-  d_subtractFP =
-      std::make_unique<ExplicitBitVect>(fpGen.getOptions()->d_fpSize);
+  d_subtractFP = std::make_unique<ExplicitBitVect>(numBits);
   for (size_t i = 0; i < nsubbitcounts.size(); ++i) {
     if (nsubbitcounts[i] > int(totSamples * frac)) {
       d_subtractFP->setBit(i);
@@ -545,36 +538,20 @@ void SynthonSet::buildAddAndSubtractFPs(
 
 std::string SynthonSet::buildProductName(
     const std::vector<size_t> &synthNums) const {
-  std::string prodName = d_id;
+  std::vector<std::string> synths(synthNums.size());
   for (size_t i = 0; i < synthNums.size(); ++i) {
-    prodName += "_" + d_synthons[i][synthNums[i]]->getId();
+    synths[i] = d_synthons[i][synthNums[i]].first;
   }
-  return prodName;
+  return details::buildProductName(d_id, synths);
 }
 
 std::unique_ptr<ROMol> SynthonSet::buildProduct(
     const std::vector<size_t> &synthNums) const {
-  MolzipParams mzparams;
-  mzparams.label = MolzipLabel::Isotope;
-
-  auto prodMol = std::make_unique<ROMol>(
-      *d_synthons.front()[synthNums.front()]->getOrigMol().get());
-  for (size_t i = 1; i < synthNums.size(); ++i) {
-    prodMol.reset(
-        combineMols(*prodMol, *d_synthons[i][synthNums[i]]->getOrigMol()));
-  }
-  prodMol = molzip(*prodMol, mzparams);
-  MolOps::sanitizeMol(*dynamic_cast<RWMol *>(prodMol.get()));
-
-  return prodMol;
-}
-
-void SynthonSet::tagSynthonAtomsAndBonds() const {
-  for (size_t i = 0; i < d_synthons.size(); ++i) {
-    for (auto &syn : d_synthons[i]) {
-      syn->tagAtomsAndBonds(static_cast<int>(i));
-    }
+  std::vector<const ROMol *> synths(synthNums.size());
+  for (size_t i = 0; i < synthNums.size(); ++i) {
+    synths[i] = d_synthons[i][synthNums[i]].second->getOrigMol().get();
   }
+  return details::buildProduct(synths);
 }
 
 }  // namespace RDKit::SynthonSpaceSearch
\ No newline at end of file
