@@ -12,6 +12,7 @@
 #include "new_canon.h"
 #include <GraphMol/RDKitBase.h>
 #include <GraphMol/QueryOps.h>
+#include <GraphMol/Atropisomers.h>
 #include <cstdint>
 #include <cstring>
 #include <iostream>
@@ -267,8 +268,7 @@ void rankWithFunctor(T &ftor, bool breakTies, int *order, bool useSpecial,
 #ifdef VERBOSE_CANON
   std::cerr << "1--------" << std::endl;
   for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
-    std::cerr << order[i] + 1 << " "
-              << " index: " << atoms[order[i]].index
+    std::cerr << order[i] + 1 << " " << " index: " << atoms[order[i]].index
               << " count: " << count[order[i]] << std::endl;
   }
 #endif
@@ -278,8 +278,7 @@ void rankWithFunctor(T &ftor, bool breakTies, int *order, bool useSpecial,
 #ifdef VERBOSE_CANON
   std::cerr << "1a--------" << std::endl;
   for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
-    std::cerr << order[i] + 1 << " "
-              << " index: " << atoms[order[i]].index
+    std::cerr << order[i] + 1 << " " << " index: " << atoms[order[i]].index
               << " count: " << count[order[i]] << std::endl;
   }
 #endif
@@ -288,8 +287,7 @@ void rankWithFunctor(T &ftor, bool breakTies, int *order, bool useSpecial,
 #ifdef VERBOSE_CANON
   std::cerr << "2--------" << std::endl;
   for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
-    std::cerr << order[i] + 1 << " "
-              << " index: " << atoms[order[i]].index
+    std::cerr << order[i] + 1 << " " << " index: " << atoms[order[i]].index
               << " count: " << count[order[i]] << std::endl;
   }
 #endif
@@ -309,8 +307,7 @@ void rankWithFunctor(T &ftor, bool breakTies, int *order, bool useSpecial,
 #ifdef VERBOSE_CANON
     std::cerr << "2a--------" << std::endl;
     for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
-      std::cerr << order[i] + 1 << " "
-                << " index: " << atoms[order[i]].index
+      std::cerr << order[i] + 1 << " " << " index: " << atoms[order[i]].index
                 << " count: " << count[order[i]] << std::endl;
     }
 #endif
@@ -348,8 +345,7 @@ void rankWithFunctor(T &ftor, bool breakTies, int *order, bool useSpecial,
 #ifdef VERBOSE_CANON
     std::cerr << "2b--------" << std::endl;
     for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
-      std::cerr << order[i] + 1 << " "
-                << " index: " << atoms[order[i]].index
+      std::cerr << order[i] + 1 << " " << " index: " << atoms[order[i]].index
                 << " count: " << count[order[i]] << std::endl;
     }
 #endif
@@ -360,8 +356,7 @@ void rankWithFunctor(T &ftor, bool breakTies, int *order, bool useSpecial,
 #ifdef VERBOSE_CANON
     std::cerr << "3--------" << std::endl;
     for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
-      std::cerr << order[i] + 1 << " "
-                << " index: " << atoms[order[i]].index
+      std::cerr << order[i] + 1 << " " << " index: " << atoms[order[i]].index
                 << " count: " << count[order[i]] << std::endl;
     }
 #endif
@@ -430,6 +425,39 @@ bondholder makeBondHolder(const Bond *bond, unsigned int otherIdx,
         }
       }
     }
+
+    if (res.stype == Bond::BondStereo::STEREOATROPCCW ||
+        res.stype == Bond::BondStereo::STEREOATROPCW) {
+      Atropisomers::AtropAtomAndBondVec atropAtomAndBondVecs[2];
+      CHECK_INVARIANT(Atropisomers::getAtropisomerAtomsAndBonds(
+                          bond, atropAtomAndBondVecs, bond->getOwningMol()),
+                      "Could not find atropisomer controlling atoms")
+
+      res.controllingAtoms[0] =
+          &atoms[atropAtomAndBondVecs[0]
+                     .second[0]
+                     ->getOtherAtom(atropAtomAndBondVecs[0].first)
+                     ->getIdx()];
+      res.controllingAtoms[2] =
+          &atoms[atropAtomAndBondVecs[1]
+                     .second[0]
+                     ->getOtherAtom(atropAtomAndBondVecs[1].first)
+                     ->getIdx()];
+      if (atropAtomAndBondVecs[0].second.size() > 1) {
+        res.controllingAtoms[1] =
+            &atoms[atropAtomAndBondVecs[0]
+                       .second[1]
+                       ->getOtherAtom(atropAtomAndBondVecs[0].first)
+                       ->getIdx()];
+      }
+      if (atropAtomAndBondVecs[1].second.size() > 1) {
+        res.controllingAtoms[3] =
+            &atoms[atropAtomAndBondVecs[1]
+                       .second[1]
+                       ->getOtherAtom(atropAtomAndBondVecs[1].first)
+                       ->getIdx()];
+      }
+    }
   }
   return res;
 }
@@ -535,14 +563,14 @@ void advancedInitCanonAtom(const ROMol &mol, Canon::canon_atom &atom,
 }  // end anonymous namespace
 
 void initCanonAtoms(const ROMol &mol, std::vector<Canon::canon_atom> &atoms,
-                    bool includeChirality) {
+                    bool includeChirality, bool includeStereoGroups) {
   for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
     basicInitCanonAtom(mol, atoms[i], i);
     advancedInitCanonAtom(mol, atoms[i], i);
     atoms[i].bonds.reserve(atoms[i].degree);
     getBonds(mol, atoms[i].atom, atoms[i].bonds, includeChirality, atoms);
   }
-  if (includeChirality) {
+  if (includeChirality && includeStereoGroups) {
     unsigned int sgidx = 1;
     for (auto &sg : mol.getStereoGroups()) {
       for (auto atom : sg.getAtoms()) {
@@ -662,7 +690,7 @@ void updateAtomNeighborIndex(canon_atom *atoms, std::vector<bondholder> &nbrs) {
 // This routine calculates the number of swaps that would be required to
 // determine what the smiles chirality value would be for a given chiral atom
 // given that the atom is visited first from the atom of interest.
-// THis is used to determine which of two atoms has priority based on the
+// This is used to determine which of two atoms has priority based on the
 // neighbor's chirality
 //
 // If the chiral neighbor has two equivlent (at least so far) neighbors that are
@@ -730,24 +758,29 @@ void updateAtomNeighborNumSwaps(
 }
 
 void rankMolAtoms(const ROMol &mol, std::vector<unsigned int> &res,
-                  bool breakTies, bool includeChirality, bool includeIsotopes) {
+                  bool breakTies, bool includeChirality, bool includeIsotopes,
+                  bool includeAtomMaps, bool includeChiralPresence,
+                  bool includeStereoGroups, bool useNonStereoRanks) {
   if (!mol.getNumAtoms()) {
     return;
   }
 
   bool clearRings = false;
-  if (!mol.getRingInfo()->isInitialized()) {
+  if (!mol.getRingInfo()->isFindFastOrBetter()) {
     MolOps::fastFindRings(mol);
     clearRings = true;
   }
   res.resize(mol.getNumAtoms());
 
   std::vector<Canon::canon_atom> atoms(mol.getNumAtoms());
-  initCanonAtoms(mol, atoms, includeChirality);
+  initCanonAtoms(mol, atoms, includeChirality, includeStereoGroups);
   AtomCompareFunctor ftor(&atoms.front(), mol);
   ftor.df_useIsotopes = includeIsotopes;
   ftor.df_useChirality = includeChirality;
   ftor.df_useChiralityRings = includeChirality;
+  ftor.df_useAtomMaps = includeAtomMaps;
+  ftor.df_useNonStereoRanks = useNonStereoRanks;
+  ftor.df_useChiralPresence = includeChiralPresence;
 
   auto order = std::make_unique<int[]>(mol.getNumAtoms());
   detail::rankWithFunctor(ftor, breakTies, order.get(), true, includeChirality);
@@ -767,7 +800,8 @@ void rankFragmentAtoms(const ROMol &mol, std::vector<unsigned int> &res,
                        const std::vector<std::string> *atomSymbols,
                        const std::vector<std::string> *bondSymbols,
                        bool breakTies, bool includeChirality,
-                       bool includeIsotopes) {
+                       bool includeIsotopes, bool includeAtomMaps,
+                       bool includeChiralPresence) {
   PRECONDITION(atomsInPlay.size() == mol.getNumAtoms(), "bad atomsInPlay size");
   PRECONDITION(bondsInPlay.size() == mol.getNumBonds(), "bad bondsInPlay size");
   PRECONDITION(!atomSymbols || atomSymbols->size() == mol.getNumAtoms(),
@@ -780,7 +814,7 @@ void rankFragmentAtoms(const ROMol &mol, std::vector<unsigned int> &res,
   }
 
   bool clearRings = false;
-  if (!mol.getRingInfo()->isInitialized()) {
+  if (!mol.getRingInfo()->isFindFastOrBetter()) {
     MolOps::fastFindRings(mol);
     clearRings = true;
   }
@@ -793,6 +827,9 @@ void rankFragmentAtoms(const ROMol &mol, std::vector<unsigned int> &res,
   AtomCompareFunctor ftor(&atoms.front(), mol, &atomsInPlay, &bondsInPlay);
   ftor.df_useIsotopes = includeIsotopes;
   ftor.df_useChirality = includeChirality;
+  ftor.df_useAtomMaps = includeAtomMaps;
+  ftor.df_useChiralityRings = includeChirality;
+  ftor.df_useChiralPresence = includeChiralPresence;
 
   auto order = std::make_unique<int[]>(mol.getNumAtoms());
   detail::rankWithFunctor(ftor, breakTies, order.get(), true, includeChirality,
@@ -813,7 +850,7 @@ void chiralRankMolAtoms(const ROMol &mol, std::vector<unsigned int> &res) {
   }
 
   bool clearRings = false;
-  if (!mol.getRingInfo()->isInitialized()) {
+  if (!mol.getRingInfo()->isFindFastOrBetter()) {
     MolOps::fastFindRings(mol);
     clearRings = true;
   }
