@@ -416,8 +416,9 @@ void testQueryQueryMatches() {
   {
     QueryAtom a1;
     std::string excStr;
+    std::unique_ptr<ATOM_EQUALS_QUERY> q(makeAtomNumQuery(7));
     try {
-      a1.expandQuery(makeAtomNumQuery(7), Queries::COMPOSITE_OR);
+      a1.expandQuery(q.get(), Queries::COMPOSITE_OR);
     } catch (std::exception &e) {
       excStr = e.what();
     }
