@@ -719,10 +719,12 @@ void testIssue3316407() {
     MolPickler::molFromPickle(pickle, *m2);
     TEST_ASSERT(m2->getNumAtoms() == 5);
     for (unsigned int i = 0; i < m->getNumAtoms(); ++i) {
-      TEST_ASSERT(m->getAtomWithIdx(i)->getExplicitValence() ==
-                  m2->getAtomWithIdx(i)->getExplicitValence());
-      TEST_ASSERT(m->getAtomWithIdx(i)->getImplicitValence() ==
-                  m2->getAtomWithIdx(i)->getImplicitValence());
+      TEST_ASSERT(
+          m->getAtomWithIdx(i)->getValence(Atom::ValenceType::EXPLICIT) ==
+          m2->getAtomWithIdx(i)->getValence(Atom::ValenceType::EXPLICIT));
+      TEST_ASSERT(
+          m->getAtomWithIdx(i)->getValence(Atom::ValenceType::IMPLICIT) ==
+          m2->getAtomWithIdx(i)->getValence(Atom::ValenceType::IMPLICIT));
     }
     // part of sf.net issue 285:
     TEST_ASSERT(m2->getAtomWithIdx(3)->hasProp(common_properties::dummyLabel));
