@@ -152,7 +152,6 @@ void InitLogs() {
 std::ostream &toStream(std::ostream &logstrm) {
   char buffer[16];
   time_t t = time(nullptr);
-  struct tm *tm;
 // localtime() is thread safe on windows, but not on *nix
 #ifdef WIN32
   strftime(buffer, 16, "[%T] ", localtime(&t));
@@ -229,25 +228,3 @@ void InitLogs() {
 
 }  // namespace RDLog
 #endif
-
-namespace RDLog {
-
-BlockLogs::BlockLogs() {
-  auto logs = {rdDebugLog, rdInfoLog, rdWarningLog, rdErrorLog};
-  for (auto log : logs) {
-    if (log != nullptr && is_log_enabled(log)) {
-      log->df_enabled = false;
-      logs_to_reenable.push_back(log);
-    }
-  }
-}
-
-BlockLogs::~BlockLogs() {
-  for (auto log : logs_to_reenable) {
-    if (log != nullptr && log.get() != nullptr) {
-      log->df_enabled = true;
-    }
-  }
-}
-
-}  // namespace RDLog
