@@ -1,6 +1,5 @@
 //
-// Copyright 2001-2008 Randal M. Henne, Greg Landrum and
-//                     Rational Discovery LLC
+// Copyright 2001-2025 Randal M. Henne and other RDKit contributors
 //
 //  @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -10,7 +9,7 @@
 //
 //
 
-#include <RDGeneral/test.h>
+#include <catch2/catch_all.hpp>
 #include "types.h"
 #include "StreamOps.h"
 #include <RDGeneral/Invariant.h>
@@ -30,13 +29,10 @@ struct Foo {
   float baz{0.f};
   Foo() {}
   Foo(int bar, float baz) : bar(bar), baz(baz) {}
-  ~Foo() { std::cerr << "deleted!" << std::endl; }
+  ~Foo() {}
 };
 
-void testGithub940() {
-  BOOST_LOG(rdErrorLog)
-      << "Testing Github940: property dictionaries leaking memory" << std::endl;
-
+TEST_CASE("testGithub940") {
   // a couple small tests to check for memory leaks. Only useful with valgrind
   {  // tests computed props
     STR_VECT computed;
@@ -55,12 +51,12 @@ void testGithub940() {
     d->clearVal(RDKit::detail::computedPropName);
     delete d;
   }
-  BOOST_LOG(rdErrorLog) << "\tdone" << std::endl;
 }
 
-void testRDAny() {
-  std::cerr << "Testing RDValue" << std::endl;
-  { RDAny v(-2147450880); }
+TEST_CASE("testRDValue") {
+  {
+    RDAny v(-2147450880);
+  }
 
   {
     int vi = 0;
@@ -68,36 +64,35 @@ void testRDAny() {
     for (int i = 0; i < 100; ++i) {
       vi += i;
       v = rdvalue_cast<int>(v) + i;
-      TEST_ASSERT(vi == rdvalue_cast<int>(v));
+      REQUIRE(vi == rdvalue_cast<int>(v));
     }
   }
-  std::cerr << "Testing RDAny" << std::endl;
   {
     RDAny a(1);
     RDAny b = a;
-    TEST_ASSERT(rdany_cast<int>(a) == 1);
-    TEST_ASSERT(rdany_cast<int>(b) == 1);
+    REQUIRE(rdany_cast<int>(a) == 1);
+    REQUIRE(rdany_cast<int>(b) == 1);
   }
 
   {
     RDAny a(1);
     RDAny b = a;
-    TEST_ASSERT(rdany_cast<int>(a) == 1);
-    TEST_ASSERT(rdany_cast<int>(b) == rdany_cast<int>(a));
+    REQUIRE(rdany_cast<int>(a) == 1);
+    REQUIRE(rdany_cast<int>(b) == rdany_cast<int>(a));
     std::map<std::string, RDAny> foo;
     foo["foo"] = a;
     foo["bar"] = std::string("This is a test");
-    TEST_ASSERT(rdany_cast<int>(foo["foo"]) == 1);
-    TEST_ASSERT(rdany_cast<int>(foo["foo"]) == rdany_cast<int>(a));
-    TEST_ASSERT(rdany_cast<std::string>(foo["bar"]) == "This is a test");
+    REQUIRE(rdany_cast<int>(foo["foo"]) == 1);
+    REQUIRE(rdany_cast<int>(foo["foo"]) == rdany_cast<int>(a));
+    REQUIRE(rdany_cast<std::string>(foo["bar"]) == "This is a test");
   }
 
   {
     bool a = true;
     RDValue v(a);
-    TEST_ASSERT(rdvalue_cast<bool>(v) == true);
+    REQUIRE(rdvalue_cast<bool>(v) == true);
     v = (int)10;
-    TEST_ASSERT(rdvalue_cast<int>(v) == 10);
+    REQUIRE(rdvalue_cast<int>(v) == 10);
   }
 
   {
@@ -114,39 +109,29 @@ void testRDAny() {
     computed.push_back("foo");
     d.setVal(RDKit::detail::computedPropName, computed);
     STR_VECT computed2 = d.getVal<STR_VECT>(RDKit::detail::computedPropName);
-    TEST_ASSERT(computed2[0] == "foo");
+    REQUIRE(computed2[0] == "foo");
     Dict d2(d);
     computed2 = d2.getVal<STR_VECT>(RDKit::detail::computedPropName);
-    TEST_ASSERT(computed2[0] == "foo");
+    REQUIRE(computed2[0] == "foo");
   }
 
   {
-    Dict d;
-    // int v=1;
-    // d.setVal("foo", v);
-    // TEST_ASSERT(d.getVal<int>("foo") == 1, "bad getval");
-
     std::vector<int> fooV;
     fooV.resize(3);
     fooV[0] = 1;
     fooV[1] = 2;
     fooV[2] = 3;
-    if (0) {
-      std::vector<int> fooV2;
-      std::cerr << "send int vect" << std::endl;
-      RDAny a(fooV);
-      std::cerr << "retrieve int vect" << std::endl;
-      fooV2 = rdany_cast<std::vector<int>>(a);
-      TEST_ASSERT(fooV == fooV2);
-    }
+    std::vector<int> fooV2;
+    RDAny a(fooV);
+    fooV2 = rdany_cast<std::vector<int>>(a);
+    REQUIRE(fooV == fooV2);
 
+    Dict d;
     {
       std::vector<int> fooV2;
-      std::cerr << "dict set int vect" << std::endl;
       d.setVal("bar", fooV);
-      std::cerr << "dict get int vect" << std::endl;
       d.getVal("bar", fooV2);
-      TEST_ASSERT(fooV == fooV2);
+      REQUIRE(fooV == fooV2);
     }
   }
 
@@ -161,9 +146,9 @@ void testRDAny() {
     RDAny baz(foo);
 
     for (int i = 0; i < 4; ++i) {
-      TEST_ASSERT(rdany_cast<std::vector<int>>(foo)[i] == i);
-      TEST_ASSERT(rdany_cast<std::vector<int>>(bar)[i] == i);
-      TEST_ASSERT(rdany_cast<std::vector<int>>(baz)[i] == i);
+      REQUIRE(rdany_cast<std::vector<int>>(foo)[i] == i);
+      REQUIRE(rdany_cast<std::vector<int>>(bar)[i] == i);
+      REQUIRE(rdany_cast<std::vector<int>>(baz)[i] == i);
     }
   }
 
@@ -176,13 +161,13 @@ void testRDAny() {
     RDAny foo(v);
 
     for (int i = 0; i < 4; ++i) {
-      TEST_ASSERT(rdany_cast<std::vector<double>>(foo)[i] == i);
+      REQUIRE(rdany_cast<std::vector<double>>(foo)[i] == i);
     }
 
     RDAny b = foo;
 
     for (int i = 0; i < 4; ++i) {
-      TEST_ASSERT(rdany_cast<std::vector<double>>(b)[i] == i);
+      REQUIRE(rdany_cast<std::vector<double>>(b)[i] == i);
     }
   }
 
@@ -272,17 +257,17 @@ void testRDAny() {
 
   {  // checks replacement with vector
     RDAny vv(2.0);
-    TEST_ASSERT(rdany_cast<double>(vv) == 2.0);
+    REQUIRE(rdany_cast<double>(vv) == 2.0);
 
     std::vector<int> vect;
     vect.push_back(1);
     vv = vect;
-    TEST_ASSERT(rdany_cast<std::vector<int>>(vv)[0] == 1);
+    REQUIRE(rdany_cast<std::vector<int>>(vv)[0] == 1);
 
     // tests copy
     RDAny vvv(vv);
 
-    TEST_ASSERT(rdany_cast<std::vector<int>>(vvv)[0] == 1);
+    REQUIRE(rdany_cast<std::vector<int>>(vvv)[0] == 1);
   }
 
   {
@@ -290,22 +275,27 @@ void testRDAny() {
     std::vector<std::pair<int, int>> pvect;
     pvect.push_back(std::make_pair<int, int>(2, 2));
     std::any any1(pvect);
-    std::any_cast<std::vector<std::pair<int, int>>>(any1);
-    std::any_cast<std::vector<std::pair<int, int>> &>(any1);
-    std::any_cast<const std::vector<std::pair<int, int>> &>(any1);
+    auto a1 = std::any_cast<std::vector<std::pair<int, int>>>(any1);
+    CHECK(a1.size() == pvect.size());
+    auto a2 = std::any_cast<std::vector<std::pair<int, int>> &>(any1);
+    CHECK(a2.size() == pvect.size());
+    auto a3 = std::any_cast<const std::vector<std::pair<int, int>> &>(any1);
+    CHECK(a3.size() == pvect.size());
 
     RDAny vv(pvect);
     auto &any = rdany_cast<std::any &>(vv);
-    std::any_cast<std::vector<std::pair<int, int>>>(any);
-    std::any_cast<std::vector<std::pair<int, int>> &>(any);
-    std::any_cast<const std::vector<std::pair<int, int>> &>(any);
+    auto a4 = std::any_cast<std::vector<std::pair<int, int>>>(any);
+    CHECK(a4.size() == pvect.size());
+    auto a5 = std::any_cast<std::vector<std::pair<int, int>> &>(any);
+    REQUIRE(a5.size() == pvect.size());
+    auto a6 = std::any_cast<const std::vector<std::pair<int, int>> &>(any);
+    REQUIRE(a6.size() == pvect.size());
 
     const std::vector<std::pair<int, int>> &pv =
         rdany_cast<std::vector<std::pair<int, int>>>(vv);
-    TEST_ASSERT(pv[0].first == 2);
+    REQUIRE(pv[0].first == 2);
     RDAny vvv(vv);
-    TEST_ASSERT(
-        (rdany_cast<std::vector<std::pair<int, int>>>(vvv)[0].first == 2));
+    REQUIRE((rdany_cast<std::vector<std::pair<int, int>>>(vvv)[0].first == 2));
   }
 
   {
@@ -314,16 +304,10 @@ void testRDAny() {
     p->push_back(100);
     RDAny v(p);
     RDAny vv(v);
-    try {
-      rdany_cast<std::vector<int>>(v);
-#ifndef UNSAFE_RDVALUE
-      PRECONDITION(0, "Should throw bad cast");
-#endif
-    } catch (std::bad_any_cast &) {
-    }
+    REQUIRE_THROWS_AS(rdany_cast<std::vector<int>>(v), std::bad_any_cast);
 
-    TEST_ASSERT((*rdany_cast<std::vector<int> *>(vv))[0] == 100);
-    TEST_ASSERT((*rdany_cast<std::vector<int> *>((const RDAny &)vv))[0] == 100);
+    REQUIRE((*rdany_cast<std::vector<int> *>(vv))[0] == 100);
+    REQUIRE((*rdany_cast<std::vector<int> *>((const RDAny &)vv))[0] == 100);
     delete p;
 
     auto *m = new std::map<int, int>();
@@ -331,7 +315,7 @@ void testRDAny() {
     RDAny mv(m);
     // leaks
     auto *anym = rdany_cast<std::map<int, int> *>(mv);
-    TEST_ASSERT(anym->find(0) != anym->end());
+    REQUIRE(anym->find(0) != anym->end());
     delete anym;
   }
 
@@ -342,9 +326,9 @@ void testRDAny() {
     p->push_back(100);
     RDAny v(p);
     RDAny vv(v);
-    TEST_ASSERT((*rdany_cast<vptr>(v))[0] == 100);
-    TEST_ASSERT((*rdany_cast<vptr>(vv))[0] == 100);
-    TEST_ASSERT((*rdany_cast<vptr>((const RDAny &)vv))[0] == 100);
+    REQUIRE((*rdany_cast<vptr>(v))[0] == 100);
+    REQUIRE((*rdany_cast<vptr>(vv))[0] == 100);
+    REQUIRE((*rdany_cast<vptr>((const RDAny &)vv))[0] == 100);
 
     typedef boost::shared_ptr<std::map<int, int>> mptr;
     mptr m(new std::map<int, int>());
@@ -352,10 +336,10 @@ void testRDAny() {
     RDAny mv(m);
     // leaks
     mptr anym = rdany_cast<mptr>(mv);
-    TEST_ASSERT(anym->find(0) != anym->end());
+    REQUIRE(anym->find(0) != anym->end());
 
     RDAny any3(boost::shared_ptr<Foo>(new Foo(1, 2.f)));
-    TEST_ASSERT(any3.m_value.getTag() == RDTypeTag::AnyTag);
+    REQUIRE(any3.m_value.getTag() == RDTypeTag::AnyTag);
   }
 }
 
@@ -373,9 +357,7 @@ class DictCon {
   Dict d;
 };
 
-void testStringVals() {
-  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdErrorLog) << "Testing String Pickle Roundtrips." << std::endl;
+TEST_CASE("testStringPickleRoundtrips") {
   {
     Dict d;
     std::string sv;
@@ -383,14 +365,14 @@ void testStringVals() {
     d.setVal("foo", sv);
     int iv;
     d.getVal("foo", iv);
-    TEST_ASSERT(iv == 1);
+    REQUIRE(iv == 1);
   }
   {
     Dict d;
     d.setVal("foo", "1");
     int iv;
     d.getVal("foo", iv);
-    TEST_ASSERT(iv == 1);
+    REQUIRE(iv == 1);
   }
   {
     Dict d;
@@ -399,7 +381,7 @@ void testStringVals() {
     d.setVal("foo", sv);
     double dv;
     d.getVal("foo", dv);
-    TEST_ASSERT(feq(dv, 1.3));
+    REQUIRE(feq(dv, 1.3));
   }
 
   {
@@ -408,17 +390,13 @@ void testStringVals() {
     d.setVal("foo", iv);
     std::string sv;
     d.getVal("foo", sv);
-    TEST_ASSERT(sv == "1");
+    REQUIRE(sv == "1");
     sv = d.getVal<std::string>("foo");
-    TEST_ASSERT(sv == "1");
+    REQUIRE(sv == "1");
   }
-
-  BOOST_LOG(rdErrorLog) << "\tdone" << std::endl;
 }
 
-void testVectToString() {
-  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdErrorLog) << "Testing conversion of vect to string." << std::endl;
+TEST_CASE("testVectToString") {
   {
     Dict d;
     std::vector<int> v;
@@ -427,7 +405,7 @@ void testVectToString() {
     d.setVal("foo", v);
     std::string sv;
     d.getVal("foo", sv);
-    TEST_ASSERT(sv == "[1,0]");
+    REQUIRE(sv == "[1,0]");
   }
   {
     Dict d;
@@ -437,9 +415,9 @@ void testVectToString() {
     d.setVal("foo", v);
     std::string sv;
     d.getVal("foo", sv);
-    TEST_ASSERT(sv == "[1,0]");
+    REQUIRE(sv == "[1,0]");
     sv = d.getVal<std::string>("foo");
-    TEST_ASSERT(sv == "[1,0]");
+    REQUIRE(sv == "[1,0]");
   }
   {
     Dict d;
@@ -449,9 +427,9 @@ void testVectToString() {
     d.setVal("foo", v);
     std::string sv;
     d.getVal("foo", sv);
-    TEST_ASSERT(sv == "[1.2,0]");
+    REQUIRE(sv == "[1.2,0]");
     sv = d.getVal<std::string>("foo");
-    TEST_ASSERT(sv == "[1.2,0]");
+    REQUIRE(sv == "[1.2,0]");
   }
   {
     Dict d;
@@ -461,24 +439,20 @@ void testVectToString() {
     d.setVal("foo", v);
     std::string sv;
     d.getVal("foo", sv);
-    TEST_ASSERT(sv == "[10001,0]");
+    REQUIRE(sv == "[10001,0]");
     sv = d.getVal<std::string>("foo");
-    TEST_ASSERT(sv == "[10001,0]");
+    REQUIRE(sv == "[10001,0]");
   }
-
-  BOOST_LOG(rdErrorLog) << "\tdone" << std::endl;
 }
 
-void testConstReturns() {
-  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdErrorLog) << "Testing returning const references." << std::endl;
+TEST_CASE("testConstReturns") {
   {
     std::string v = "foo";
     RDAny anyv(v);
 
     std::string tgt = rdany_cast<std::string>(anyv);
     const std::string &ctgt = rdany_cast<std::string>(anyv);
-    TEST_ASSERT(ctgt != "");
+    REQUIRE(ctgt != "");
   }
 
   {
@@ -488,7 +462,7 @@ void testConstReturns() {
 
     // const std::string nv=d.getVal<const std::string &>("foo");
     std::string nv = d.getVal<std::string>("foo");
-    TEST_ASSERT(nv == "foo");
+    REQUIRE(nv == "foo");
   }
 
   {
@@ -502,7 +476,6 @@ void testConstReturns() {
     std::clock_t start, end;
 
     double ls = 0;
-    BOOST_LOG(rdErrorLog) << "any cast" << std::endl;
     start = std::clock();
     for (int i = 0; i < nreps; ++i) {
       const std::string &nv = rdany_cast<std::string>(anyv);
@@ -514,7 +487,6 @@ void testConstReturns() {
                           << ls << std::endl;
 
     ls = 0;
-    BOOST_LOG(rdErrorLog) << "copy" << std::endl;
     start = std::clock();
     for (int i = 0; i < nreps; ++i) {
       std::string nv = rdany_cast<std::string>(anyv);
@@ -526,7 +498,6 @@ void testConstReturns() {
                           << ls << std::endl;
 
     ls = 0;
-    BOOST_LOG(rdErrorLog) << "ref" << std::endl;
     start = std::clock();
     for (int i = 0; i < nreps; ++i) {
       const std::string &nv = rdany_cast<std::string>(anyv);
@@ -538,7 +509,6 @@ void testConstReturns() {
                           << ls << std::endl;
 
     ls = 0;
-    BOOST_LOG(rdErrorLog) << "dict" << std::endl;
     start = std::clock();
     for (int i = 0; i < nreps; ++i) {
       const std::string &nv = d.getVal<std::string>("foo");
@@ -550,7 +520,6 @@ void testConstReturns() {
                           << ls << std::endl;
 
     ls = 0;
-    BOOST_LOG(rdErrorLog) << "ref with hasVal" << std::endl;
     start = std::clock();
     std::string k = "foo";
     for (int i = 0; i < nreps; ++i) {
@@ -566,14 +535,9 @@ void testConstReturns() {
 
     // std::string nv=d.getVal<std::string>("foo");
   }
-
-  BOOST_LOG(rdErrorLog) << "\tdone" << std::endl;
 }
 
-void testUpdate() {
-  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdErrorLog) << "Testing dict update." << std::endl;
-
+TEST_CASE("testUpdate") {
   {
     Dict d;
     std::string sv;
@@ -588,10 +552,10 @@ void testUpdate() {
 
     Dict d2;
     d2.update(d);
-    TEST_ASSERT(d.getVal<std::string>("foo") == d2.getVal<std::string>("foo"));
-    TEST_ASSERT(d.getVal<double>("foo2") == d2.getVal<double>("foo2"));
-    TEST_ASSERT(d.getVal<std::vector<int>>("foo3") ==
-                d2.getVal<std::vector<int>>("foo3"));
+    REQUIRE(d.getVal<std::string>("foo") == d2.getVal<std::string>("foo"));
+    REQUIRE(d.getVal<double>("foo2") == d2.getVal<double>("foo2"));
+    REQUIRE(d.getVal<std::vector<int>>("foo3") ==
+            d2.getVal<std::vector<int>>("foo3"));
   }
 
   {  // a few tests to make sure copying/updating with nonPOD data is ok
@@ -609,29 +573,28 @@ void testUpdate() {
       Dict d2;
       d2.setVal("foo", 1);
       d2.update(d, true);
-      TEST_ASSERT(d2.getVal<std::string>("foo") == "1.3");
-      TEST_ASSERT(d.getVal<double>("foo2") == d2.getVal<double>("foo2"));
-      TEST_ASSERT(d.getVal<std::vector<int>>("foo3") ==
-                  d2.getVal<std::vector<int>>("foo3"));
+      REQUIRE(d2.getVal<std::string>("foo") == "1.3");
+      REQUIRE(d.getVal<double>("foo2") == d2.getVal<double>("foo2"));
+      REQUIRE(d.getVal<std::vector<int>>("foo3") ==
+              d2.getVal<std::vector<int>>("foo3"));
     }
 
     {
       Dict d2 = d;
       d2.setVal("foo", 1);
-      TEST_ASSERT(1 == d2.getVal<int>("foo"));
-      TEST_ASSERT(d.getVal<double>("foo2") == d2.getVal<double>("foo2"));
-      TEST_ASSERT(d.getVal<std::vector<int>>("foo3") ==
-                  d2.getVal<std::vector<int>>("foo3"));
+      REQUIRE(1 == d2.getVal<int>("foo"));
+      REQUIRE(d.getVal<double>("foo2") == d2.getVal<double>("foo2"));
+      REQUIRE(d.getVal<std::vector<int>>("foo3") ==
+              d2.getVal<std::vector<int>>("foo3"));
     }
 
     {
       Dict d2(d);
-      TEST_ASSERT(d.getVal<double>("foo2") == d2.getVal<double>("foo2"));
-      TEST_ASSERT(d.getVal<std::vector<int>>("foo3") ==
-                  d2.getVal<std::vector<int>>("foo3"));
+      REQUIRE(d.getVal<double>("foo2") == d2.getVal<double>("foo2"));
+      REQUIRE(d.getVal<std::vector<int>>("foo3") ==
+              d2.getVal<std::vector<int>>("foo3"));
     }
   }
-  BOOST_LOG(rdErrorLog) << "\tdone" << std::endl;
 }
 
 class FooHandler : public CustomPropHandler {
@@ -666,7 +629,7 @@ class FooHandler : public CustomPropHandler {
   CustomPropHandler *clone() const override { return new FooHandler; }
 };
 
-void testCustomProps() {
+TEST_CASE("testCustomProps") {
   Foo f(1, 2.f);
   Dict d;
   d.setVal<Foo>("foo", f);
@@ -675,21 +638,21 @@ void testCustomProps() {
   std::vector<CustomPropHandler *> handlers = {&foo_handler,
                                                foo_handler.clone()};
   for (auto handler : handlers) {
-    TEST_ASSERT(handler->canSerialize(value));
+    REQUIRE(handler->canSerialize(value));
     RDValue bad_value = 1;
-    TEST_ASSERT(!handler->canSerialize(bad_value));
+    REQUIRE(!handler->canSerialize(bad_value));
     std::stringstream ss;
-    TEST_ASSERT(handler->write(ss, value));
+    REQUIRE(handler->write(ss, value));
     RDValue newValue;
-    TEST_ASSERT(handler->read(ss, newValue));
-    TEST_ASSERT(from_rdvalue<const Foo &>(newValue).bar == f.bar);
-    TEST_ASSERT(from_rdvalue<const Foo &>(newValue).baz == f.baz);
+    REQUIRE(handler->read(ss, newValue));
+    REQUIRE(from_rdvalue<const Foo &>(newValue).bar == f.bar);
+    REQUIRE(from_rdvalue<const Foo &>(newValue).baz == f.baz);
     newValue.destroy();
   }
   delete handlers[1];
 }
 
-void testGithub2910() {
+TEST_CASE("testGithub2910") {
   Dict d;
   d.setVal("foo", 1.0);
   d.clearVal("foo");
@@ -697,98 +660,85 @@ void testGithub2910() {
   d.clearVal("foo");
 }
 
-int main() {
-  RDLog::InitLogs();
-  testGithub940();
-
-  testRDAny();
+TEST_CASE("basics") {
   Dict d;
   INT_VECT fooV;
   fooV.resize(3);
-  BOOST_LOG(rdInfoLog) << "dict test" << std::endl;
-  TEST_ASSERT(!d.hasVal("foo"));
+  REQUIRE(!d.hasVal("foo"));
   int x = 1;
   d.setVal("foo", x);
-  TEST_ASSERT(d.hasVal("foo"));
-  TEST_ASSERT(!d.hasVal("bar"));
+  REQUIRE(d.hasVal("foo"));
+  REQUIRE(!d.hasVal("bar"));
   int v, v2;
   d.getVal("foo", v);
-  TEST_ASSERT(v == 1);
+  REQUIRE(v == 1);
   v2 = d.getVal<int>("foo");
-  TEST_ASSERT(v2 == v);
+  REQUIRE(v2 == v);
   d.setVal("bar", fooV);
   d.getVal("foo", v);
-  TEST_ASSERT(v == 1);
+  REQUIRE(v == 1);
   v2 = d.getVal<int>("foo");
-  TEST_ASSERT(v2 == v);
+  REQUIRE(v2 == v);
   INT_VECT fooV2, fooV3;
   d.getVal("bar", fooV2);
   fooV3 = d.getVal<INT_VECT>("bar");
-  TEST_ASSERT(fooV == fooV2);
-  TEST_ASSERT(fooV2 == fooV3);
+  REQUIRE(fooV == fooV2);
+  REQUIRE(fooV2 == fooV3);
 
   VECT_INT_VECT fooV4;
   fooV4.resize(3);
-  TEST_ASSERT(!d.hasVal("baz"));
+  REQUIRE(!d.hasVal("baz"));
   d.setVal("baz", fooV4);
-  TEST_ASSERT(d.hasVal("baz"));
+  REQUIRE(d.hasVal("baz"));
 
   DictCon dc1;
-  TEST_ASSERT(!dc1.getDict()->hasVal("foo"));
+  REQUIRE(!dc1.getDict()->hasVal("foo"));
   int y = 1;
   dc1.getDict()->setVal("foo", y);
-  TEST_ASSERT(dc1.getDict()->hasVal("foo"));
-  TEST_ASSERT(!dc1.getDict()->hasVal("bar"));
+  REQUIRE(dc1.getDict()->hasVal("foo"));
+  REQUIRE(!dc1.getDict()->hasVal("bar"));
   dc1.getDict()->setVal("bar", fooV);
   dc1.getDict()->getVal("foo", v);
-  TEST_ASSERT(v == 1);
+  REQUIRE(v == 1);
   dc1.getDict()->getVal("bar", fooV2);
-  TEST_ASSERT(fooV == fooV2);
+  REQUIRE(fooV == fooV2);
   fooV4.resize(3);
-  TEST_ASSERT(!dc1.getDict()->hasVal("baz"));
+  REQUIRE(!dc1.getDict()->hasVal("baz"));
   dc1.getDict()->setVal("baz", fooV4);
-  TEST_ASSERT(dc1.getDict()->hasVal("baz"));
+  REQUIRE(dc1.getDict()->hasVal("baz"));
 
   dc1.getDict()->reset();
 
   DictCon dc2 = dc1;
-  TEST_ASSERT(!dc2.getDict()->hasVal("foo"));
+  REQUIRE(!dc2.getDict()->hasVal("foo"));
   int z = 1;
   dc2.getDict()->setVal("foo", z);
-  TEST_ASSERT(dc2.getDict()->hasVal("foo"));
-  TEST_ASSERT(!dc2.getDict()->hasVal("bar"));
+  REQUIRE(dc2.getDict()->hasVal("foo"));
+  REQUIRE(!dc2.getDict()->hasVal("bar"));
   dc2.getDict()->setVal("bar", fooV);
   dc2.getDict()->getVal("foo", v);
-  TEST_ASSERT(v == 1);
+  REQUIRE(v == 1);
   dc2.getDict()->getVal("bar", fooV2);
-  TEST_ASSERT(fooV == fooV2);
+  REQUIRE(fooV == fooV2);
   fooV4.resize(3);
-  TEST_ASSERT(!dc2.getDict()->hasVal("baz"));
+  REQUIRE(!dc2.getDict()->hasVal("baz"));
   dc2.getDict()->setVal("baz", fooV4);
-  TEST_ASSERT(dc2.getDict()->hasVal("baz"));
+  REQUIRE(dc2.getDict()->hasVal("baz"));
 
   DictCon dc3(dc2);
-  TEST_ASSERT(dc3.getDict()->hasVal("foo"));
+  REQUIRE(dc3.getDict()->hasVal("foo"));
   dc3.getDict()->getVal("foo", v);
-  TEST_ASSERT(v == 1);
+  REQUIRE(v == 1);
   dc3.getDict()->getVal("bar", fooV2);
-  TEST_ASSERT(fooV == fooV2);
+  REQUIRE(fooV == fooV2);
   fooV4.resize(3);
-  TEST_ASSERT(dc3.getDict()->hasVal("baz"));
+  REQUIRE(dc3.getDict()->hasVal("baz"));
 
-  TEST_ASSERT(dc3.getDict()->hasVal("foo"));
+  REQUIRE(dc3.getDict()->hasVal("foo"));
   dc3.getDict()->getVal("foo", v);
-  TEST_ASSERT(v == 1);
+  REQUIRE(v == 1);
   dc3.getDict()->getVal("bar", fooV2);
-  TEST_ASSERT(fooV == fooV2);
+  REQUIRE(fooV == fooV2);
   fooV4.resize(3);
-  TEST_ASSERT(dc3.getDict()->hasVal("baz"));
-
-  testStringVals();
-  testVectToString();
-  testConstReturns();
-  testUpdate();
-  testCustomProps();
-  testGithub2910();
-  return 0;
+  REQUIRE(dc3.getDict()->hasVal("baz"));
 }
