@@ -32,6 +32,7 @@ const std::string _BondsPotentialStereo = "_BondsPotentialStereo";
 const std::string _ChiralAtomRank = "_chiralAtomRank";
 const std::string _CIPCode = "_CIPCode";
 const std::string _CIPRank = "_CIPRank";
+const std::string _CIPComputed = "_CIPComputed";
 const std::string _CanonicalRankingNumber = "_CanonicalRankingNumber";
 const std::string _ChiralityPossible = "_ChiralityPossible";
 const std::string _CrippenLogP = "_CrippenLogP";
@@ -128,11 +129,14 @@ const std::string molRingBondCount = "molRingBondCount";
 const std::string molSubstCount = "molSubstCount";
 const std::string molAttachPoint = "molAttchpt";
 const std::string molAttachOrder = "molAttchord";
+const std::string molAttachOrderTemplate = "molAttachOrderTemplate";
 const std::string molAtomClass = "molClass";
 const std::string molAtomSeqId = "molSeqid";
 const std::string molRxnExactChange = "molRxnExachg";
 const std::string molReactStatus = "molReactStatus";
 const std::string _fromAttachPoint = "_fromAttchpt";
+const std::string natReplace = "natReplace";
+const std::string templateNames = "templateNames";
 
 const std::string molNote = "molNote";
 const std::string atomNote = "atomNote";
