@@ -41,9 +41,7 @@ class RDKIT_SIMDIVPICKERS_EXPORT HierarchicalClusterPicker : public DistPicker {
    * Sets the hierarchy clustering method
    */
   explicit HierarchicalClusterPicker(ClusterMethod clusterMethod)
-      : d_method(clusterMethod) {
-    ;
-  };
+      : d_method(clusterMethod) {}
 
   /*! \brief This is the function that does the picking
    *
@@ -78,7 +76,7 @@ class RDKIT_SIMDIVPICKERS_EXPORT HierarchicalClusterPicker : public DistPicker {
    *    \param pickSize - the number items to pick from pool (<= poolSize)
    */
   RDKit::INT_VECT pick(const double *distMat, unsigned int poolSize,
-                       unsigned int pickSize) const;
+                       unsigned int pickSize) const override;
 
   /*! \brief This is the function that does the clustering of the items - used
    *by the picker
