@@ -3,16 +3,20 @@
 #
 #   @@ All Rights Reserved  @@
 #
-import unittest, subprocess, os
+import os
+import subprocess
+import unittest
+
 from rdkit import RDConfig
 
 
 class TestCase(unittest.TestCase):
+
   def test1Github1406(self):
     with open('data/simple.smi') as inf:
-      p = subprocess.run(('python', 'rfrag.py'),stdin=inf,stdout=subprocess.PIPE)
+      p = subprocess.run(('python', 'rfrag.py'), stdin=inf, stdout=subprocess.PIPE)
     self.assertFalse(p.returncode)
-    self.assertEqual(p.stdout,b'''c1ccccc1,benzene,,
+    self.assertEqual(p.stdout, b'''c1ccccc1,benzene,,
 Cc1ccccc1,toluene,,C[*:1].c1ccc(cc1)[*:1]
 ''')
 
