@@ -14,10 +14,8 @@ namespace GapeGa {
 
 int Chromosome::idCounter = 0;
 
-Chromosome::Chromosome() :  chromosomeId(idCounter++), fitness(0){
-}
+Chromosome::Chromosome() : chromosomeId(idCounter++), fitness(0) {}
 
-Chromosome::~Chromosome() {
-}
+Chromosome::~Chromosome() {}
 
-}
+}  // namespace GapeGa
