@@ -1,4 +1,5 @@
 #include <iostream>
+#include <ranges>
 #include <sstream>
 #include <stdexcept>
 
@@ -25,8 +26,11 @@ using namespace RDKit;
 // Bondi radii
 //  can find more of these in Table 12 of this publication:
 //   https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3658832/
+// The dummy atom radius (atomic number 0) is set to
+// 2.16 in ShapeInputOptions and may be varied there, as
+// may all the other radii if required, including the
+// addition of atoms not covered here.
 const std::map<unsigned int, double> vdw_radii = {
-    {0, 1.10},   // dummy atom (value copied from H)
     {1, 1.10},   // H
     {2, 1.40},   // He
     {3, 1.81},   // Li
@@ -159,19 +163,18 @@ std::vector<std::vector<const ROMol *>> *getPh4Patterns() {
   return patterns.get();
 }
 
-// the conformer is translated to the origin
-ShapeInput PrepareConformer(const ROMol &mol, int confId, bool useColors) {
-  ShapeInput res;
-
+namespace {
+std::vector<std::pair<std::vector<unsigned int>, unsigned int>> extractFeatures(
+    const ROMol &mol, const ShapeInputOptions &shapeOpts) {
   // unpack features (PubChem-specific property from SDF)
   // NOTE: this unpacking assumes that RWMol-atom-index = SDF-atom-number - 1
   //   e.g. RWMol uses [0..N-1] and SDF uses [1..N], with atoms in the same
   //   order
+  // If there are no PubChem features, falls back on RDKit pphore types.
 
   std::vector<std::pair<std::vector<unsigned int>, unsigned int>>
       feature_idx_type;
-
-  if (useColors) {
+  if (shapeOpts.useColors) {
     std::string features;
     if (mol.getPropIfPresent(pubchemFeatureName, features)) {
       // regular atoms have type 0; feature "atoms" (features represented by a
@@ -244,8 +247,135 @@ ShapeInput PrepareConformer(const ROMol &mol, int confId, bool useColors) {
       }
     }
   }
+  return feature_idx_type;
+}
 
-  // unpack atoms
+bool atomInSubset(unsigned int atomIdx, const ShapeInputOptions &shapeOpts) {
+  if (shapeOpts.atomSubset.empty()) {
+    return true;
+  }
+  return std::ranges::find(shapeOpts.atomSubset, atomIdx) !=
+         shapeOpts.atomSubset.end();
+}
+bool atomAllowedInColor(unsigned int atomIdx,
+                        const ShapeInputOptions &shapeOpts) {
+  return std::ranges::find(shapeOpts.notColorAtoms, atomIdx) ==
+         shapeOpts.notColorAtoms.end();
+}
+
+double getAtomRadius(unsigned int atomIdx, const ShapeInputOptions &shapeOpts) {
+  auto it = std::ranges::find_if(
+      shapeOpts.atomRadii,
+      [atomIdx](const auto &p) -> bool { return p.first == atomIdx; });
+  return it == shapeOpts.atomRadii.end() ? -1.0 : it->second;
+}
+
+// Get the atom radii.  rad_vector is expected to be big enough to hold them
+// all.  Also computes the average coordinates of the selected atoms.
+void extractAtomRadii(const Conformer &conformer, unsigned int nAtoms,
+                      const ShapeInputOptions &shapeOpts, RDGeom::Point3D &ave,
+                      unsigned int &nSelectedAtoms,
+                      std::vector<double> &rad_vector) {
+  nSelectedAtoms = 0;
+  for (unsigned int i = 0u; i < nAtoms; ++i) {
+    if (!atomInSubset(i, shapeOpts)) {
+      continue;
+    }
+    double rad = getAtomRadius(i, shapeOpts);
+    if (rad > 0.0) {
+      rad_vector[nSelectedAtoms++] = rad;
+      ave += conformer.getAtomPos(i);
+    } else {
+      unsigned int Z =
+          conformer.getOwningMol().getAtomWithIdx(i)->getAtomicNum();
+      if (Z > 1) {
+        ave += conformer.getAtomPos(i);
+        if (auto rad = vdw_radii.find(Z); rad != vdw_radii.end()) {
+          rad_vector[nSelectedAtoms++] = rad->second;
+        } else {
+          throw ValueErrorException("No VdW radius for atom with Z=" +
+                                    std::to_string(Z));
+        }
+      } else if (shapeOpts.includeDummies && Z == 0) {
+        ave += conformer.getAtomPos(i);
+        rad_vector[nSelectedAtoms++] = shapeOpts.dummyRadius;
+      }
+    }
+  }
+  ave /= nSelectedAtoms;
+}
+
+void extractAtomCoords(const Conformer &conformer, const unsigned int nAtoms,
+                       const ShapeInputOptions &shapeOpts,
+                       const RDGeom::Point3D &ave, std::vector<float> &coords) {
+  for (unsigned i = 0, j = 0; i < nAtoms; ++i) {
+    if (!atomInSubset(i, shapeOpts)) {
+      continue;
+    }
+    // use only non-H for alignment, optionally with dummy atoms.
+    unsigned int Z = conformer.getOwningMol().getAtomWithIdx(i)->getAtomicNum();
+    if (Z > 1 || (shapeOpts.includeDummies && Z == 0)) {
+      RDGeom::Point3D pos = conformer.getAtomPos(i);
+      pos -= ave;
+      coords[j * 3] = pos.x;
+      coords[(j * 3) + 1] = pos.y;
+      coords[(j * 3) + 2] = pos.z;
+      ++j;
+    }
+  }
+}
+
+void extractFeatureCoords(
+    const Conformer &conformer, const unsigned int nAtoms,
+    const unsigned int nSelectedAtoms,
+    const std::vector<std::pair<std::vector<unsigned int>, unsigned int>>
+        &feature_idx_type,
+    const ShapeInputOptions &shapeOpts, const RDGeom::Point3D &ave,
+    unsigned int &numFeatures, ShapeInput &res,
+    std::vector<double> &rad_vector) {
+  // get feature coordinates - simply the average of coords of all atoms in the
+  // feature
+  for (unsigned i = 0; i < feature_idx_type.size(); ++i) {
+    RDGeom::Point3D floc;
+    unsigned int nSel = 0;
+    for (unsigned int j = 0; j < feature_idx_type[i].first.size(); ++j) {
+      unsigned int idx = feature_idx_type[i].first[j];
+      if (!atomInSubset(idx, shapeOpts) ||
+          !atomAllowedInColor(idx, shapeOpts)) {
+        continue;
+      }
+      if (idx >= nAtoms ||
+          conformer.getOwningMol().getAtomWithIdx(idx)->getAtomicNum() <= 1) {
+        throw ValueErrorException("Invalid feature atom index");
+      }
+      floc += conformer.getAtomPos(idx);
+      ++nSel;
+    }
+    if (nSel == feature_idx_type[i].first.size()) {
+      floc /= nSel;
+      floc -= ave;
+      DEBUG_MSG("feature type " << feature_idx_type[i].second << " (" << floc
+                                << ")");
+
+      auto array_idx = nSelectedAtoms + numFeatures;
+      res.coord[array_idx * 3] = floc.x;
+      res.coord[(array_idx * 3) + 1] = floc.y;
+      res.coord[(array_idx * 3) + 2] = floc.z;
+      rad_vector[array_idx] = radius_color;
+      res.atom_type_vector[array_idx] = feature_idx_type[i].second;
+      ++numFeatures;
+    }
+  }
+}
+
+}  // namespace
+// The conformer is left where it is, the shape is translated to the origin.
+ShapeInput PrepareConformer(const ROMol &mol, int confId,
+                            const ShapeInputOptions &shapeOpts) {
+  Align3D::setUseCutOff(true);
+  ShapeInput res;
+
+  auto feature_idx_type = extractFeatures(mol, shapeOpts);
 
   auto &conformer = mol.getConformer(confId);
   if (!conformer.is3D()) {
@@ -254,71 +384,33 @@ ShapeInput PrepareConformer(const ROMol &mol, int confId, bool useColors) {
   unsigned int nAtoms = mol.getNumAtoms();
   // DEBUG_MSG("num atoms: " << nAtoms);
 
-  unsigned int nHeavyAtoms = mol.getNumHeavyAtoms();
-  DEBUG_MSG("num heavy atoms: " << nHeavyAtoms);
-
-  unsigned int nAlignmentAtoms = nHeavyAtoms + feature_idx_type.size();
-
+  // Start with the arrays as large as they will possibly have to be.
+  // They will be re-sized later.
+  unsigned int nAlignmentAtoms = nAtoms + feature_idx_type.size();
   std::vector<double> rad_vector(nAlignmentAtoms);
   res.atom_type_vector.resize(nAlignmentAtoms, 0);
 
   RDGeom::Point3D ave;
-  for (unsigned i = 0, activeAtomIdx = 0; i < nAtoms; ++i) {
-    unsigned int Z = mol.getAtomWithIdx(i)->getAtomicNum();
-    if (Z > 1) {
-      ave += conformer.getAtomPos(i);
-
-      if (auto rad = vdw_radii.find(Z); rad != vdw_radii.end()) {
-        rad_vector[activeAtomIdx++] = rad->second;
-      } else {
-        throw ValueErrorException("No VdW radius for atom with Z=" +
-                                  std::to_string(Z));
-      }
-    }
-  }
+  unsigned int nSelectedAtoms = 0;
+  extractAtomRadii(conformer, nAtoms, shapeOpts, ave, nSelectedAtoms,
+                   rad_vector);
 
   // translate steric center to origin
-  ave /= nHeavyAtoms;
   DEBUG_MSG("steric center: (" << ave << ")");
   res.shift = {-ave.x, -ave.y, -ave.z};
   res.coord.resize(nAlignmentAtoms * 3);
 
-  for (unsigned i = 0; i < nAtoms; ++i) {
-    // use only non-H for alignment
-    if (mol.getAtomWithIdx(i)->getAtomicNum() > 1) {
-      RDGeom::Point3D pos = conformer.getAtomPos(i);
-      pos -= ave;
-
-      res.coord[i * 3] = pos.x;
-      res.coord[(i * 3) + 1] = pos.y;
-      res.coord[(i * 3) + 2] = pos.z;
-    }
-  }
-
-  // get feature coordinates - simply the average of coords of all atoms in the
-  // feature
-  for (unsigned i = 0; i < feature_idx_type.size(); ++i) {
-    RDGeom::Point3D floc;
-    for (unsigned int j = 0; j < feature_idx_type[i].first.size(); ++j) {
-      unsigned int idx = feature_idx_type[i].first[j];
-      if (idx >= nAtoms || mol.getAtomWithIdx(idx)->getAtomicNum() <= 1) {
-        throw ValueErrorException("Invalid feature atom index");
-      }
-      floc += conformer.getAtomPos(idx);
-    }
-    floc /= feature_idx_type[i].first.size();
-    floc -= ave;
-    DEBUG_MSG("feature type " << feature_idx_type[i].second << " (" << floc
-                              << ")");
-
-    auto array_idx = nHeavyAtoms + i;
-    res.coord[array_idx * 3] = floc.x;
-    res.coord[(array_idx * 3) + 1] = floc.y;
-    res.coord[(array_idx * 3) + 2] = floc.z;
-    rad_vector[array_idx] = radius_color;
-    res.atom_type_vector[array_idx] = feature_idx_type[i].second;
-  }
+  extractAtomCoords(conformer, nAtoms, shapeOpts, ave, res.coord);
+  unsigned int numFeatures = 0;
+  extractFeatureCoords(conformer, nAtoms, nSelectedAtoms, feature_idx_type,
+                       shapeOpts, ave, numFeatures, res, rad_vector);
 
+  // Now cut the final vectors down to the actual number of atoms and
+  // features used.
+  nAlignmentAtoms = nSelectedAtoms + numFeatures;
+  res.coord.resize(nAlignmentAtoms * 3);
+  rad_vector.resize(nAlignmentAtoms);
+  res.atom_type_vector.resize(nAlignmentAtoms);
   Align3D::setAlpha(rad_vector.data(), rad_vector.size(), res.alpha_vector);
 
   // regular atom self overlap
@@ -343,18 +435,12 @@ ShapeInput PrepareConformer(const ROMol &mol, int confId, bool useColors) {
   return res;
 }
 
-std::pair<double, double> AlignMolecule(const ShapeInput &refShape, ROMol &fit,
-                                        std::vector<float> &matrix,
-                                        int fitConfId, bool useColors,
-                                        double opt_param,
-                                        unsigned int max_preiters,
-                                        unsigned int max_postiters) {
-  PRECONDITION(matrix.size() == 12, "bad matrix size");
-  Align3D::setUseCutOff(true);
-
-  DEBUG_MSG("Fit details:");
-  auto fitShape = PrepareConformer(fit, fitConfId, useColors);
-
+std::pair<double, double> AlignShape(const ShapeInput &refShape,
+                                     ShapeInput &fitShape,
+                                     std::vector<float> &matrix,
+                                     double opt_param,
+                                     unsigned int max_preiters,
+                                     unsigned int max_postiters) {
   std::set<unsigned int> jointColorAtomTypeSet;
   Align3D::getJointColorTypeSet(
       refShape.atom_type_vector.data(), refShape.atom_type_vector.size(),
@@ -362,8 +448,11 @@ std::pair<double, double> AlignMolecule(const ShapeInput &refShape, ROMol &fit,
       jointColorAtomTypeSet);
   auto mapCp = refShape.colorAtomType2IndexVectorMap;
   Align3D::restrictColorAtomType2IndexVectorMap(mapCp, jointColorAtomTypeSet);
-  Align3D::restrictColorAtomType2IndexVectorMap(
-      fitShape.colorAtomType2IndexVectorMap, jointColorAtomTypeSet);
+  // Take copy of the color atom mappings so as not to alter the input shape
+  // which might be re-used.
+  auto fitMapCp = fitShape.colorAtomType2IndexVectorMap;
+  Align3D::restrictColorAtomType2IndexVectorMap(fitMapCp,
+                                                jointColorAtomTypeSet);
 
   DEBUG_MSG("Running alignment...");
   double nbr_st = 0.0;
@@ -372,42 +461,79 @@ std::pair<double, double> AlignMolecule(const ShapeInput &refShape, ROMol &fit,
       refShape.coord.data(), refShape.alpha_vector,
       refShape.volumeAtomIndexVector, mapCp, refShape.sov, refShape.sof,
       fitShape.coord.data(), fitShape.alpha_vector,
-      fitShape.volumeAtomIndexVector, fitShape.colorAtomType2IndexVectorMap,
-      fitShape.sov, fitShape.sof, !jointColorAtomTypeSet.empty(), max_preiters,
-      max_postiters, opt_param, matrix.data(), nbr_st, nbr_ct);
+      fitShape.volumeAtomIndexVector, fitMapCp, fitShape.sov, fitShape.sof,
+      !jointColorAtomTypeSet.empty(), max_preiters, max_postiters, opt_param,
+      matrix.data(), nbr_st, nbr_ct);
 
   DEBUG_MSG("Done!");
   DEBUG_MSG("nbr_st: " << nbr_st);
   DEBUG_MSG("nbr_ct: " << nbr_ct);
 
+  std::vector<float> transformed(fitShape.coord.size());
+  Align3D::VApplyRotTransMatrix(transformed.data(), fitShape.coord.data(),
+                                fitShape.coord.size() / 3, matrix.data());
+  fitShape.coord = transformed;
+  return std::make_pair(nbr_st, nbr_ct);
+}
+
+void TransformConformer(const std::vector<double> &finalTrans,
+                        const std::vector<float> &matrix, ShapeInput &fitShape,
+                        Conformer &fitConf) {
+  // we reuse/modify the coord member of fitShape in order to avoid memory
+  // allocations
+  const unsigned int nAtoms = fitConf.getOwningMol().getNumAtoms();
+  if (nAtoms > fitShape.volumeAtomIndexVector.size()) {
+    // Hs are missing... make sure we have space for them
+    fitShape.coord.resize(3 * nAtoms);
+  }
+  // initialize the fitShape coords with the starting atomic positions from
+  // the conformer shifted to the center of "mass" coordinates.
+  for (unsigned int i = 0; i < nAtoms; ++i) {
+    const auto &pos = fitConf.getAtomPos(i);
+    fitShape.coord[i * 3] = pos.x + fitShape.shift[0];
+    fitShape.coord[i * 3 + 1] = pos.y + fitShape.shift[1];
+    fitShape.coord[i * 3 + 2] = pos.z + fitShape.shift[2];
+  }
+
+  std::vector<float> transformed(nAtoms * 3);
+  Align3D::VApplyRotTransMatrix(transformed.data(), fitShape.coord.data(),
+                                nAtoms, matrix.data());
+
+  // now set the coordinates in the conformer; undo the shift of the reference
+  // shape to center of "mass" coordinates
+  for (unsigned i = 0; i < nAtoms; ++i) {
+    RDGeom::Point3D &pos = fitConf.getAtomPos(i);
+    pos.x = transformed[i * 3] - finalTrans[0];
+    pos.y = transformed[(i * 3) + 1] - finalTrans[1];
+    pos.z = transformed[(i * 3) + 2] - finalTrans[2];
+  }
+}
+
+std::pair<double, double> AlignMolecule(
+    const ShapeInput &refShape, ROMol &fit, std::vector<float> &matrix,
+    int fitConfId, bool useColors, double opt_param, unsigned int max_preiters,
+    unsigned int max_postiters, bool applyRefShift) {
+  PRECONDITION(matrix.size() == 12, "bad matrix size");
+  Align3D::setUseCutOff(true);
+
+  DEBUG_MSG("Fit details:");
+  ShapeInputOptions shapeOpts;
+  shapeOpts.useColors = useColors;
+  auto fitShape = PrepareConformer(fit, fitConfId, shapeOpts);
+  auto tanis = AlignShape(refShape, fitShape, matrix, opt_param, max_preiters,
+                          max_postiters);
+
   // transform fit coords
   Conformer &fit_conformer = fit.getConformer(fitConfId);
-  if (3 * fit.getNumAtoms() != fitShape.coord.size()) {
-    // Hs were removed
-    fitShape.coord.resize(3 * fit.getNumAtoms());
-    for (unsigned int i = 0; i < fit.getNumAtoms(); ++i) {
-      const auto &pos = fit_conformer.getAtomPos(i);
-      fitShape.coord[i * 3] = pos.x + fitShape.shift[0];
-      fitShape.coord[i * 3 + 1] = pos.y + fitShape.shift[1];
-      fitShape.coord[i * 3 + 2] = pos.z + fitShape.shift[2];
-    }
+  std::vector<double> finalTrans{0.0, 0.0, 0.0};
+  if (applyRefShift) {
+    finalTrans = refShape.shift;
   }
-  std::vector<float> transformed(fit.getNumAtoms() * 3);
-  Align3D::VApplyRotTransMatrix(transformed.data(), fitShape.coord.data(),
-                                fit.getNumAtoms(), matrix.data());
+  TransformConformer(finalTrans, matrix, fitShape, fit_conformer);
+  fit.setProp("shape_align_shape_tanimoto", tanis.first);
+  fit.setProp("shape_align_color_tanimoto", tanis.second);
 
-  for (unsigned i = 0; i < fit.getNumAtoms(); ++i) {
-    // both conformers have been translated to the origin, translate the fit
-    // conformer back to the steric center of the reference.
-    RDGeom::Point3D &pos = fit_conformer.getAtomPos(i);
-    pos.x = transformed[i * 3] - refShape.shift[0];
-    pos.y = transformed[(i * 3) + 1] - refShape.shift[1];
-    pos.z = transformed[(i * 3) + 2] - refShape.shift[2];
-  }
-  fit.setProp("shape_align_shape_tanimoto", nbr_st);
-  fit.setProp("shape_align_color_tanimoto", nbr_ct);
-
-  return std::make_pair(nbr_st, nbr_ct);
+  return tanis;
 }
 
 std::pair<double, double> AlignMolecule(const ROMol &ref, ROMol &fit,
@@ -419,8 +545,11 @@ std::pair<double, double> AlignMolecule(const ROMol &ref, ROMol &fit,
   Align3D::setUseCutOff(true);
 
   DEBUG_MSG("Reference details:");
-  auto refShape = PrepareConformer(ref, refConfId, useColors);
+  ShapeInputOptions shapeOpts;
+  shapeOpts.useColors = useColors;
+  auto refShape = PrepareConformer(ref, refConfId, shapeOpts);
 
-  return AlignMolecule(refShape, fit, matrix, fitConfId, useColors, opt_param,
-                       max_preiters, max_postiters);
+  auto scores = AlignMolecule(refShape, fit, matrix, fitConfId, useColors,
+                              opt_param, max_preiters, max_postiters, true);
+  return scores;
 }
