@@ -14,9 +14,15 @@
   RD Version: $Rev$            
 """
 
+import os
+import sys
+import tempfile
+import threading
+import time
+import types
+
 import SimpleXMLRPCServer
-import threading, sys, time, types, os, tempfile
-from pymol import cmd, cgo
+from pymol import cgo, cmd
 
 # initial port to try for the server
 _xmlPort = 9123
@@ -248,20 +254,22 @@ is white
     o = []
   else:
     o = [cgo.ALPHA, 1 - transparency]
-  o.extend([cgo.CYLINDER,
-            x1,
-            y1,
-            z1,
-            x2,
-            y2,
-            z2,
-            rad,
-            r1,
-            g1,
-            b1,
-            r2,
-            g2,
-            b2, ])
+  o.extend([
+    cgo.CYLINDER,
+    x1,
+    y1,
+    z1,
+    x2,
+    y2,
+    z2,
+    rad,
+    r1,
+    g1,
+    b1,
+    r2,
+    g2,
+    b2,
+  ])
   obj.extend(o)
   cgoDict[id] = obj
   cmd.load_cgo(obj, id, 1)
