@@ -10,10 +10,8 @@
 import os
 import unittest
 
-from rdkit import Chem
-from rdkit import Geometry
-from rdkit import RDConfig
-from rdkit.Chem import ChemicalFeatures, AllChem
+from rdkit import Chem, Geometry, RDConfig
+from rdkit.Chem import AllChem, ChemicalFeatures
 from rdkit.Chem.Pharm3D import Pharmacophore
 
 
@@ -39,12 +37,14 @@ class TestCase(unittest.TestCase):
                    EndFeature\n"""
 
     self.featFactory = ChemicalFeatures.BuildFeatureFactoryFromString(self.fdefBlock)
-    self.feats = [ChemicalFeatures.FreeChemicalFeature('HBondAcceptor', 'HAcceptor1',
-                                                       Geometry.Point3D(0.0, 0.0, 0.0)),
-                  ChemicalFeatures.FreeChemicalFeature('HBondDonor', 'HDonor1',
-                                                       Geometry.Point3D(2.65, 0.0, 0.0)),
-                  ChemicalFeatures.FreeChemicalFeature('Aromatic', 'Aromatic1',
-                                                       Geometry.Point3D(5.12, 0.908, 0.0)), ]
+    self.feats = [
+      ChemicalFeatures.FreeChemicalFeature('HBondAcceptor', 'HAcceptor1',
+                                           Geometry.Point3D(0.0, 0.0, 0.0)),
+      ChemicalFeatures.FreeChemicalFeature('HBondDonor', 'HDonor1',
+                                           Geometry.Point3D(2.65, 0.0, 0.0)),
+      ChemicalFeatures.FreeChemicalFeature('Aromatic', 'Aromatic1',
+                                           Geometry.Point3D(5.12, 0.908, 0.0)),
+    ]
     self.pcophore = Pharmacophore.Pharmacophore(self.feats)
 
   def test1Basics(self):
