@@ -1,5 +1,6 @@
 #
-#  Copyright (c) 2011, Novartis Institutes for BioMedical Research Inc.
+#  Copyright (c) 2011-2025, Novartis Institutes for BioMedical Research Inc.
+#   and other RDKit contributors
 #  All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -42,7 +43,7 @@ from rdkit.Chem import (INCHI_AVAILABLE, ForwardSDMolSupplier, MolFromMolBlock,
 
 if INCHI_AVAILABLE:
   from rdkit.Chem import (InchiReadWriteError, InchiToInchiKey, MolBlockToInchi, MolFromInchi,
-                          MolToInchi, MolToInchiKey)
+                          MolToInchi, MolToInchiKey, GetInchiVersion)
 
 COLOR_RED = '\033[31m'
 COLOR_GREEN = '\033[32m'
@@ -204,11 +205,11 @@ class TestCase(unittest.TestCase):
           # InChI messed up the radical?
           unsanitizedInchiMol = MolFromInchi(x, sanitize=False)
           if sum([
-              a.GetNumRadicalElectrons() * a.GetAtomicNum()
-              for a in m.GetAtoms() if a.GetNumRadicalElectrons() != 0
+              a.GetNumRadicalElectrons() * a.GetAtomicNum() for a in m.GetAtoms()
+              if a.GetNumRadicalElectrons() != 0
           ]) != sum([
-              a.GetNumRadicalElectrons() * a.GetAtomicNum()
-              for a in unsanitizedInchiMol.GetAtoms() if a.GetNumRadicalElectrons() != 0
+              a.GetNumRadicalElectrons() * a.GetAtomicNum() for a in unsanitizedInchiMol.GetAtoms()
+              if a.GetNumRadicalElectrons() != 0
           ]):
             reasonable += 1
             continue
@@ -324,6 +325,11 @@ M  END"""
     inchi2 = MolBlockToInchi(mb2, options="/FixedH")
     self.assertEqual(inchi2, "InChI=1/C8H8N2/c1-6-7-4-2-3-5-8(7)10-9-6/h2-5H,1H3,(H,9,10)/f/h10H")
 
+  def test6GetInchiVersion(self):
+    version = GetInchiVersion()
+    self.assertIsInstance(version, str)
+    self.assertGreaterEqual(version, "1.07.2")
+
 
 if __name__ == '__main__':  # pragma: nocover
   # only run the test if InChI is available
