@@ -211,66 +211,89 @@ class TestCase(unittest.TestCase):
 
   def testEnumerateStereoisomersBasic(self):
     mol = Chem.MolFromSmiles('CC(F)=CC(Cl)C')
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(len(smiles), 4)
 
   def testEnumerateStereoisomersLargeRandomSample(self):
     # near max number of stereo centers allowed
     mol = Chem.MolFromSmiles('CC(F)=CC(Cl)C' * 31)
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(len(smiles), 1024)
 
   def testEnumerateStereoisomersWithCrazyNumberOfCenters(self):
     # insanely large numbers of isomers aren't a problem
     mol = Chem.MolFromSmiles('CC(F)=CC(Cl)C' * 101)
     opts = AllChem.StereoEnumerationOptions(rand=None, maxIsomers=13)
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(len(smiles), 13)
 
   def testEnumerateStereoisomersRandomSamplingShouldBeDeterministicAndPortable(self):
     mol = Chem.MolFromSmiles('CC(F)=CC(Cl)C=C(Br)C(I)N')
     opts = AllChem.StereoEnumerationOptions(maxIsomers=2)
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts))
-    expected = set(
-      ['C/C(F)=C\\[C@H](Cl)/C=C(/Br)[C@H](N)I', 'C/C(F)=C/[C@@H](Cl)/C=C(/Br)[C@H](N)I'])
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
+    expected = set([
+      'C/C(F)=C\\[C@H](Cl)/C=C(/Br)[C@H](N)I',
+      'C/C(F)=C/[C@@H](Cl)/C=C(/Br)[C@H](N)I',
+    ])
     self.assertEqual(smiles, expected)
 
   def testEnumerateStereoisomersMaxIsomersShouldBeReturnedEvenWithTryEmbedding(self):
-    m = Chem.MolFromSmiles('BrC=CC1OC(C2)(F)C2(Cl)C1')
+    mol = Chem.MolFromSmiles('BrC=CC1OC(C2)(F)C2(Cl)C1')
     opts = AllChem.StereoEnumerationOptions(tryEmbedding=True, maxIsomers=8)
     isomers = set()
-    for x in AllChem.EnumerateStereoisomers(m, options=opts):
-      isomers.add(Chem.MolToSmiles(x, isomericSmiles=True))
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      isomers.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(len(isomers), 8)
 
   def testEnumerateStereoisomersTryEmbeddingShouldNotInfiniteLoopWhenMaxIsomersIsLargerThanActual(
       self):
-    m = Chem.MolFromSmiles('BrC=CC1OC(C2)(F)C2(Cl)C1')
+    mol = Chem.MolFromSmiles('BrC=CC1OC(C2)(F)C2(Cl)C1')
     opts = AllChem.StereoEnumerationOptions(tryEmbedding=True, maxIsomers=1024)
     isomers = set()
-    for x in AllChem.EnumerateStereoisomers(m, options=opts):
-      isomers.add(Chem.MolToSmiles(x, isomericSmiles=True))
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      isomers.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(len(isomers), 8)
 
   def testEnumerateStereoisomersRandomSeeding(self):
     opts = AllChem.StereoEnumerationOptions(rand=None, maxIsomers=3)
     mol = Chem.MolFromSmiles('CC(F)=CC(Cl)C')
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts))
-    self.assertEqual(smiles,
-                     set(['C/C(F)=C/[C@@H](C)Cl', 'C/C(F)=C\\[C@H](C)Cl', 'C/C(F)=C\\[C@@H](C)Cl']))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
+    self.assertEqual(
+      smiles, set([
+        'C/C(F)=C/[C@@H](C)Cl',
+        'C/C(F)=C\\[C@H](C)Cl',
+        'C/C(F)=C\\[C@@H](C)Cl',
+      ]))
 
     opts = AllChem.StereoEnumerationOptions(rand=0xDEADBEEF)
     mol = Chem.MolFromSmiles('c1ccc2c(c1)C(=O)N(C2=O)C3CCC(=O)NC3=O')
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(
       smiles,
-      set(['O=C1CC[C@@H](N2C(=O)c3ccccc3C2=O)C(=O)N1', 'O=C1CC[C@H](N2C(=O)c3ccccc3C2=O)C(=O)N1']))
+      set([
+        'O=C1CC[C@@H](N2C(=O)c3ccccc3C2=O)C(=O)N1',
+        'O=C1CC[C@H](N2C(=O)c3ccccc3C2=O)C(=O)N1',
+      ]))
 
     class DeterministicRandom(random.Random):
 
@@ -289,40 +312,51 @@ class TestCase(unittest.TestCase):
     smiles = list(
       Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol))
     self.assertEqual(smiles, [
-      'CCC/C(=C(/CCl)[C@H](C)CBr)[C@H](F)C(C)C', 'CCC/C(=C(/CCl)[C@@H](C)CBr)[C@H](F)C(C)C',
-      'CCC/C(=C(\\CCl)[C@H](C)CBr)[C@H](F)C(C)C', 'CCC/C(=C(\\CCl)[C@@H](C)CBr)[C@H](F)C(C)C'
+      'CCC/C(=C(/CCl)[C@H](C)CBr)[C@H](F)C(C)C',
+      'CCC/C(=C(/CCl)[C@@H](C)CBr)[C@H](F)C(C)C',
+      'CCC/C(=C(\\CCl)[C@H](C)CBr)[C@H](F)C(C)C',
+      'CCC/C(=C(\\CCl)[C@@H](C)CBr)[C@H](F)C(C)C',
     ])
     rand = DeterministicRandom()
     opts = AllChem.StereoEnumerationOptions(rand=rand, maxIsomers=3)
-    smiles = list(
-      sorted(
-        Chem.MolToSmiles(i, isomericSmiles=True)
-        for i in AllChem.EnumerateStereoisomers(mol, opts)))
+    smiles = list()
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.append(Chem.MolToSmiles(m, isomericSmiles=True))
+    smiles.sort()
     self.assertEqual(smiles, [
-      'CCC/C(=C(/CCl)[C@@H](C)CBr)[C@H](F)C(C)C', 'CCC/C(=C(/CCl)[C@H](C)CBr)[C@H](F)C(C)C',
-      'CCC/C(=C(\\CCl)[C@H](C)CBr)[C@H](F)C(C)C'
+      'CCC/C(=C(/CCl)[C@@H](C)CBr)[C@H](F)C(C)C',
+      'CCC/C(=C(/CCl)[C@H](C)CBr)[C@H](F)C(C)C',
+      'CCC/C(=C(\\CCl)[C@H](C)CBr)[C@H](F)C(C)C',
     ])
 
   def testEnumerateStereoisomersOnlyUnassigned(self):
     # shouldn't enumerate anything
     fully_assigned = Chem.MolFromSmiles('C/C(F)=C/[C@@H](C)Cl')
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True)
-      for i in AllChem.EnumerateStereoisomers(fully_assigned))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(fully_assigned):
+      self.assertEqual(m.HasProp('_MolFileChiralFlag'), False)
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(smiles, set(['C/C(F)=C/[C@@H](C)Cl']))
 
     # should only enumerate the bond stereo
     partially_assigned = Chem.MolFromSmiles('CC(F)=C[C@@H](C)Cl')
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True)
-      for i in AllChem.EnumerateStereoisomers(partially_assigned))
-    self.assertEqual(smiles, set(['C/C(F)=C/[C@@H](C)Cl', 'C/C(F)=C\\[C@@H](C)Cl']))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(partially_assigned):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
+    self.assertEqual(smiles, set([
+      'C/C(F)=C/[C@@H](C)Cl',
+      'C/C(F)=C\\[C@@H](C)Cl',
+    ]))
 
     # should enumerate everything
     opts = AllChem.StereoEnumerationOptions(onlyUnassigned=False)
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True)
-      for i in AllChem.EnumerateStereoisomers(fully_assigned, opts))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(fully_assigned, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
+    print(smiles)
     self.assertEqual(
       smiles,
       set([
@@ -335,47 +369,54 @@ class TestCase(unittest.TestCase):
   def testEnumerateStereoisomersOnlyUnique(self):
     mol = Chem.MolFromSmiles('FC(Cl)C(Cl)F')
     opts = AllChem.StereoEnumerationOptions(unique=False)
-    smiles = [
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts)
-    ]
+    smiles = []
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.append(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(len(smiles), 4)
     self.assertEqual(len(set(smiles)), 3)
 
     mol = Chem.MolFromSmiles('FC(Cl)C(Cl)F')
     opts = AllChem.StereoEnumerationOptions(unique=True)
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(
       smiles, set(['F[C@@H](Cl)[C@@H](F)Cl', 'F[C@H](Cl)[C@@H](F)Cl', 'F[C@H](Cl)[C@H](F)Cl']))
 
     mol = Chem.MolFromSmiles('CC=CC=CC')
     opts = AllChem.StereoEnumerationOptions(unique=False)
-    smiles = [
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts)
-    ]
+    smiles = []
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.append(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(len(smiles), 4)
     self.assertEqual(len(set(smiles)), 3)
 
     mol = Chem.MolFromSmiles('CC=CC=CC')
     opts = AllChem.StereoEnumerationOptions(unique=True)
-    smiles = set(
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(smiles, set(['C/C=C/C=C/C', 'C/C=C\\C=C\\C', 'C/C=C\\C=C/C']))
 
     mol = Chem.MolFromSmiles('FC(Cl)C=CC=CC(F)Cl')
     opts = AllChem.StereoEnumerationOptions(unique=False)
-    smiles = [
-      Chem.MolToSmiles(i, isomericSmiles=True) for i in AllChem.EnumerateStereoisomers(mol, opts)
-    ]
+    smiles = []
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.append(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(len(smiles), 16)
     self.assertEqual(len(set(smiles)), 10)
 
     mol = Chem.MolFromSmiles('FC(Cl)C=CC=CC(F)Cl')
     opts = AllChem.StereoEnumerationOptions(unique=True)
-    smiles = set(
-      sorted(
-        Chem.MolToSmiles(i, isomericSmiles=True)
-        for i in AllChem.EnumerateStereoisomers(mol, opts)))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
     self.assertEqual(
       smiles,
       set(
@@ -391,7 +432,10 @@ class TestCase(unittest.TestCase):
     rdbase = os.environ["RDBASE"]
     filename = os.path.join(rdbase, 'Code/GraphMol/FileParsers/test_data/two_centers_or.mol')
     mol = Chem.MolFromMolFile(filename)
-    smiles = set(Chem.MolToSmiles(m) for m in AllChem.EnumerateStereoisomers(mol))
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m))
     # switches the centers linked by an "OR", but not the absolute group
     self.assertEqual(smiles, {r'C[C@H]([C@@H](C)F)[C@@H](C)Br', r'C[C@@H]([C@H](C)F)[C@@H](C)Br'})
 
@@ -411,43 +455,53 @@ class TestCase(unittest.TestCase):
     mol = Chem.MolFromMolFile(filename)
 
     opts = AllChem.StereoEnumerationOptions(onlyUnassigned=False, unique=False)
-    smiles = [Chem.MolToSmiles(m) for m in AllChem.EnumerateStereoisomers(mol, opts)]
+    smiles = []
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.append(Chem.MolToSmiles(m))
+    print('!!!!', smiles)
     self.assertEqual(len(smiles), len(set(smiles)))
     self.assertEqual(len(smiles), 2**3)
 
   def testIssue2890(self):
     mol = Chem.MolFromSmiles('CC=CC')
     mol.GetBondWithIdx(1).SetStereo(Chem.rdchem.BondStereo.STEREOANY)
-
-    self.assertEqual(len(list(AllChem.EnumerateStereoisomers(mol))), 2)
+    isomers = []
+    for m in AllChem.EnumerateStereoisomers(mol):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      isomers.append(m)
+    self.assertEqual(len(isomers), 2)
 
   def testIssue3231(self):
     mol = Chem.MolFromSmiles(
       'C[C@H](OC1=C(N)N=CC(C2=CN(C3C[C@H](C)NCC3)N=C2)=C1)C4=C(Cl)C=CC(F)=C4Cl')
     Chem.AssignStereochemistry(mol, force=True, flagPossibleStereoCenters=True)
-    l = Chem.FindMolChiralCenters(mol, includeUnassigned=True)
-    self.assertEqual(l, [(1, 'S'), (12, '?'), (14, 'S')])
+    centers = Chem.FindMolChiralCenters(mol, includeUnassigned=True)
+    self.assertEqual(centers, [(1, 'S'), (12, '?'), (14, 'S')])
     enumsi_opt = AllChem.StereoEnumerationOptions(maxIsomers=20, onlyUnassigned=False)
     isomers = list(AllChem.EnumerateStereoisomers(mol, enumsi_opt))
     chi_cents = []
     for iso in isomers:
+      self.assertEqual(iso.GetProp('_MolFileChiralFlag'), '1')
       Chem.AssignStereochemistry(iso)
       chi_cents.append(Chem.FindMolChiralCenters(iso, includeUnassigned=True))
-    self.assertEqual(sorted(chi_cents),
-                     [[(1, 'R'), (12, 'R'),
-                       (14, 'R')], [(1, 'R'), (12, 'R'),
-                                    (14, 'S')], [(1, 'R'), (12, 'S'),
-                                                 (14, 'R')], [(1, 'R'), (12, 'S'), (14, 'S')],
-                      [(1, 'S'), (12, 'R'),
-                       (14, 'R')], [(1, 'S'), (12, 'R'),
-                                    (14, 'S')], [(1, 'S'), (12, 'S'),
-                                                 (14, 'R')], [(1, 'S'), (12, 'S'), (14, 'S')]])
+    self.assertEqual(sorted(chi_cents), [
+      [(1, 'R'), (12, 'R'), (14, 'R')],
+      [(1, 'R'), (12, 'R'), (14, 'S')],
+      [(1, 'R'), (12, 'S'), (14, 'R')],
+      [(1, 'R'), (12, 'S'), (14, 'S')],
+      [(1, 'S'), (12, 'R'), (14, 'R')],
+      [(1, 'S'), (12, 'R'), (14, 'S')],
+      [(1, 'S'), (12, 'S'), (14, 'R')],
+      [(1, 'S'), (12, 'S'), (14, 'S')],
+    ])
 
   def testIssue3505(self):
     m = Chem.MolFromSmiles('CCC(C)Br')
     mols = list(AllChem.EnumerateStereoisomers(m))
     self.assertEqual(len(mols), 2)
     for mol in mols:
+      self.assertEqual(mol.GetProp('_MolFileChiralFlag'), '1')
       at = mol.GetAtomWithIdx(2)
       self.assertIn(at.GetChiralTag(),
                     [Chem.ChiralType.CHI_TETRAHEDRAL_CW, Chem.ChiralType.CHI_TETRAHEDRAL_CCW])
@@ -458,20 +512,28 @@ class TestCase(unittest.TestCase):
     rdbase = os.environ["RDBASE"]
     filename = os.path.join(rdbase, 'Code/GraphMol/FileParsers/test_data/simple_either.mol')
     mol = Chem.MolFromMolFile(filename)
-    smiles = [Chem.MolToSmiles(m) for m in AllChem.EnumerateStereoisomers(mol)]
-    self.assertEqual(set(smiles), {"C/C=C/C", "C/C=C\\C"})
+    smiles = set()
+    for m in AllChem.EnumerateStereoisomers(mol):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      smiles.add(Chem.MolToSmiles(m, isomericSmiles=True))
+    self.assertEqual(smiles, {"C/C=C/C", "C/C=C\\C"})
 
   def testTryEmbeddingManyChirals(self):
     smiles = "C1" + "C(Cl)(Br)" * 40 + "C1"
     mol = Chem.MolFromSmiles(smiles)
     opts = AllChem.StereoEnumerationOptions(tryEmbedding=True, maxIsomers=2)
-    self.assertEqual(len(list(AllChem.EnumerateStereoisomers(mol, options=opts))), 2)
+    isomers = []
+    for m in AllChem.EnumerateStereoisomers(mol, opts):
+      self.assertEqual(m.GetProp('_MolFileChiralFlag'), '1')
+      isomers.append(m)
+    self.assertEqual(len(isomers), 2)
 
   def testGithub6045(self):
     mol = Chem.MolFromSmiles('O[C@H](Br)[C@H](F)C |&1:1,3|')
     prods = list(AllChem.EnumerateStereoisomers(mol))
     self.assertEqual(len(prods), 2)
     for prod in prods:
+      self.assertEqual(prod.GetProp('_MolFileChiralFlag'), '1')
       self.assertEqual(len(prod.GetStereoGroups()), 0)
 
   def testGithub7516(self):
