@@ -8,129 +8,133 @@
 #  which is included in the file license.txt, found at the root
 #  of the RDKit source tree.
 #
-from __future__ import print_function
+
 import copy
 import struct
-from rdkit.six import iterkeys
-from rdkit import six
+
 from rdkit import DataStructs
 
 
 class VectCollection(object):
   """
 
-  >>> vc = VectCollection()
-  >>> bv1 = DataStructs.ExplicitBitVect(10)
-  >>> bv1.SetBitsFromList((1,3,5))
-  >>> vc.AddVect(1,bv1)
-  >>> bv1 = DataStructs.ExplicitBitVect(10)
-  >>> bv1.SetBitsFromList((6,8))
-  >>> vc.AddVect(2,bv1)
-  >>> len(vc)
-  10
-  >>> vc.GetNumBits()
-  10
-  >>> vc[0]
-  0
-  >>> vc[1]
-  1
-  >>> vc[9]
-  0
-  >>> vc[6]
-  1
-  >>> vc.GetBit(6)
-  1
-  >>> list(vc.GetOnBits())
-  [1, 3, 5, 6, 8]
+    >>> vc = VectCollection()
+    >>> bv1 = DataStructs.ExplicitBitVect(10)
+    >>> bv1.SetBitsFromList((1,3,5))
+    >>> vc.AddVect(1,bv1)
+    >>> bv1 = DataStructs.ExplicitBitVect(10)
+    >>> bv1.SetBitsFromList((6,8))
+    >>> vc.AddVect(2,bv1)
+    >>> len(vc)
+    10
+    >>> vc.GetNumBits()
+    10
+    >>> vc[0]
+    0
+    >>> vc[1]
+    1
+    >>> vc[9]
+    0
+    >>> vc[6]
+    1
+    >>> vc.GetBit(6)
+    1
+    >>> list(vc.GetOnBits())
+    [1, 3, 5, 6, 8]
 
-  keys must be unique, so adding a duplicate replaces the
-  previous values:
-  >>> bv1 = DataStructs.ExplicitBitVect(10)
-  >>> bv1.SetBitsFromList((7,9))
-  >>> vc.AddVect(1,bv1)
-  >>> len(vc)
-  10
-  >>> vc[1]
-  0
-  >>> vc[9]
-  1
-  >>> vc[6]
-  1
+    keys must be unique, so adding a duplicate replaces the
+    previous values:
 
-  we can also query the children:
-  >>> vc.NumChildren()
-  2
-  >>> cs = vc.GetChildren()
-  >>> id,fp = cs[0]
-  >>> id
-  1
-  >>> list(fp.GetOnBits())
-  [7, 9]
-  >>> id,fp = cs[1]
-  >>> id
-  2
-  >>> list(fp.GetOnBits())
-  [6, 8]
+    >>> bv1 = DataStructs.ExplicitBitVect(10)
+    >>> bv1.SetBitsFromList((7,9))
+    >>> vc.AddVect(1,bv1)
+    >>> len(vc)
+    10
+    >>> vc[1]
+    0
+    >>> vc[9]
+    1
+    >>> vc[6]
+    1
 
-  attach/detach operations:
-  >>> bv1 = DataStructs.ExplicitBitVect(10)
-  >>> bv1.SetBitsFromList((5,6))
-  >>> vc.AddVect(3,bv1)
-  >>> vc.NumChildren()
-  3
-  >>> list(vc.GetOnBits())
-  [5, 6, 7, 8, 9]
-  >>> vc.DetachVectsNotMatchingBit(6)
-  >>> vc.NumChildren()
-  2
-  >>> list(vc.GetOnBits())
-  [5, 6, 8]
+    we can also query the children:
+
+    >>> vc.NumChildren()
+    2
+    >>> cs = vc.GetChildren()
+    >>> id,fp = cs[0]
+    >>> id
+    1
+    >>> list(fp.GetOnBits())
+    [7, 9]
+    >>> id,fp = cs[1]
+    >>> id
+    2
+    >>> list(fp.GetOnBits())
+    [6, 8]
+
+    attach/detach operations:
+
+    >>> bv1 = DataStructs.ExplicitBitVect(10)
+    >>> bv1.SetBitsFromList((5,6))
+    >>> vc.AddVect(3,bv1)
+    >>> vc.NumChildren()
+    3
+    >>> list(vc.GetOnBits())
+    [5, 6, 7, 8, 9]
+    >>> vc.DetachVectsNotMatchingBit(6)
+    >>> vc.NumChildren()
+    2
+    >>> list(vc.GetOnBits())
+    [5, 6, 8]
 
 
-  >>> bv1 = DataStructs.ExplicitBitVect(10)
-  >>> bv1.SetBitsFromList((7,9))
-  >>> vc.AddVect(1,bv1)
-  >>> vc.NumChildren()
-  3
-  >>> list(vc.GetOnBits())
-  [5, 6, 7, 8, 9]
-  >>> vc.DetachVectsMatchingBit(6)
-  >>> vc.NumChildren()
-  1
-  >>> list(vc.GetOnBits())
-  [7, 9]
+    >>> bv1 = DataStructs.ExplicitBitVect(10)
+    >>> bv1.SetBitsFromList((7,9))
+    >>> vc.AddVect(1,bv1)
+    >>> vc.NumChildren()
+    3
+    >>> list(vc.GetOnBits())
+    [5, 6, 7, 8, 9]
+    >>> vc.DetachVectsMatchingBit(6)
+    >>> vc.NumChildren()
+    1
+    >>> list(vc.GetOnBits())
+    [7, 9]
 
 
-  to copy VectCollections, use the copy module:
-  >>> bv1 = DataStructs.ExplicitBitVect(10)
-  >>> bv1.SetBitsFromList((5,6))
-  >>> vc.AddVect(3,bv1)
-  >>> list(vc.GetOnBits())
-  [5, 6, 7, 9]
-  >>> vc2 = copy.copy(vc)
-  >>> vc.DetachVectsNotMatchingBit(6)
-  >>> list(vc.GetOnBits())
-  [5, 6]
-  >>> list(vc2.GetOnBits())
-  [5, 6, 7, 9]
+    to copy VectCollections, use the copy module:
 
-  The Uniquify() method can be used to remove duplicate vectors:
-  >>> vc = VectCollection()
-  >>> bv1 = DataStructs.ExplicitBitVect(10)
-  >>> bv1.SetBitsFromList((7,9))
-  >>> vc.AddVect(1,bv1)
-  >>> vc.AddVect(2,bv1)
-  >>> bv1 = DataStructs.ExplicitBitVect(10)
-  >>> bv1.SetBitsFromList((2,3,5))
-  >>> vc.AddVect(3,bv1)
-  >>> vc.NumChildren()
-  3
-  >>> vc.Uniquify()
-  >>> vc.NumChildren()
-  2
+    >>> bv1 = DataStructs.ExplicitBitVect(10)
+    >>> bv1.SetBitsFromList((5,6))
+    >>> vc.AddVect(3,bv1)
+    >>> list(vc.GetOnBits())
+    [5, 6, 7, 9]
+    >>> vc2 = copy.copy(vc)
+    >>> vc.DetachVectsNotMatchingBit(6)
+    >>> list(vc.GetOnBits())
+    [5, 6]
+    >>> list(vc2.GetOnBits())
+    [5, 6, 7, 9]
+
+    The Uniquify() method can be used to remove duplicate vectors:
+
+    >>> vc = VectCollection()
+    >>> bv1 = DataStructs.ExplicitBitVect(10)
+    >>> bv1.SetBitsFromList((7,9))
+    >>> vc.AddVect(1,bv1)
+    >>> vc.AddVect(2,bv1)
+    >>> bv1 = DataStructs.ExplicitBitVect(10)
+    >>> bv1.SetBitsFromList((2,3,5))
+    >>> vc.AddVect(3,bv1)
+    >>> vc.NumChildren()
+    3
+    >>> vc.Uniquify()
+    >>> vc.NumChildren()
+    2
 
 
-  """
+    """
 
   def __init__(self):
     self.__vects = {}
@@ -155,7 +159,7 @@ class VectCollection(object):
     self.__orVect = None
     if not self.__vects:
       return
-    ks = list(iterkeys(self.__vects))
+    ks = list(iter(self.__vects))
     self.__orVect = copy.copy(self.__vects[ks[0]])
     self.__numBits = self.__orVect.GetNumBits()
     for i in range(1, len(ks)):
@@ -243,7 +247,7 @@ class VectCollection(object):
     return pkl
 
   def __setstate__(self, pkl):
-    if six.PY3 and isinstance(pkl, str):
+    if isinstance(pkl, str):
       pkl = bytes(pkl, encoding='Latin1')
 
     self.__vects = {}
@@ -270,8 +274,8 @@ class VectCollection(object):
 #  doctest boilerplate
 #
 def _runDoctests(verbose=None):  # pragma: nocover
-  import sys
   import doctest
+  import sys
   failed, _ = doctest.testmod(optionflags=doctest.ELLIPSIS, verbose=verbose)
   sys.exit(failed)
 
