@@ -8,12 +8,10 @@
 #  of the RDKit source tree.
 #
 
-
 import doctest
 import unittest
 
-from rdkit import Chem
-from rdkit import RDConfig
+from rdkit import Chem, RDConfig
 from rdkit.Dbase.DbConnection import DbConnect
 from rdkit.SimDivFilters import SimilarityPickers
 
